searchData={"items":[{"type":"module","title":"Cldr.Date","doc":"Provides localization and formatting of a `t:Date.t/0`\nstruct or any map with one or more of the keys `:year`, `:month`,\n`:day` and optionally `:calendar`.\n\n`Cldr.Date` provides support for the built-in calendar\n`Calendar.ISO` or any calendars defined with\n[ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars).\n\nCLDR provides standard format strings for `t:Date.t/0` which\nare represented by the formats `:short`, `:medium`, `:long`\nand `:full`.  This abstraction allows for locale-independent\nformatting since each locale and calendar may define the underlying\nformat string as appropriate.","ref":"Cldr.Date.html"},{"type":"function","title":"Cldr.Date.available_formats/3","doc":"Returns a map of the available date formats for a\ngiven locale and calendar.","ref":"Cldr.Date.html#available_formats/3"},{"type":"function","title":"Arguments - Cldr.Date.available_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.Date.html#available_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.Date.available_formats/3","doc":"iex> Cldr.Date.available_formats(:en)\n    {:ok,\n     %{\n       d: \"d\",\n       y: \"y\",\n       E: \"ccc\",\n       M: \"L\",\n       MMMEd: \"E, MMM d\",\n       Ed: \"d E\",\n       Md: \"M/d\",\n       GyMMMd: \"MMM d, y G\",\n       Gy: \"y G\",\n       GyMMM: \"MMM y G\",\n       GyMMMEd: \"E, MMM d, y G\",\n       MMMd: \"MMM d\",\n       GyMd: \"M/d/y G\",\n       MMMMd: \"MMMM d\",\n       MEd: \"E, M/d\",\n       MMM: \"LLL\",\n       yMd: \"M/d/y\",\n       yMMMd: \"MMM d, y\",\n       yMMMM: \"MMMM y\",\n       yMMM: \"MMM y\",\n       yMMMEd: \"E, MMM d, y\",\n       yMEd: \"E, M/d/y\",\n       yM: \"M/y\",\n       yQQQQ: \"QQQQ y\",\n       yQQQ: \"QQQ y\",\n       yw: %{\n         other: \"'week' w 'of' Y\",\n         pluralize: :week_of_year,\n         one: \"'week' w 'of' Y\"\n       },\n       MMMMW: %{\n         other: \"'week' W 'of' MMMM\",\n         pluralize: :week_of_month,\n         one: \"'week' W 'of' MMMM\"\n       }\n     }}","ref":"Cldr.Date.html#available_formats/3-examples"},{"type":"function","title":"Cldr.Date.formats/3","doc":"Returns a map of the standard date formats for a given\nlocale and calendar.","ref":"Cldr.Date.html#formats/3"},{"type":"function","title":"Arguments - Cldr.Date.formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.Date.html#formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.Date.formats/3","doc":"iex> Cldr.Date.formats(:en, :gregorian, MyApp.Cldr)\n    {:ok, %Cldr.Date.Formats{\n      full: \"EEEE, MMMM d, y\",\n      long: \"MMMM d, y\",\n      medium: \"MMM d, y\",\n      short: \"M/d/yy\"\n    }}\n\n    iex> Cldr.Date.formats(:en, :buddhist, MyApp.Cldr)\n    {:ok, %Cldr.Date.Formats{\n      full: \"EEEE, MMMM d, y G\",\n      long: \"MMMM d, y G\",\n      medium: \"MMM d, y G\",\n      short: \"M/d/y GGGGG\"\n    }}","ref":"Cldr.Date.html#formats/3-examples"},{"type":"macro","title":"Cldr.Date.is_full_date/1","doc":"","ref":"Cldr.Date.html#is_full_date/1"},{"type":"function","title":"Cldr.Date.to_string/3","doc":"Formats a date according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html).","ref":"Cldr.Date.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Date.to_string/3","doc":"* `date` is a `t:Date.t/0` struct or any map that contains one or more\n  of the keys `:year`, `:month`, `:day` and optionally `:calendar`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.Date.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Date.to_string/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full`, or a format ID\n  or a format string. The default is `:medium` for full dates (that is,\n  dates having `:year`, `:month`, `:day` and `:calendar` fields). The\n  default for partial dates is to derive a candidate format ID from the date and\n  find the best match from the formats returned by\n  `Cldr.Date.available_formats/3`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `:locale:` any locale returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted date digits\n  should be transliterated.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.Date.available_formats/3`\n  to see which formats have these variants. Currently no date-specific\n  formats have such variants but they may in the future.\n\n* `:era` which, if set to `:variant`, will use a variant for the era if one\n  is available in the requested locale. In the `:en` locale, for example, `era: :variant`\n  will return `CE` instead of `AD` and `BCE` instead of `BC`.","ref":"Cldr.Date.html#to_string/3-options"},{"type":"function","title":"Returns - Cldr.Date.to_string/3","doc":"* `{:ok, formatted_string}` or\n\n* `{:error, reason}`","ref":"Cldr.Date.html#to_string/3-returns"},{"type":"function","title":"Examples - Cldr.Date.to_string/3","doc":"# Full dates have the default format `:medium`\n    iex> Cldr.Date.to_string(~D[2017-07-10], MyApp.Cldr, locale: :en)\n    {:ok, \"Jul 10, 2017\"}\n\n    iex> Cldr.Date.to_string(~D[2017-07-10], MyApp.Cldr, format: :medium, locale: :en)\n    {:ok, \"Jul 10, 2017\"}\n\n    iex> Cldr.Date.to_string(~D[2017-07-10], MyApp.Cldr, format: :full, locale: :en)\n    {:ok, \"Monday, July 10, 2017\"}\n\n    iex> Cldr.Date.to_string(~D[2017-07-10], MyApp.Cldr, format: :short, locale: :en)\n    {:ok, \"7/10/17\"}\n\n    iex> Cldr.Date.to_string(~D[2017-07-10], MyApp.Cldr, format: :short, locale: \"fr\")\n    {:ok, \"10/07/2017\"}\n\n    # A partial date with a derived \"best match\" format\n    iex> Cldr.Date.to_string(%{year: 2024, month: 6}, MyApp.Cldr, locale: \"fr\")\n    {:ok, \"06/2024\"}\n\n    # A partial date with a best match CLDR-defined format\n    iex> Cldr.Date.to_string(%{year: 2024, month: 6}, MyApp.Cldr, format: :yMMM, locale: \"fr\")\n    {:ok, \"juin 2024\"}\n\n    # Sometimes the available date fields can't be mapped to an available\n    # CLDR-defined format.\n    iex> Cldr.Date.to_string(%{year: 2024, day: 3}, MyApp.Cldr, locale: \"fr\")\n    {:error,\n     {Cldr.DateTime.UnresolvedFormat, \"No available format resolved for :dy\"}}","ref":"Cldr.Date.html#to_string/3-examples"},{"type":"function","title":"Cldr.Date.to_string!/3","doc":"Formats a date according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html)\nor raises an exception.","ref":"Cldr.Date.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Date.to_string!/3","doc":"* `date` is a `t:Date.t/0` struct or any map that contains one or more\n  of the keys `:year`, `:month`, `:day` and optionally `:calendar`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.Date.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Date.to_string!/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full`, or a format ID\n  or a format string. The default is `:medium` for full dates (that is,\n  dates having `:year`, `:month`, `:day` and `:calendar` fields). The\n  default for partial dates is to derive a candidate format from the date and\n  find the best match from the formats returned by\n  `Cldr.Date.available_formats/3`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted date digits should\n  be transliterated.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.Date.available_formats/3`\n  to see which formats have these variants. Currently no date-specific\n  formats have such variants but they may in the future.\n\n* `:era` which, if set to `:variant`, will use a variant for the era if one\n  is available in the requested locale. In the `:en` locale, for example, `era: :variant`\n  will return `CE` instead of `AD` and `BCE` instead of `BC`.","ref":"Cldr.Date.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Date.to_string!/3","doc":"* `formatted_date` or\n\n* raises an exception.","ref":"Cldr.Date.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.Date.to_string!/3","doc":"iex> Cldr.Date.to_string!(~D[2017-07-10], MyApp.Cldr, locale: :en)\n    \"Jul 10, 2017\"\n\n    iex> Cldr.Date.to_string!(~D[2017-07-10], MyApp.Cldr, format: :medium, locale: :en)\n    \"Jul 10, 2017\"\n\n    iex> Cldr.Date.to_string!(~D[2017-07-10], MyApp.Cldr, format: :full, locale: :en)\n    \"Monday, July 10, 2017\"\n\n    iex> Cldr.Date.to_string!(~D[2017-07-10], MyApp.Cldr, format: :short, locale: :en)\n    \"7/10/17\"\n\n    iex> Cldr.Date.to_string!(~D[2017-07-10], MyApp.Cldr, format: :short, locale: \"fr\")\n    \"10/07/2017\"\n\n    # A partial date with a derived \"best match\" format\n    iex> Cldr.Date.to_string!(%{year: 2024, month: 6}, MyApp.Cldr, locale: \"fr\")\n    \"06/2024\"\n\n    # A partial date with a best match CLDR-defined format\n    iex> Cldr.Date.to_string!(%{year: 2024, month: 6}, MyApp.Cldr, format: :yMMM, locale: \"fr\")\n    \"juin 2024\"","ref":"Cldr.Date.html#to_string!/3-examples"},{"type":"module","title":"Cldr.DateTime","doc":"Provides localization and formatting of a datetime.\n\nA date time is any `t:DateTime.t/0` or `t:NaiveDateTime.t/0`\nstruct or any map that contains one or more of the keys `:year`, `:month`, `:day`,\n`:hour`, `:minute` and `:second` or `:microsecond` with optional `:time_zone`, `:zone_abbr`,\n`:utc_offset`, `:std_offset` and `:calendar` fields.\n\n`Cldr.DateTime` provides support for the built-in calendar\n`Calendar.ISO` or any calendars defined with\n[ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars)\n\nCLDR provides standard format strings for `t:DateTime.t/0` which\nare represented by the names `:short`, `:medium`, `:long`\nand `:full`.  This allows for locale-independent\nformatting since each locale and calendar will define the underlying\nformat string as appropriate.","ref":"Cldr.DateTime.html"},{"type":"macro","title":"Cldr.DateTime.has_date/1","doc":"Guards whether the given datetime has components of\na date.","ref":"Cldr.DateTime.html#has_date/1"},{"type":"macro","title":"Cldr.DateTime.has_date_and_time/1","doc":"Guard whether the given datetime has components of\nboth a date and a time.","ref":"Cldr.DateTime.html#has_date_and_time/1"},{"type":"macro","title":"Cldr.DateTime.has_time/1","doc":"Guards whether the given datetime has components of\na time.","ref":"Cldr.DateTime.html#has_time/1"},{"type":"macro","title":"Cldr.DateTime.is_any_date_time/1","doc":"Indicates if a given map fulfills the requirements\nfor a naive date time or date time.","ref":"Cldr.DateTime.html#is_any_date_time/1"},{"type":"macro","title":"Cldr.DateTime.is_date_time/1","doc":"Indicates if a given map fulfills the requirements\nfor a date time.","ref":"Cldr.DateTime.html#is_date_time/1"},{"type":"macro","title":"Cldr.DateTime.is_naive_date_time/1","doc":"Indicates if a given map fulfills the requirements\nfor a naive date time.","ref":"Cldr.DateTime.html#is_naive_date_time/1"},{"type":"function","title":"Cldr.DateTime.to_string/3","doc":"Formats a DateTime according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html).","ref":"Cldr.DateTime.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.DateTime.to_string/3","doc":"* `datetime` is a `t:DateTime.t/0` or `t:NaiveDateTime.t/0` struct or any map that contains\n  one or more of the keys `:year`, `:month`, `:day`, `:hour`, `:minute` and `:second` or\n  `:microsecond` with optional `:time_zone`, `:zone_abbr`, `:utc_offset`, `:std_offset`\n  and `:calendar` fields.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.DateTime.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.DateTime.to_string/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full` or a format string or\n  any of the keys in the map returned by `Cldr.DateTime.Format.date_time_formats/3`.\n  The default is `:medium`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `:date_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the date part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:date_format` is not specified\n  then the date format is defined by the `:format` option.\n\n* `:time_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the time part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:time_format` is not specified\n  then the time format is defined by the `:format` option.\n\n* `:style` is either `:at` or `:default`. When set to `:at` the datetime may\n  be formatted with a localised string representing `  at  ` if such\n  a format exists. See `Cldr.DateTime.Format.date_time_at_formats/2`.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.DateTime.Format.date_time_available_formats/3`\n  to see which formats have these variants.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted datetime digits should\n  be transliterated.\n\n* `:era` which, if set to `:variant`, will use a variant for the era if one\n  is available in the requested locale. In the `:en` locale, for example, `era: :variant`\n  will return `CE` instead of `AD` and `BCE` instead of `BC`.\n\n* `period: :variant` will use a variant for the time period and flexible time period if\n  one is available in the locale.  For example, in the `:en` locale `period: :variant` will\n  return \"pm\" instead of \"PM\".","ref":"Cldr.DateTime.html#to_string/3-options"},{"type":"function","title":"Notes - Cldr.DateTime.to_string/3","doc":"* If the provided `datetime` contains only date fields, the call is delegated to\n  `Cldr.Date.to_string/2`.\n\n* If the provided `datetime` contains only time fields, the call is delegated to\n  `Cldr.Time.to_string/2`.","ref":"Cldr.DateTime.html#to_string/3-notes"},{"type":"function","title":"Returns - Cldr.DateTime.to_string/3","doc":"* `{:ok, formatted_datetime}` or\n\n* `{:error, reason}`","ref":"Cldr.DateTime.html#to_string/3-returns"},{"type":"function","title":"Examples - Cldr.DateTime.to_string/3","doc":"iex> {:ok, date_time} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], \"Etc/UTC\")\n    iex> Cldr.DateTime.to_string(date_time)\n    {:ok, \"Jan 1, 2000, 11:59:59 PM\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, locale: :en)\n    {:ok, \"Jan 1, 2000, 11:59:59 PM\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :long, locale: :en)\n    {:ok, \"January 1, 2000, 11:59:59 PM UTC\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :hms, locale: :en)\n    {:ok, \"11:59:59 PM\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, locale: :en)\n    {:ok, \"Saturday, January 1, 2000, 11:59:59 PM GMT\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, locale: :fr)\n    {:ok, \"samedi 1 janvier 2000, 23:59:59 UTC\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, style: :at, locale: :en)\n    {:ok, \"Saturday, January 1, 2000 at 11:59:59 PM GMT\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, style: :at, locale: :fr)\n    {:ok, \"samedi 1 janvier 2000 à 23:59:59 UTC\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :MMMMW, locale: :fr)\n    {:ok, \"semaine 1 (janvier)\"}\n    iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :yw, locale: :fr)\n    {:ok, \"semaine 1 de 2000\"}","ref":"Cldr.DateTime.html#to_string/3-examples"},{"type":"function","title":"Cldr.DateTime.to_string!/3","doc":"Formats a DateTime according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html)\nreturning a formatted string or raising on error.","ref":"Cldr.DateTime.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.DateTime.to_string!/3","doc":"* `datetime` is a `t:DateTime.t/0` or `t:NaiveDateTime.t/0` struct or any map that contains\n  one or more of the keys `:year`, `:month`, `:day`, `:hour`, `:minute` and `:second` or\n  `:microsecond` with optional `:time_zone`, `:zone_abbr`, `:utc_offset`, `:std_offset`\n  and `:calendar` fields.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.DateTime.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.DateTime.to_string!/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full` or a format string or\n  any of the keys returned by `Cldr.DateTime.Format.date_time_formats/3`.\n  The default is `:medium`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `:style` is either `:at` or `:default`. When set to `:at` the datetime may\n  be formatted with a localised string representing `  at  ` if such\n  a format exists. See `Cldr.DateTime.Format.date_time_at_formats/2`.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of datetime\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.DateTime.Format.date_time_available_formats/2`\n  to see which formats have these variants.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted datetime digits should\n  be transliterated.\n\n* `:era` which, if set to `:variant`, will use a variant for the era if one\n  is available in the requested locale. In the `:en` locale, for example, `era: :variant`\n  will return `CE` instead of `AD` and `BCE` instead of `BC`.\n\n* `period: :variant` will use a variant for the time period and flexible time period if\n  one is available in the locale.  For example, in the `:en` locale `period: :variant` will\n  return \"pm\" instead of \"PM\".","ref":"Cldr.DateTime.html#to_string!/3-options"},{"type":"function","title":"Notes - Cldr.DateTime.to_string!/3","doc":"* If the provided `datetime` contains only date fields, the call is delegated to\n  `Cldr.Date.to_string/2`.\n\n* If the provided `datetime` contains only time fields, the call is delegated to\n  `Cldr.Time.to_string/2`.","ref":"Cldr.DateTime.html#to_string!/3-notes"},{"type":"function","title":"Returns - Cldr.DateTime.to_string!/3","doc":"* `formatted_datetime` or\n\n* raises an exception","ref":"Cldr.DateTime.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.DateTime.to_string!/3","doc":"iex> {:ok, date_time} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], \"Etc/UTC\")\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, locale: :en)\n    \"Jan 1, 2000, 11:59:59 PM\"\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :long, locale: :en)\n    \"January 1, 2000, 11:59:59 PM UTC\"\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :full, locale: :en)\n    \"Saturday, January 1, 2000, 11:59:59 PM GMT\"\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :full, locale: :fr)\n    \"samedi 1 janvier 2000, 23:59:59 UTC\"\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :MMMMW, locale: :fr)\n    \"semaine 1 (janvier)\"\n    iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :yw, locale: :fr)\n    \"semaine 1 de 2000\"","ref":"Cldr.DateTime.html#to_string!/3-examples"},{"type":"module","title":"Cldr.DateTime.Relative","doc":"Functions to support the string formatting of relative time/datetime numbers.\n\nThis module provides formatting of numbers (as integers, floats, Dates or DateTimes)\nas \"ago\" or \"in\" with an appropriate time unit.  For example, \"2 days ago\" or\n\"in 10 seconds\"","ref":"Cldr.DateTime.Relative.html"},{"type":"function","title":"Cldr.DateTime.Relative.known_styles/0","doc":"","ref":"Cldr.DateTime.Relative.html#known_styles/0"},{"type":"function","title":"Cldr.DateTime.Relative.known_units/0","doc":"Returns a list of the valid unit keys for `to_string/2`","ref":"Cldr.DateTime.Relative.html#known_units/0"},{"type":"function","title":"Example - Cldr.DateTime.Relative.known_units/0","doc":"iex> Cldr.DateTime.Relative.known_units()\n    [:day, :fri, :hour, :minute, :mon, :month, :quarter, :sat, :second,\n    :sun, :thu, :tue, :wed, :week, :year]","ref":"Cldr.DateTime.Relative.html#known_units/0-example"},{"type":"function","title":"Cldr.DateTime.Relative.scale_relative/2","doc":"Calculates the time span in the given `unit` from the time given in seconds.","ref":"Cldr.DateTime.Relative.html#scale_relative/2"},{"type":"function","title":"Examples - Cldr.DateTime.Relative.scale_relative/2","doc":"iex> Cldr.DateTime.Relative.scale_relative(1234, :second)\n    1234\n\n    iex> Cldr.DateTime.Relative.scale_relative(1234, :minute)\n    21\n\n    iex> Cldr.DateTime.Relative.scale_relative(1234, :hour)\n    0","ref":"Cldr.DateTime.Relative.html#scale_relative/2-examples"},{"type":"function","title":"Cldr.DateTime.Relative.to_string/3","doc":"Returns a `{:ok, string}` representing a relative time (ago, in) for a given\nnumber, Date or Datetime.  Returns `{:error, reason}` when errors are detected.\n\n* `relative` is a number or Date/Datetime representing the time distance from `now` or from\n  `options[:relative_to]`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.\n\n* `options` is a `Keyword` list of options which are:","ref":"Cldr.DateTime.Relative.html#to_string/3"},{"type":"function","title":"Options - Cldr.DateTime.Relative.to_string/3","doc":"* `:locale` is the locale in which the binary is formatted.\n  The default is `Cldr.get_locale/0`\n\n* `:format` is the format of the binary.  Format may be `:default`, `:narrow` or `:short`.\n\n* `:unit` is the time unit for the formatting.  The allowable units are `:second`, `:minute`,\n  `:hour`, `:day`, `:week`, `:month`, `:year`, `:mon`, `:tue`, `:wed`, `:thu`, `:fri`, `:sat`,\n  `:sun`, `:quarter`.\n\n* `:relative_to` is the baseline `t:Date/0` or `t:Datetime.t/0` from which the difference\n  from `relative` is calculated when `relative` is a Date or a DateTime. The default for\n  a `t:Date.t/0` is `Date.utc_today/0`, for a `t:DateTime.t/0` it is `DateTime.utc_now/0`.","ref":"Cldr.DateTime.Relative.html#to_string/3-options"},{"type":"function","title":"Notes - Cldr.DateTime.Relative.to_string/3","doc":"When `options[:unit]` is not specified, `Cldr.DateTime.Relative.to_string/2`\nattempts to identify the appropriate unit based upon the magnitude of `relative`.\n\nFor example, given a parameter of less than `60`, then `to_string/2` will assume\n`:seconds` as the unit.  See `unit_from_relative_time/1`.","ref":"Cldr.DateTime.Relative.html#to_string/3-notes"},{"type":"function","title":"Examples - Cldr.DateTime.Relative.to_string/3","doc":"iex> Cldr.DateTime.Relative.to_string(-1, MyApp.Cldr)\n    {:ok, \"1 second ago\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1, MyApp.Cldr)\n    {:ok, \"in 1 second\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1, MyApp.Cldr, unit: :day)\n    {:ok, \"tomorrow\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1, MyApp.Cldr, unit: :day, locale: \"fr\")\n    {:ok, \"demain\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1, MyApp.Cldr, unit: :day, format: :narrow)\n    {:ok, \"tomorrow\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1234, MyApp.Cldr, unit: :year)\n    {:ok, \"in 1,234 years\"}\n\n    iex> Cldr.DateTime.Relative.to_string(1234, MyApp.Cldr, unit: :year, locale: \"fr\")\n    {:ok, \"dans 1 234 ans\"}\n\n    iex> Cldr.DateTime.Relative.to_string(31, MyApp.Cldr)\n    {:ok, \"in 31 seconds\"}\n\n    iex> Cldr.DateTime.Relative.to_string(~D[2017-04-29], MyApp.Cldr, relative_to: ~D[2017-04-26])\n    {:ok, \"in 3 days\"}\n\n    iex> Cldr.DateTime.Relative.to_string(310, MyApp.Cldr, format: :short, locale: \"fr\")\n    {:ok, \"dans 5 min\"}\n\n    iex> Cldr.DateTime.Relative.to_string(310, MyApp.Cldr, format: :narrow, locale: \"fr\")\n    {:ok, \"+5 min\"}\n\n    iex> Cldr.DateTime.Relative.to_string 2, MyApp.Cldr, unit: :wed, format: :short, locale: \"en\"\n    {:ok, \"in 2 Wed.\"}\n\n    iex> Cldr.DateTime.Relative.to_string 1, MyApp.Cldr, unit: :wed, format: :short\n    {:ok, \"next Wed.\"}\n\n    iex> Cldr.DateTime.Relative.to_string -1, MyApp.Cldr, unit: :wed, format: :short\n    {:ok, \"last Wed.\"}\n\n    iex> Cldr.DateTime.Relative.to_string -1, MyApp.Cldr, unit: :wed\n    {:ok, \"last Wednesday\"}\n\n    iex> Cldr.DateTime.Relative.to_string -1, MyApp.Cldr, unit: :quarter\n    {:ok, \"last quarter\"}\n\n    iex> Cldr.DateTime.Relative.to_string -1, MyApp.Cldr, unit: :mon, locale: \"fr\"\n    {:ok, \"lundi dernier\"}\n\n    iex> Cldr.DateTime.Relative.to_string(~D[2017-04-29], MyApp.Cldr, unit: :ziggeraut)\n    {:error, {Cldr.DateTime.UnknownTimeUnit,\n     \"Unknown time unit :ziggeraut.  Valid time units are [:day, :fri, :hour, :minute, :mon, :month, :quarter, :sat, :second, :sun, :thu, :tue, :wed, :week, :year]\"}}","ref":"Cldr.DateTime.Relative.html#to_string/3-examples"},{"type":"function","title":"Cldr.DateTime.Relative.to_string!/3","doc":"Returns a string representing a relative time (ago, in) for a given\nnumber, Date or Datetime or raises an exception on error.","ref":"Cldr.DateTime.Relative.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Relative.to_string!/3","doc":"* `relative` is a number or Date/Datetime representing the time distance from `now` or from\n  options[:relative_to].\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.\n\n* `options` is a `Keyword` list of options.","ref":"Cldr.DateTime.Relative.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.DateTime.Relative.to_string!/3","doc":"* `:locale` is the locale in which the binary is formatted.\n  The default is `Cldr.get_locale/0`.\n\n* `:format` is the format of the binary.  Format may be `:default`, `:narrow` or `:short`.\n  The default is `:default`.\n\n* `:unit` is the time unit for the formatting.  The allowable units are `:second`, `:minute`,\n  `:hour`, `:day`, `:week`, `:month`, `:year`, `:mon`, `:tue`, `:wed`, `:thu`, `:fri`, `:sat`,\n  `:sun`, `:quarter`.\n\n* `:relative_to` is the baseline `t:Date/0` or `t:Datetime.t/0` from which the difference\n  from `relative` is calculated when `relative` is a Date or a DateTime. The default for\n  a `t:Date.t/0` is `Date.utc_today/0`, for a `t:DateTime.t/0` it is `DateTime.utc_now/0`.\n\nSee `to_string/3`","ref":"Cldr.DateTime.Relative.html#to_string!/3-options"},{"type":"function","title":"Cldr.DateTime.Relative.unit_from_relative_time/1","doc":"Returns an estimate of the appropriate time unit for an integer of a given\nmagnitude of seconds.","ref":"Cldr.DateTime.Relative.html#unit_from_relative_time/1"},{"type":"function","title":"Examples - Cldr.DateTime.Relative.unit_from_relative_time/1","doc":"iex> Cldr.DateTime.Relative.unit_from_relative_time(1234)\n    :minute\n\n    iex> Cldr.DateTime.Relative.unit_from_relative_time(12345)\n    :hour\n\n    iex> Cldr.DateTime.Relative.unit_from_relative_time(123456)\n    :day\n\n    iex> Cldr.DateTime.Relative.unit_from_relative_time(1234567)\n    :week\n\n    iex> Cldr.DateTime.Relative.unit_from_relative_time(12345678)\n    :month\n\n    iex> Cldr.DateTime.Relative.unit_from_relative_time(123456789)\n    :year","ref":"Cldr.DateTime.Relative.html#unit_from_relative_time/1-examples"},{"type":"module","title":"Cldr.Time","doc":"Provides localization and formatting of a time.\n\nA time is any `t:Time.t/0` struct or any map with one or more of\nthe keys `:hour`, `:minute`, `:second` and optionally `:time_zone`,\n`:zone_abbr`, `:utc_offset`, `:std_offset` and `:microsecond`.\n\n`Cldr.Time` provides support for the built-in calendar\n`Calendar.ISO` or any calendars defined with\n[ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars)\n\nCLDR provides standard format strings for `Time` which\nare represented by the names `:short`, `:medium`, `:long`\nand `:full`.  This allows for locale-independent\nformatting since each locale may define the underlying\nformat string as appropriate.","ref":"Cldr.Time.html"},{"type":"function","title":"Cldr.Time.available_formats/3","doc":"Returns a map of the available date formats for a\ngiven locale and calendar.","ref":"Cldr.Time.html#available_formats/3"},{"type":"function","title":"Arguments - Cldr.Time.available_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.Time.html#available_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.Time.available_formats/3","doc":"iex> Cldr.Time.available_formats(:en)\n    {:ok,\n     %{\n       h: %{unicode: \"h a\", ascii: \"h a\"},\n       hms: %{unicode: \"h:mm:ss a\", ascii: \"h:mm:ss a\"},\n       ms: \"mm:ss\",\n       H: \"HH\",\n       Hm: \"HH:mm\",\n       Hms: \"HH:mm:ss\",\n       Hmsv: \"HH:mm:ss v\",\n       Hmv: \"HH:mm v\",\n       hm: %{unicode: \"h:mm a\", ascii: \"h:mm a\"},\n       hmsv: %{unicode: \"h:mm:ss a v\", ascii: \"h:mm:ss a v\"},\n       hmv: %{unicode: \"h:mm a v\", ascii: \"h:mm a v\"}\n     }}","ref":"Cldr.Time.html#available_formats/3-examples"},{"type":"function","title":"Cldr.Time.formats/3","doc":"Returns a map of the standard time formats for a given\nlocale and calendar.","ref":"Cldr.Time.html#formats/3"},{"type":"function","title":"Arguments - Cldr.Time.formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.Time.html#formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.Time.formats/3","doc":"iex> Cldr.Time.formats(:en, :gregorian, MyApp.Cldr)\n    {:ok,\n     %Cldr.Time.Formats{\n       short: \"h:mm a\",\n       medium: \"h:mm:ss a\",\n       long: \"h:mm:ss a z\",\n       full: \"h:mm:ss a zzzz\"\n     }}\n\n    iex> Cldr.Time.formats(:en, :buddhist, MyApp.Cldr)\n    {:ok,\n     %Cldr.Time.Formats{\n       short: \"h:mm a\",\n       medium: \"h:mm:ss a\",\n       long: \"h:mm:ss a z\",\n       full: \"h:mm:ss a zzzz\"\n     }}","ref":"Cldr.Time.html#formats/3-examples"},{"type":"function","title":"Cldr.Time.hour_format_from_locale/1","doc":"Return the preferred time format for a locale.","ref":"Cldr.Time.html#hour_format_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Time.hour_format_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`","ref":"Cldr.Time.html#hour_format_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Time.hour_format_from_locale/1","doc":"* The hour format as an atom to be used for localization purposes. The\n  return value is used as a function name in `Cldr.DateTime.Formatter`","ref":"Cldr.Time.html#hour_format_from_locale/1-returns"},{"type":"function","title":"Notes - Cldr.Time.hour_format_from_locale/1","doc":"* The `hc` key of the `u` extension is honoured and will\n  override the default preferences for a locale or territory.\n  See the last example below.\n\n* Different locales and territories present the hour\n  of day in different ways. These are represented\n  in `Cldr.DateTime.Formatter` in the following way:\n\n| Symbol  | Midn.  |  Morning  | Noon  |  Afternoon | Midn. |\n| :----:  | :---:  | :-----:   | :--:  | :--------: | :---: |\n|   h     |  12    | 1...11    |  12   |   1...11   |  12   |\n|   K     |   0    | 1...11    |   0   |   1...11   |   0   |\n|   H     |   0    | 1...11    |  12   |  13...23   |   0   |\n|   k     |  24    | 1...11    |  12   |  13...23   |  24   |","ref":"Cldr.Time.html#hour_format_from_locale/1-notes"},{"type":"function","title":"Examples - Cldr.Time.hour_format_from_locale/1","doc":"iex> Cldr.Time.hour_format_from_locale(\"en-AU\")\n    :h12\n\n    iex> Cldr.Time.hour_format_from_locale(\"fr\")\n    :h23\n\n    iex> Cldr.Time.hour_format_from_locale(\"fr-u-hc-h12\")\n    :h12","ref":"Cldr.Time.html#hour_format_from_locale/1-examples"},{"type":"function","title":"Cldr.Time.hour_format_from_locale/2","doc":"","ref":"Cldr.Time.html#hour_format_from_locale/2"},{"type":"macro","title":"Cldr.Time.is_full_time/1","doc":"","ref":"Cldr.Time.html#is_full_time/1"},{"type":"function","title":"Cldr.Time.to_string/3","doc":"Formats a time according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html).","ref":"Cldr.Time.html#to_string/3"},{"type":"function","title":"Returns - Cldr.Time.to_string/3","doc":"* `{:ok, formatted_time}` or\n\n* `{:error, reason}`.","ref":"Cldr.Time.html#to_string/3-returns"},{"type":"function","title":"Arguments - Cldr.Time.to_string/3","doc":"* `time` is a `t:Time.t/0` struct or any map that contains\n  one or more of the keys `:hour`, `:minute`, `:second` and optionally `:microsecond`,\n  `:time_zone`, `:zone_abbr`, `:utc_offset` and `:std_offset`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.Time.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Time.to_string/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full`, or a format id\n  or a format string. The default is `:medium` for full times (that is,\n  times having `:hour`, `:minute` and `:second` fields). The\n  default for partial times is to derive a candidate format from the time and\n  find the best match from the formats returned by\n  `Cldr.Time.available_formats/3`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `:locale` any locale returned by `Cldr.known_locale_names/1`.  The default is\n  `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted date digits should\n  be transliterated.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.Time.available_formats/3`\n  to see which formats have these variants.\n\n* `period: :variant` will use a variant for the time period and flexible time period if\n  one is available in the locale.  For example, in the `:en` locale, `period: :variant` will\n  return \"pm\" instead of \"PM\".","ref":"Cldr.Time.html#to_string/3-options"},{"type":"function","title":"Examples - Cldr.Time.to_string/3","doc":"iex> Cldr.Time.to_string(~T[07:35:13.215217], MyApp.Cldr)\n    {:ok, \"7:35:13 AM\"}\n\n    iex> Cldr.Time.to_string(~T[07:35:13.215217], MyApp.Cldr, format: :short)\n    {:ok, \"7:35 AM\"}\n\n    iex> Cldr.Time.to_string(~T[07:35:13.215217], MyApp.Cldr, format: :short, period: :variant)\n    {:ok, \"7:35 am\"}\n\n    iex> Cldr.Time.to_string(~T[07:35:13.215217], MyApp.Cldr, format: :medium, locale: \"fr\")\n    {:ok, \"07:35:13\"}\n\n    iex> Cldr.Time.to_string(~T[07:35:13.215217], MyApp.Cldr, format: :medium)\n    {:ok, \"7:35:13 AM\"}\n\n    iex> {:ok, datetime} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], \"Etc/UTC\")\n    iex> Cldr.Time.to_string datetime, MyApp.Cldr, format: :long\n    {:ok, \"11:59:59 PM UTC\"}\n\n    # A partial time with a best match CLDR-defined format\n    iex> Cldr.Time.to_string(%{hour: 23, minute: 11})\n    {:ok, \"11:11 PM\"}\n\n    # Sometimes the available time fields can't be mapped to an available\n    # CLDR-defined format.\n    iex> Cldr.Time.to_string(%{minute: 11})\n    {:error,\n     {Cldr.DateTime.UnresolvedFormat, \"No available format resolved for :m\"}}","ref":"Cldr.Time.html#to_string/3-examples"},{"type":"function","title":"Cldr.Time.to_string!/3","doc":"Formats a time according to a format string\nas defined in CLDR and described in [TR35](http://unicode.org/reports/tr35/tr35-dates.html).","ref":"Cldr.Time.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Time.to_string!/3","doc":"* `time` is a `t:Time.t/0` struct or any map that contains\n  one or more of the keys `:hour`, `:minute`, `:second` and optionally `:microsecond`,\n  `:time_zone`, `:zone_abbr`, `:utc_offset` and `:std_offset`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options for formatting.","ref":"Cldr.Time.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Time.to_string!/3","doc":"* `:format` is one of `:short`, `:medium`, `:long`, `:full`, or a format id\n  or a format string. The default is `:medium` for full times (that is,\n  times having `:hour`, `:minute` and `:second` fields). The\n  default for partial times is to derive a candidate format from the time and\n  find the best match from the formats returned by\n  `Cldr.Time.available_formats/3`. See [here](README.md#date-time-and-datetime-localization-formats)\n  for more information about specifying formats.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `:number_system` a number system into which the formatted time digits should\n  be transliterated.\n\n* `:prefer` is either `:unicode` (the default) or `:ascii`. A small number of\n  formats have two variants - one using Unicode spaces (typically non-breaking space) and\n  another using only ASCII whitespace. The `:ascii` format is primarily to support legacy\n  use cases and is not recommended. See `Cldr.Time.available_formats/3`\n  to see which formats have these variants.\n\n* `period: :variant` will use a variant for the time period and flexible time period if\n  one is available in the locale.  For example, in the `:en` locale `period: :variant` will\n  return \"pm\" instead of \"PM\"","ref":"Cldr.Time.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Time.to_string!/3","doc":"* `formatted_time_string` or\n\n* raises an exception.","ref":"Cldr.Time.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.Time.to_string!/3","doc":"iex> Cldr.Time.to_string!(~T[07:35:13.215217], MyApp.Cldr)\n    \"7:35:13 AM\"\n\n    iex> Cldr.Time.to_string!(~T[07:35:13.215217], MyApp.Cldr, format: :short)\n    \"7:35 AM\"\n\n    iex> Cldr.Time.to_string!(~T[07:35:13.215217], MyApp.Cldr, format: :short, period: :variant)\n    \"7:35 am\"\n\n    iex> Cldr.Time.to_string!(~T[07:35:13.215217], MyApp.Cldr, format: :medium, locale: \"fr\")\n    \"07:35:13\"\n\n    iex> Cldr.Time.to_string!(~T[07:35:13.215217], MyApp.Cldr, format: :medium)\n    \"7:35:13 AM\"\n\n    iex> {:ok, datetime} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], \"Etc/UTC\")\n    iex> Cldr.Time.to_string!(datetime, MyApp.Cldr, format: :long)\n    \"11:59:59 PM UTC\"\n\n    # A partial time with a best match CLDR-defined format\n    iex> Cldr.Time.to_string!(%{hour: 23, minute: 11})\n    \"11:11 PM\"","ref":"Cldr.Time.html#to_string!/3-examples"},{"type":"module","title":"Cldr.Date.Interval","doc":"Interval formats allow for software to format intervals like \"Jan 10-12, 2008\" as a\nshorter and more natural format than \"Jan 10, 2008 - Jan 12, 2008\". They are designed\nto take a start and end date, time or datetime plus a formatting pattern\nand use that information to produce a localized format.\n\nSee `Cldr.Interval.to_string/3` and `Cldr.Date.Interval.to_string/3`.","ref":"Cldr.Date.Interval.html"},{"type":"function","title":"Cldr.Date.Interval.greatest_difference/2","doc":"Returns the format code representing the date or\ntime unit that is the greatest difference between\ntwo dates.","ref":"Cldr.Date.Interval.html#greatest_difference/2"},{"type":"function","title":"Arguments - Cldr.Date.Interval.greatest_difference/2","doc":"* `from` is any `t:Date.t/0`.\n\n* `to` is any `t:Date.t/0`.","ref":"Cldr.Date.Interval.html#greatest_difference/2-arguments"},{"type":"function","title":"Returns - Cldr.Date.Interval.greatest_difference/2","doc":"* `{:ok, format_code}` where `format_code` is one of\n\n  * `:y` meaning that the greatest difference is in the year\n  * `:M` meaning that the greatest difference is in the month\n  * `:d` meaning that the greatest difference is in the day\n\n* `{:error, :no_practical_difference}`","ref":"Cldr.Date.Interval.html#greatest_difference/2-returns"},{"type":"function","title":"Example - Cldr.Date.Interval.greatest_difference/2","doc":"iex> Cldr.Date.Interval.greatest_difference ~D[2022-04-22], ~D[2022-04-23]\n    {:ok, :d}\n\n    iex> Cldr.Date.Interval.greatest_difference ~D[2022-04-22], ~D[2022-04-22]\n    {:error, :no_practical_difference}","ref":"Cldr.Date.Interval.html#greatest_difference/2-example"},{"type":"function","title":"Cldr.Date.Interval.to_string/3","doc":"Returns a `Date.Range` or `CalendarInterval` as\na localised string.","ref":"Cldr.Date.Interval.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Date.Interval.to_string/3","doc":"* `range` is either a `Date.Range.t` returned from `Date.range/2`\n  or a `CalendarInterval.t`\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date]`.","ref":"Cldr.Date.Interval.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Date.Interval.to_string/3","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:date`, `:month_and_day`, `:month`\n  and `:year_and_month`. The default is `:date`.\n\n* `:locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`\n\n* `:number_system` a number system into which the formatted date digits should\n  be transliterated","ref":"Cldr.Date.Interval.html#to_string/3-options"},{"type":"function","title":"Returns - Cldr.Date.Interval.to_string/3","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Date.Interval.html#to_string/3-returns"},{"type":"function","title":"Notes - Cldr.Date.Interval.to_string/3","doc":"* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(:en, :gregorian)`\n  where `\"en\"` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval.","ref":"Cldr.Date.Interval.html#to_string/3-notes"},{"type":"function","title":"Examples - Cldr.Date.Interval.to_string/3","doc":"iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-12-31]), MyApp.Cldr\n    {:ok, \"Jan 1 – Dec 31, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr\n    {:ok, \"Jan 1 – 12, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-12-01]), MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    {:ok, \"January – December 2020\"}\n\n    iex> use CalendarInterval\n    iex> Cldr.Date.Interval.to_string ~I\"2020-01/12\", MyApp.Cldr\n    {:ok, \"Jan 1 – Dec 31, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :short\n    {:ok, \"1/1/2020 – 1/12/2020\"}\n\n    iex> Cldr.Date.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long, locale: \"fr\"\n    {:ok, \"mer. 1 – dim. 12 janv. 2020\"}","ref":"Cldr.Date.Interval.html#to_string/3-examples"},{"type":"function","title":"Cldr.Date.Interval.to_string/4","doc":"Returns a localised string representing the formatted\ninterval formed by two dates.","ref":"Cldr.Date.Interval.html#to_string/4"},{"type":"function","title":"Arguments - Cldr.Date.Interval.to_string/4","doc":"* `from` is any map that conforms to the\n  `Calendar.date` type.\n\n* `to` is any map that conforms to the\n  `Calendar.date` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore an `Cldr` backend module\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date]`.\n\nEither `from` or `to` may also be `nil` in which case the\ninterval is formatted as an open interval with the non-nil\nside formatted as a standalone date.","ref":"Cldr.Date.Interval.html#to_string/4-arguments"},{"type":"function","title":"Options - Cldr.Date.Interval.to_string/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:date`, `:month_and_day`, `:month`\n  and `:year_and_month`. The default is `:date`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Date.Interval.html#to_string/4-options"},{"type":"function","title":"Returns - Cldr.Date.Interval.to_string/4","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Date.Interval.html#to_string/4-returns"},{"type":"function","title":"Notes - Cldr.Date.Interval.to_string/4","doc":"* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(:en, :gregorian)`\n  where `:en` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval.","ref":"Cldr.Date.Interval.html#to_string/4-notes"},{"type":"function","title":"Examples - Cldr.Date.Interval.to_string/4","doc":"iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-12-31], MyApp.Cldr\n    {:ok, \"Jan 1 – Dec 31, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n    {:ok, \"Jan 1 – 12, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-12-01], MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    {:ok, \"January – December 2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :short\n    {:ok, \"1/1/2020 – 1/12/2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], nil, MyApp.Cldr,\n    ...> format: :short\n    {:ok, \"1/1/20 –\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long, locale: \"fr\"\n    {:ok, \"mer. 1 – dim. 12 janv. 2020\"}\n\n    iex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long, locale: \"th\", number_system: :thai\n    {:ok, \"พ. ๑ ม.ค. – อา. ๑๒ ม.ค. ๒๐๒๐\"}","ref":"Cldr.Date.Interval.html#to_string/4-examples"},{"type":"function","title":"Cldr.Date.Interval.to_string!/3","doc":"Returns a `Date.Range` or `CalendarInterval` as\na localised string or raises an exception.","ref":"Cldr.Date.Interval.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Date.Interval.to_string!/3","doc":"* `range` is either a `Date.Range.t` returned from `Date.range/2`\n  or a `CalendarInterval.t`\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date]`.","ref":"Cldr.Date.Interval.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Date.Interval.to_string!/3","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:date`, `:month_and_day`, `:month`\n  and `:year_and_month`. The default is `:date`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Date.Interval.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Date.Interval.to_string!/3","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.Date.Interval.html#to_string!/3-returns"},{"type":"function","title":"Notes - Cldr.Date.Interval.to_string!/3","doc":"* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(:en, :gregorian)`\n  where `:en` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval.","ref":"Cldr.Date.Interval.html#to_string!/3-notes"},{"type":"function","title":"Examples - Cldr.Date.Interval.to_string!/3","doc":"iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-12-31]), MyApp.Cldr\n    \"Jan 1 – Dec 31, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr\n    \"Jan 1 – 12, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long\n    \"Wed, Jan 1 – Sun, Jan 12, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-12-01]), MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    \"January – December 2020\"\n\n    iex> use CalendarInterval\n    iex> Cldr.Date.Interval.to_string! ~I\"2020-01/12\", MyApp.Cldr\n    \"Jan 1 – Dec 31, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :short\n    \"1/1/2020 – 1/12/2020\"\n\n    iex> Cldr.Date.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long, locale: \"fr\"\n    \"mer. 1 – dim. 12 janv. 2020\"","ref":"Cldr.Date.Interval.html#to_string!/3-examples"},{"type":"function","title":"Cldr.Date.Interval.to_string!/4","doc":"Returns a localised string representing the formatted\ninterval formed by two dates or raises an\nexception.","ref":"Cldr.Date.Interval.html#to_string!/4"},{"type":"function","title":"Arguments - Cldr.Date.Interval.to_string!/4","doc":"* `from` is any map that conforms to the\n  `Calendar.date` type.\n\n* `to` is any map that conforms to the\n  `Calendar.date` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date]`.","ref":"Cldr.Date.Interval.html#to_string!/4-arguments"},{"type":"function","title":"Options - Cldr.Date.Interval.to_string!/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:date`, `:month_and_day`, `:month`\n  and `:year_and_month`. The default is `:date`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Date.Interval.html#to_string!/4-options"},{"type":"function","title":"Returns - Cldr.Date.Interval.to_string!/4","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.Date.Interval.html#to_string!/4-returns"},{"type":"function","title":"Notes - Cldr.Date.Interval.to_string!/4","doc":"* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(:en, :gregorian)`\n  where `:en` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval.","ref":"Cldr.Date.Interval.html#to_string!/4-notes"},{"type":"function","title":"Examples - Cldr.Date.Interval.to_string!/4","doc":"iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-12-31], MyApp.Cldr\n    \"Jan 1 – Dec 31, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n    \"Jan 1 – 12, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long\n    \"Wed, Jan 1 – Sun, Jan 12, 2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-12-01], MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    \"January – December 2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :short\n    \"1/1/2020 – 1/12/2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long, locale: \"fr\"\n    \"mer. 1 – dim. 12 janv. 2020\"\n\n    iex> Cldr.Date.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long, locale: \"th\", number_system: :thai\n    \"พ. ๑ ม.ค. – อา. ๑๒ ม.ค. ๒๐๒๐\"","ref":"Cldr.Date.Interval.html#to_string!/4-examples"},{"type":"module","title":"Cldr.DateTime.Interval","doc":"Interval formats allow for software to format intervals like \"Jan 10-12, 2008\" as a\nshorter and more natural format than \"Jan 10, 2008 - Jan 12, 2008\". They are designed\nto take a start and end date, time or datetime plus a formatting pattern\nand use that information to produce a localized format.\n\nSee `Cldr.Interval.to_string/3` and `Cldr.DateTime.Interval.to_string/3`","ref":"Cldr.DateTime.Interval.html"},{"type":"function","title":"Cldr.DateTime.Interval.greatest_difference/2","doc":"Returns the format code representing the date or\ntime unit that is the greatest difference between\ntwo date/times.","ref":"Cldr.DateTime.Interval.html#greatest_difference/2"},{"type":"function","title":"Arguments - Cldr.DateTime.Interval.greatest_difference/2","doc":"* `from` is any `t:DateTime.t/0` or `t:NaiveDateTine.t/0`\n\n* `to` is any `t:DateTime.t/0` or `t:NaiveDateTine.t/0`","ref":"Cldr.DateTime.Interval.html#greatest_difference/2-arguments"},{"type":"function","title":"Returns - Cldr.DateTime.Interval.greatest_difference/2","doc":"* `{:ok, format_code}` where `format_code` is one of\n\n  * `:y` meaning that the greatest difference is in the year\n  * `:M` meaning that the greatest difference is in the month\n  * `:d` meaning that the greatest difference is in the day\n  * `:H` meaning that the greatest difference is in the hour\n  * `:m` meaning that the greatest difference is in the minute\n\n* `{:error, :no_practical_difference}`","ref":"Cldr.DateTime.Interval.html#greatest_difference/2-returns"},{"type":"function","title":"Example - Cldr.DateTime.Interval.greatest_difference/2","doc":"iex> Cldr.DateTime.Interval.greatest_difference ~U[2022-04-22 02:00:00.0Z], ~U[2022-04-22 03:00:00.0Z]\n    {:ok, :H}\n\n    iex> Cldr.DateTime.Interval.greatest_difference ~U[2022-04-22 02:00:00.0Z], ~U[2022-04-22 02:00:01.0Z]\n    {:error, :no_practical_difference}","ref":"Cldr.DateTime.Interval.html#greatest_difference/2-example"},{"type":"function","title":"Cldr.DateTime.Interval.to_string/4","doc":"Returns a localised string representing the formatted\ninterval formed by two dates.","ref":"Cldr.DateTime.Interval.html#to_string/4"},{"type":"function","title":"Arguments - Cldr.DateTime.Interval.to_string/4","doc":"* `from` is any map that conforms to the\n  `Calendar.datetime` type.\n\n* `to` is any map that conforms to the\n  `Calendar.datetime` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module\n\n* `options` is a keyword list of options. The default is `[]`.\n\nEither of `from` or `to` may also be `nil` in which case the\nresult is an \"open\" interval and the non-nil parameter is formatted\nusing `Cldr.DateTime.to_string/3`.","ref":"Cldr.DateTime.Interval.html#to_string/4-arguments"},{"type":"function","title":"Options - Cldr.DateTime.Interval.to_string/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representation of an interval\n  format. The default is `:medium`.\n\n* `:date_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the date part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:date_format` is not specified\n  then the date format is defined by the `:format` option.\n\n* `:time_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the time part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:time_format` is not specified\n  thenthe time format is defined by the `:format` option.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated","ref":"Cldr.DateTime.Interval.html#to_string/4-options"},{"type":"function","title":"Returns - Cldr.DateTime.Interval.to_string/4","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.DateTime.Interval.html#to_string/4-returns"},{"type":"function","title":"Notes - Cldr.DateTime.Interval.to_string/4","doc":"* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval","ref":"Cldr.DateTime.Interval.html#to_string/4-notes"},{"type":"function","title":"Examples - Cldr.DateTime.Interval.to_string/4","doc":"iex> Cldr.DateTime.Interval.to_string ~U[2020-01-01 00:00:00.0Z],\n    ...> ~U[2020-12-31 10:00:00.0Z], MyApp.Cldr\n    {:ok, \"Jan 1, 2020, 12:00:00 AM – Dec 31, 2020, 10:00:00 AM\"}\n\n    iex> Cldr.DateTime.Interval.to_string ~U[2020-01-01 00:00:00.0Z], nil, MyApp.Cldr\n    {:ok, \"Jan 1, 2020, 12:00:00 AM –\"}","ref":"Cldr.DateTime.Interval.html#to_string/4-examples"},{"type":"function","title":"Cldr.DateTime.Interval.to_string!/3","doc":"Returns a localised string representing the formatted\ninterval formed by two dates or raises an\nexception.","ref":"Cldr.DateTime.Interval.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Interval.to_string!/3","doc":"* `from` is any map that conforms to the\n  `Calendar.datetime` type.\n\n* `to` is any map that conforms to the\n  `Calendar.datetime` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is `[]`.","ref":"Cldr.DateTime.Interval.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.DateTime.Interval.to_string!/3","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:date_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the date part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:date_format` is not specified\n  then the date format is defined by the `:format` option.\n\n* `:time_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the time part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:time_format` is not specified\n  then the time format is defined by the `:format` option.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.DateTime.Interval.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.DateTime.Interval.to_string!/3","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.DateTime.Interval.html#to_string!/3-returns"},{"type":"function","title":"Notes - Cldr.DateTime.Interval.to_string!/3","doc":"* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval","ref":"Cldr.DateTime.Interval.html#to_string!/3-notes"},{"type":"function","title":"Examples - Cldr.DateTime.Interval.to_string!/3","doc":"iex> use CalendarInterval\n    iex> Cldr.DateTime.Interval.to_string! ~I\"2020-01-01 00:00/10:00\", MyApp.Cldr\n    \"Jan 1, 2020, 12:00:00 AM – 10:00:59 AM\"","ref":"Cldr.DateTime.Interval.html#to_string!/3-examples"},{"type":"function","title":"Cldr.DateTime.Interval.to_string!/4","doc":"Returns a localised string representing the formatted\ninterval formed by two dates or raises an\nexception.","ref":"Cldr.DateTime.Interval.html#to_string!/4"},{"type":"function","title":"Arguments - Cldr.DateTime.Interval.to_string!/4","doc":"* `from` is any map that conforms to the\n  `Calendar.datetime` type.\n\n* `to` is any map that conforms to the\n  `Calendar.datetime` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is `[]`.","ref":"Cldr.DateTime.Interval.html#to_string!/4-arguments"},{"type":"function","title":"Options - Cldr.DateTime.Interval.to_string!/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representation of an interval\n  format. The default is `:medium`.\n\n* `:date_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the date part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:date_format` is not specified\n  then the date format is defined by the `:format` option.\n\n* `:time_format` is any one of `:short`, `:medium`, `:long`, `:full`. If defined,\n  this option is used to format the time part of the date time. This option is\n  only acceptable if the `:format` option is not specified, or is specified as either\n  `:short`, `:medium`, `:long`, `:full`. If `:time_format` is not specified\n  then the time format is defined by the `:format` option.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.DateTime.Interval.html#to_string!/4-options"},{"type":"function","title":"Returns - Cldr.DateTime.Interval.to_string!/4","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.DateTime.Interval.html#to_string!/4-returns"},{"type":"function","title":"Notes - Cldr.DateTime.Interval.to_string!/4","doc":"* For more information on interval format string\n  see the `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date is formatted instead of an interval","ref":"Cldr.DateTime.Interval.html#to_string!/4-notes"},{"type":"function","title":"Examples - Cldr.DateTime.Interval.to_string!/4","doc":"iex> Cldr.DateTime.Interval.to_string! ~U[2020-01-01 00:00:00.0Z],\n    ...> ~U[2020-12-31 10:00:00.0Z], MyApp.Cldr\n    \"Jan 1, 2020, 12:00:00 AM – Dec 31, 2020, 10:00:00 AM\"","ref":"Cldr.DateTime.Interval.html#to_string!/4-examples"},{"type":"module","title":"Cldr.Interval","doc":"Interval formats allow for software to format intervals like \"Jan 10-12, 2008\" as a\nshorter and more natural format than \"Jan 10, 2008 - Jan 12, 2008\". They are designed\nto take a start and end date, time or datetime plus a formatting pattern\nand use that information to produce a localized format.\n\nThe interval functions in the library will determine the calendar\nfield with the greatest difference between the two datetimes before using the\nformat pattern.\n\nFor example, the greatest difference in \"Jan 10-12, 2008\" is the day field, while\nthe greatest difference in \"Jan 10 - Feb 12, 2008\" is the month field. This is used to\npick the exact pattern to be used.","ref":"Cldr.Interval.html"},{"type":"module","title":"Interval Formats - Cldr.Interval","doc":"CLDR provides a two-level mapping to a concrete format string.\nTo simplify the developer experience, `ex_cldr_dates_times` groups these\nmappings into `styles` and `formats`.\n\nStyles group different CLDR formats into similar types. These\nstyles can be seen by examining the output below:\n\n```elixir\niex> Cldr.Date.Interval.styles()\n%{\n  date: %{long: :yMMMEd, medium: :yMMMd, short: :yMd},\n  month: %{long: :MMM, medium: :MMM, short: :M},\n  month_and_day: %{long: :MMMEd, medium: :MMMd, short: :Md},\n  year_and_month: %{long: :yMMMM, medium: :yMMM, short: :yM}\n}\n\niex> Cldr.Time.Interval.styles()\n%{\n  flex: %{h12: %{long: :Bhm, medium: :Bhm, short: :Bh}, h23: %{long: :Bhm, medium: :Bhm, short: :Bh}},\n  time: %{h12: %{long: :hm, medium: :hm, short: :h}, h23: %{long: :Hm, medium: :Hm, short: :H}},\n  zone: %{h12: %{long: :hmv, medium: :hmv, short: :hv}, h23: %{long: :Hmv, medium: :Hmv, short: :Hv}}\n}\n```\n\nHere the style is the key if the map: `:date`, `:month`,\n`:month_and_day` and `year_and_month`.\n\nThese are then mapped to interval formats `:short`, `:medium` or `:long`.","ref":"Cldr.Interval.html#module-interval-formats"},{"type":"module","title":"Interval formats - Cldr.Interval","doc":"In a manner similar to formatting individual dates, times and datetimes, format\ntypes are introduced to simplify common usage. For all intervals the following\nformat types are;\n\n* `:short`\n* `:medium` (the default)\n* `:long`\n\nIn each case, the mapping is from a style to a format type and then of\nresolves to a native CLDR format map.\n\nThese maps can be examined as follows where `\"en\"` is any configured\nlocale name and `:gregorian` is the underlying CLDR calendar type. In\ncommon use the `:gregorian` calendar is the standard.  However other\ncalendar types are also supported. For example:\n\n```elixir\niex> Cldr.known_calendars()\n[:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem,\n :gregorian, :hebrew, :indian, :islamic, :islamic_civil, :islamic_rgsa,\n :islamic_tbla, :islamic_umalqura, :japanese, :persian, :roc]\n```\n\nTo examine the available interval formats, `Cldr.DateTime.Format.interval_formats/2`\ncan be used although its use is primarily internal to the implementation of\n`to_string/3` and would not normally be called directly.\n\n```elixir\nCldr.DateTime.Format.interval_formats(:en, :gregorian)\n=> {:ok,\n     %{\n       Bh: %{B: [\"h B – \", \"h B\"], h: [\"h – \", \"h B\"]},\n       Bhm: %{\n         B: [\"h:mm B – \", \"h:mm B\"],\n         h: [\"h:mm – \", \"h:mm B\"],\n         m: [\"h:mm – \", \"h:mm B\"]\n       },\n       Gy: %{G: [\"y G – \", \"y G\"], y: [\"y – \", \"y G\"]},\n       GyM: %{\n         G: [\"M/y G – \", \"M/y G\"],\n         M: [\"M/y – \", \"M/y G\"],\n         y: [\"M/y – \", \"M/y G\"]\n       },\n       GyMEd: %{\n         G: [\"E, M/d/y G – \", \"E, M/d/y G\"],\n         M: [\"E, M/d/y – \", \"E, M/d/y G\"],\n         d: [\"E, M/d/y – \", \"E, M/d/y G\"],\n         y: [\"E, M/d/y – \", \"E, M/d/y G\"]\n       },\n       ...\n     }\n   }\n```\n\nAt this point we can see that the path to resolving a format is:\n\n* Apply the format style. For dates, this is `:date`.\n* Apply the format type. For dates, the default is `:medium`.\n\nThis will then return a map such as:\n\n```elixir\n%{\n   d: [\"MMM d – \", \"d, y\"],\n   m: [\"MMM d – \", \"MMM d, y\"],\n   y: [\"MMM d, y – \", \"MMM d, y\"]\n }\n```","ref":"Cldr.Interval.html#module-interval-formats"},{"type":"module","title":"The field with the greatest difference - Cldr.Interval","doc":"There remains one more choice to make - and that choice is made\nbased upon the highest order date field that is different between the\n`from` and `to` dates.\n\nWith two dates `2020-02-02` and `2021-01-01` the highest order\ndifference is `:year`. With `2020-02-02` and `2020-01-01` it is `:month`.","ref":"Cldr.Interval.html#module-the-field-with-the-greatest-difference"},{"type":"module","title":"Formatting the interval - Cldr.Interval","doc":"Using this `greatest difference` information we can now resolve the\nfinal format. With the `:year` field being the greatest difference then\nthe format is `y: [\"MMM d, y – \", \"MMM d, y\"]`.\n\nFinally, formatting can proceed for the `from` date being formatted with\n`\"MMM d, y – \"` and the `to` date being formatted with `\"MMM d, y\"` and the\ntwo results then being concatenated to form the final string.","ref":"Cldr.Interval.html#module-formatting-the-interval"},{"type":"module","title":"Other ways to specify an interval format - Cldr.Interval","doc":"So far we have considered formats that a resolved from standard styles\nand format types. This is the typical usage and they are specified\nas parameters to the `to_string/3` function. For example:\n\n```elixir\niex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n{:ok, \"Jan 1 – 12, 2020\"}\n\niex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr, format: :long\n{:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\niex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n...> style: :month_and_day\n{:ok, \"Jan 1 – 12\"}\n```","ref":"Cldr.Interval.html#module-other-ways-to-specify-an-interval-format"},{"type":"module","title":"Direct use of CLDR format types - Cldr.Interval","doc":"It is also possible to directly specify the CLDR format type. For example:\n```elixir\niex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr, format: :GyMMMd\n{:ok, \"Jan 1 – 12, 2020 AD\"}\n```","ref":"Cldr.Interval.html#module-direct-use-of-cldr-format-types"},{"type":"module","title":"Using format strings - Cldr.Interval","doc":"In the unusual situation where one of the standard format styles and types does\nnot meet requirements, a format string can also be specified. For example:\n\n```elixir\niex> Cldr.Date.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n...> format: \"E, M/d/y – E, M/d/y\"\n{:ok, \"Wed, 1/1/2020 – Sun, 1/12/2020\"}\n```\n\nIn this case, the steps to formatting are:\n\n1. Split the format string at the point at which the first repeating\nformatting code is detected. In the pattern above it is where the second `E`\nis detected. The result in this case will be `[\"E, M/d/y – \", \"E, M/d/y\"]`\nFor the purposes of splitting, duplicate are ignored. Therefore\n\"EEE, M/d/y – E, M/d/y\" will split into `[\"EEE, M/d/y – \", \"E, M/d/y\"]`.\n\n2. Each part of the pattern is parsed.\n\n3. The two dates, times or datetimes are formatted.\n\nThis is a more expensive operation than using the predefined styles and\nformat types since the underlying formats for these types are precompiled\ninto an efficient runtime format.","ref":"Cldr.Interval.html#module-using-format-strings"},{"type":"module","title":"Configuring precompiled interval formats - Cldr.Interval","doc":"If there is a requirement for repeated use of format strings\nthen they can be configured in the backend module so that they are\nprecompiled and therefore not suffer a runtime performance penalty.\n\nIn a backend module, configure the required formats as a list under the\n`:precompile_interval_formats` key:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\"],\n    default_locale: \"en\",\n    precompile_interval_formats: [\"E, MMM d/y – d/y\"]\nend\n```","ref":"Cldr.Interval.html#module-configuring-precompiled-interval-formats"},{"type":"function","title":"Cldr.Interval.to_string/3","doc":"Returns a `Date.Range` or `CalendarInterval` as\na localised string.","ref":"Cldr.Interval.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Interval.to_string/3","doc":"* `range` is either a `Date.Range.t` returned from `Date.range/2`\n  or a `CalendarInterval.t`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date | :time | nil]`.","ref":"Cldr.Interval.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Interval.to_string/3","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The valid\n  styles depends on whether formatting is for a date, time or datetime.\n  Since the functions in this module will make a determination as\n  to which formatter to be used based upon the data passed to them\n  it is recommended the style option be omitted. If styling is important\n  then call `to_string/3` directly on `Cldr.Date.Interval`, `Cldr.Time.Interval`\n  or `Cldr.DateTime.Interval`.\n\n  * For a date the alternatives are `:date`, `:month_and_day`, `:month`\n    and `:year_and_month`. The default is `:date`.\n\n  * For a time the alternatives are `:time`, `:zone` and\n    `:flex`. The default is `:time`.\n\n  * For a datetime there are no style options, the default\n    for each of the date and time part is used.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Interval.html#to_string/3-options"},{"type":"function","title":"Returns - Cldr.Interval.to_string/3","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Interval.html#to_string/3-returns"},{"type":"function","title":"Notes - Cldr.Interval.to_string/3","doc":"* `to_string/3` will decide which formatter to call based upon\n  the arguments provided to it.\n\n  * A `Date.Range.t` will call `Cldr.Date.Interval.to_string/3`.\n\n  * A `CalendarInterval` will call `Cldr.Date.Interval.to_string/3`\n    if its `:precision` is `:year`, `:month` or `:day`. Otherwise\n    it will call `Cldr.Time.Interval.to_string/3`.\n\n  * If `from` and `to` both conform to the `Calendar.datetime()`\n    type then `Cldr.DateTime.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.date()`\n    type then `Cldr.Date.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.time()`\n    type then `Cldr.Time.Interval.to_string/3` is called.\n\n* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date, time or datetime is formatted instead of an interval.","ref":"Cldr.Interval.html#to_string/3-notes"},{"type":"function","title":"Examples - Cldr.Interval.to_string/3","doc":"iex> Cldr.Interval.to_string Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\n    iex> use CalendarInterval\n    iex> Cldr.Interval.to_string ~I\"2020-01-01/12\", MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}","ref":"Cldr.Interval.html#to_string/3-examples"},{"type":"function","title":"Cldr.Interval.to_string/4","doc":"Returns a string representing the formatted\ninterval formed by two dates.","ref":"Cldr.Interval.html#to_string/4"},{"type":"function","title":"Arguments - Cldr.Interval.to_string/4","doc":"* `from` is any map that conforms to the\n  any one of the `Calendar` types.\n\n* `to` is any map that conforms to the\n  any one of the `Calendar` types. `to` must\n  occur on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date | :time | nil]`.","ref":"Cldr.Interval.html#to_string/4-arguments"},{"type":"function","title":"Options - Cldr.Interval.to_string/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The valid\n  styles depends on whether formatting is for a date, time or datetime.\n  Since the functions in this module will make a determination as\n  to which formatter to be used based upon the data passed to them\n  it is recommended the style option be omitted. If styling is important\n  then call `to_string/3` directly on `Cldr.Date.Interval`, `Cldr.Time.Interval`\n  or `Cldr.DateTime.Interval`.\n\n  * For a date the alternatives are `:date`, `:month_and_day`, `:month`\n    and `:year_and_month`. The default is `:date`.\n\n  * For a time the alternatives are `:time`, `:zone` and\n    `:flex`. The default is `:time`.\n\n  * For a datetime there are no style options, the default\n    for each of the date and time part is used.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Interval.html#to_string/4-options"},{"type":"function","title":"Returns - Cldr.Interval.to_string/4","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Interval.html#to_string/4-returns"},{"type":"function","title":"Notes - Cldr.Interval.to_string/4","doc":"* `to_string/3` will decide which formatter to call based upon\n  the arguments provided to it.\n\n  * A `Date.Range.t` will call `Cldr.Date.Interval.to_string/3`.\n\n  * A `CalendarInterval` will call `Cldr.Date.Interval.to_string/3`\n    if its `:precision` is `:year`, `:month` or `:day`. Otherwise\n    it will call `Cldr.Time.Interval.to_string/3`.\n\n  * If `from` and `to` both conform to the `Calendar.datetime()`\n    type then `Cldr.DateTime.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.date()`\n    type then `Cldr.Date.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.time()`\n    type then `Cldr.Time.Interval.to_string/3` is called.\n\n* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date, time or datetime is formatted instead of an interval.","ref":"Cldr.Interval.html#to_string/4-notes"},{"type":"function","title":"Examples - Cldr.Interval.to_string/4","doc":"iex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-12-31], MyApp.Cldr\n    {:ok, \"Jan 1 – Dec 31, 2020\"}\n\n    iex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n    {:ok, \"Jan 1 – 12, 2020\"}\n\n    iex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\n    iex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-12-01], MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    {:ok, \"January – December 2020\"}\n\n    iex> Cldr.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-12-01 10:05:00.0Z], MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"January 1, 2020, 12:00:00 AM UTC – December 1, 2020, 10:05:00 AM UTC\"}\n\n    iex> Cldr.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:05:00.0Z], MyApp.Cldr,\n    ...> format: :long\n    {:ok, \"January 1, 2020, 12:00:00 AM UTC – 10:05:00 AM UTC\"}","ref":"Cldr.Interval.html#to_string/4-examples"},{"type":"function","title":"Cldr.Interval.to_string!/3","doc":"Returns a `Date.Range` or `CalendarInterval` as\na localised string or raises an exception.","ref":"Cldr.Interval.html#to_string!/3"},{"type":"function","title":"Arguments - Cldr.Interval.to_string!/3","doc":"* `range` is either a `Date.Range.t` returned from `Date.range/2`\n  or a `CalendarInterval.t`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date | :time | nil]`.","ref":"Cldr.Interval.html#to_string!/3-arguments"},{"type":"function","title":"Options - Cldr.Interval.to_string!/3","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The valid\n  styles depends on whether formatting is for a date, time or datetime.\n  Since the functions in this module will make a determination as\n  to which formatter to be used based upon the data passed to them\n  it is recommended the style option be omitted. If styling is important\n  then call `to_string/3` directly on `Cldr.Date.Interval`, `Cldr.Time.Interval`\n  or `Cldr.DateTime.Interval`.\n\n  * For a date the alternatives are `:date`, `:month_and_day`, `:month`\n    and `:year_and_month`. The default is `:date`.\n\n  * For a time the alternatives are `:time`, `:zone` and\n    `:flex`. The default is `:time`.\n\n  * For a datetime there are no style options, the default\n    for each of the date and time part is used.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Interval.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Interval.to_string!/3","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.Interval.html#to_string!/3-returns"},{"type":"function","title":"Notes - Cldr.Interval.to_string!/3","doc":"* `to_string/3` will decide which formatter to call based upon\n  the arguments provided to it.\n\n  * A `Date.Range.t` will call `Cldr.Date.Interval.to_string/3`.\n\n  * A `CalendarInterval` will call `Cldr.Date.Interval.to_string/3`\n    if its `:precision` is `:year`, `:month` or `:day`. Otherwise\n    it will call `Cldr.Time.Interval.to_string/3`.\n\n  * If `from` and `to` both conform to the `Calendar.datetime()`\n    type then `Cldr.DateTime.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.date()`\n    type then `Cldr.Date.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.time()`\n    type then `Cldr.Time.Interval.to_string/3` is called.\n\n* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date, time or datetime is formatted instead of an interval.","ref":"Cldr.Interval.html#to_string!/3-notes"},{"type":"function","title":"Examples - Cldr.Interval.to_string!/3","doc":"iex> use CalendarInterval\n    iex> Cldr.Interval.to_string! ~I\"2020-01-01/12\", MyApp.Cldr,\n    ...> format: :long\n    \"Wed, Jan 1 – Sun, Jan 12, 2020\"\n\n    iex> Cldr.Interval.to_string! Date.range(~D[2020-01-01], ~D[2020-01-12]), MyApp.Cldr,\n    ...> format: :long\n    \"Wed, Jan 1 – Sun, Jan 12, 2020\"","ref":"Cldr.Interval.html#to_string!/3-examples"},{"type":"function","title":"Cldr.Interval.to_string!/4","doc":"Returns a string representing the formatted\ninterval formed by two dates or raises an\nexception.","ref":"Cldr.Interval.html#to_string!/4"},{"type":"function","title":"Arguments - Cldr.Interval.to_string!/4","doc":"* `from` is any map that conforms to the\n  any one of the `Calendar` types.\n\n* `to` is any map that conforms to the\n  any one of the `Calendar` types. `to` must\n  occur on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore a `Cldr` backend module\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :date | :time | nil]`.","ref":"Cldr.Interval.html#to_string!/4-arguments"},{"type":"function","title":"Options - Cldr.Interval.to_string!/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The valid\n  styles depends on whether formatting is for a date, time or datetime.\n  Since the functions in this module will make a determination as\n  to which formatter to be used based upon the data passed to them\n  it is recommended the style option be omitted. If styling is important\n  then call `to_string/3` directly on `Cldr.Date.Interval`, `Cldr.Time.Interval`\n  or `Cldr.DateTime.Interval`.\n\n  * For a date the alternatives are `:date`, `:month_and_day`, `:month`\n    and `:year_and_month`. The default is `:date`.\n\n  * For a time the alternatives are `:time`, `:zone` and\n    `:flex`. The default is `:time`.\n\n  * For a datetime there are no style options, the default\n    for each of the date and time part is used.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Interval.html#to_string!/4-options"},{"type":"function","title":"Returns - Cldr.Interval.to_string!/4","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Interval.html#to_string!/4-returns"},{"type":"function","title":"Notes - Cldr.Interval.to_string!/4","doc":"* `to_string/3` will decide which formatter to call based upon\n  the arguments provided to it.\n\n  * A `Date.Range.t` will call `Cldr.Date.Interval.to_string/3`\n\n  * A `CalendarInterval` will call `Cldr.Date.Interval.to_string/3`\n    if its `:precision` is `:year`, `:month` or `:day`. Otherwise\n    it will call `Cldr.Time.Interval.to_string/3`.\n\n  * If `from` and `to` both conform to the `Calendar.datetime()`\n    type then `Cldr.DateTime.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.date()`\n    type then `Cldr.Date.Interval.to_string/3` is called.\n\n  * Otherwise if `from` and `to` conform to the `Calendar.time()`\n    type then `Cldr.Time.Interval.to_string/3` is called.\n\n* `CalendarInterval` support requires adding the\n  dependency [calendar_interval](https://hex.pm/packages/calendar_interval)\n  to the `deps` configuration in `mix.exs`.\n\n* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configuration locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  date, time or datetime is formatted instead of an interval.","ref":"Cldr.Interval.html#to_string!/4-notes"},{"type":"function","title":"Examples - Cldr.Interval.to_string!/4","doc":"iex> Cldr.Interval.to_string! ~D[2020-01-01], ~D[2020-12-31], MyApp.Cldr\n    \"Jan 1 – Dec 31, 2020\"\n\n    iex> Cldr.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n    \"Jan 1 – 12, 2020\"\n\n    iex> Cldr.Interval.to_string! ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n    ...> format: :long\n    \"Wed, Jan 1 – Sun, Jan 12, 2020\"\n\n    iex> Cldr.Interval.to_string! ~D[2020-01-01], ~D[2020-12-01], MyApp.Cldr,\n    ...> format: :long, style: :year_and_month\n    \"January – December 2020\"\n\n    iex> Cldr.Interval.to_string! ~U[2020-01-01 00:00:00.0Z], ~U[2020-12-01 10:05:00.0Z], MyApp.Cldr,\n    ...> format: :long\n    \"January 1, 2020, 12:00:00 AM UTC – December 1, 2020, 10:05:00 AM UTC\"\n\n    iex> Cldr.Interval.to_string! ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:05:00.0Z], MyApp.Cldr,\n    ...> format: :long\n    \"January 1, 2020, 12:00:00 AM UTC – 10:05:00 AM UTC\"","ref":"Cldr.Interval.html#to_string!/4-examples"},{"type":"type","title":"Cldr.Interval.datetime/0","doc":"Any date, time or datetime","ref":"Cldr.Interval.html#t:datetime/0"},{"type":"type","title":"Cldr.Interval.range/0","doc":"A Date.Range or CalendarInterval range","ref":"Cldr.Interval.html#t:range/0"},{"type":"module","title":"Cldr.Time.Interval","doc":"Interval formats allow for software to format intervals like \"Jan 10-12, 2008\" as a\nshorter and more natural format than \"Jan 10, 2008 - Jan 12, 2008\". They are designed\nto take a start and end date, time or datetime plus a formatting pattern\nand use that information to produce a localized format.\n\nSee `Cldr.Interval.to_string/3` and `Cldr.Time.Interval.to_string/3`","ref":"Cldr.Time.Interval.html"},{"type":"function","title":"Cldr.Time.Interval.greatest_difference/2","doc":"Returns the format code representing the date or\ntime unit that is the greatest difference between\ntwo times.\n\nOnly differences in hours or minutes are considered.","ref":"Cldr.Time.Interval.html#greatest_difference/2"},{"type":"function","title":"Arguments - Cldr.Time.Interval.greatest_difference/2","doc":"* `from` is any `t:Time.t/0`.\n\n* `to` is any `t:Time.t/0`.","ref":"Cldr.Time.Interval.html#greatest_difference/2-arguments"},{"type":"function","title":"Returns - Cldr.Time.Interval.greatest_difference/2","doc":"* `{:ok, format_code}` where `format_code` is one of:\n\n  * `:H` meaning that the greatest difference is in the hour\n  * `:m` meaning that the greatest difference is in the minute\n\n* `{:error, :no_practical_difference}`","ref":"Cldr.Time.Interval.html#greatest_difference/2-returns"},{"type":"function","title":"Example - Cldr.Time.Interval.greatest_difference/2","doc":"iex> Cldr.Time.Interval.greatest_difference ~T[10:11:00], ~T[10:12:00]\n    {:ok, :m}\n\n    iex> Cldr.Time.Interval.greatest_difference ~T[10:11:00], ~T[10:11:00]\n    {:error, :no_practical_difference}","ref":"Cldr.Time.Interval.html#greatest_difference/2-example"},{"type":"function","title":"Cldr.Time.Interval.to_string/4","doc":"Returns a string representing the formatted\ninterval formed by two times.","ref":"Cldr.Time.Interval.html#to_string/4"},{"type":"function","title":"Arguments - Cldr.Time.Interval.to_string/4","doc":"* `from` is any map that conforms to the\n  `Calendar.time` type.\n\n* `to` is any map that conforms to the\n  `Calendar.time` type. `to` must occur\n  on or after `from`.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore `Cldr` backend module\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :time]`.\n\nEither `from` or `to` may also be `nil` in which case the\ninterval is formatted as an open interval with the non-nil\nside formatted as a standalone time.","ref":"Cldr.Time.Interval.html#to_string/4-arguments"},{"type":"function","title":"Options - Cldr.Time.Interval.to_string/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:time`, `:zone`,\n  and `:flex`. The default is `:time`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`.\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Time.Interval.html#to_string/4-options"},{"type":"function","title":"Returns - Cldr.Time.Interval.to_string/4","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Time.Interval.html#to_string/4-returns"},{"type":"function","title":"Notes - Cldr.Time.Interval.to_string/4","doc":"* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  time is formatted instead of an interval.","ref":"Cldr.Time.Interval.html#to_string/4-notes"},{"type":"function","title":"Examples - Cldr.Time.Interval.to_string/4","doc":"iex> Cldr.Time.Interval.to_string ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :short\n    {:ok, \"10 – 10 AM\"}\n\n    iex> Cldr.Time.Interval.to_string ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :medium\n    {:ok, \"10:00 – 10:03 AM\"}\n\n    iex> Cldr.Time.Interval.to_string ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :long\n    {:ok, \"10:00 – 10:03 AM\"}\n\n    iex> Cldr.Time.Interval.to_string ~T[10:00:00], ~T[10:03:00], MyApp.Cldr,\n    ...> format: :long, style: :flex\n    {:ok, \"10:00 – 10:03 in the morning\"}\n\n    iex> Cldr.Time.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:00:00.0Z],\n    ...> MyApp.Cldr, format: :long, style: :flex\n    {:ok, \"12:00 – 10:00 in the morning\"}\n\n    iex> Cldr.Time.Interval.to_string ~U[2020-01-01 00:00:00.0Z], nil, MyApp.Cldr,\n    ...> format: :long, style: :flex\n    {:ok, \"12:00:00 AM UTC –\"}\n\n    iex> Cldr.Time.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:00:00.0Z],\n    ...> MyApp.Cldr, format: :long, style: :zone\n    {:ok, \"12:00 – 10:00 AM Etc/UTC\"}\n\n    iex> Cldr.Time.Interval.to_string ~T[10:00:00], ~T[10:03:00], MyApp.Cldr,\n    ...> format: :long, style: :flex, locale: \"th\"\n    {:ok, \"10:00 – 10:03 ในตอนเช้า\"}","ref":"Cldr.Time.Interval.html#to_string/4-examples"},{"type":"function","title":"Cldr.Time.Interval.to_string!/4","doc":"Returns a string representing the formatted\ninterval formed by two times.","ref":"Cldr.Time.Interval.html#to_string!/4"},{"type":"function","title":"Arguments - Cldr.Time.Interval.to_string!/4","doc":"* `from` is any map that conforms to the\n  `Calendar.time` type.\n\n* `to` is any map that conforms to the\n  `Calendar.time` type.\n\n* `backend` is any module that includes `use Cldr` and\n  is therefore `Cldr` backend module\n\n* `options` is a keyword list of options. The default is\n  `[format: :medium, style: :time]`.","ref":"Cldr.Time.Interval.html#to_string!/4-arguments"},{"type":"function","title":"Options - Cldr.Time.Interval.to_string!/4","doc":"* `:format` is one of `:short`, `:medium` or `:long` or a\n  specific format type or a string representing of an interval\n  format. The default is `:medium`.\n\n* `:style` supports different formatting styles. The\n  alternatives are `:time`, `:zone`,\n  and `:flex`. The default is `:time`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct.  The default is `Cldr.get_locale/0`\n\n* `number_system:` a number system into which the formatted date digits should\n  be transliterated.","ref":"Cldr.Time.Interval.html#to_string!/4-options"},{"type":"function","title":"Returns - Cldr.Time.Interval.to_string!/4","doc":"* `string` or\n\n* raises an exception","ref":"Cldr.Time.Interval.html#to_string!/4-returns"},{"type":"function","title":"Notes - Cldr.Time.Interval.to_string!/4","doc":"* For more information on interval format string\n  see `Cldr.Interval`.\n\n* The available predefined formats that can be applied are the\n  keys of the map returned by `Cldr.DateTime.Format.interval_formats(\"en\", :gregorian)`\n  where `\"en\"` can be replaced by any configured locale name and `:gregorian`\n  is the underlying CLDR calendar type.\n\n* In the case where `from` and `to` are equal, a single\n  time is formatted instead of an interval.","ref":"Cldr.Time.Interval.html#to_string!/4-notes"},{"type":"function","title":"Examples - Cldr.Time.Interval.to_string!/4","doc":"iex> Cldr.Time.Interval.to_string! ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :short\n    \"10 – 10 AM\"\n\n    iex> Cldr.Time.Interval.to_string! ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :medium\n    \"10:00 – 10:03 AM\"\n\n    iex> Cldr.Time.Interval.to_string! ~T[10:00:00], ~T[10:03:00], MyApp.Cldr, format: :long\n    \"10:00 – 10:03 AM\"\n\n    iex> Cldr.Time.Interval.to_string ~T[23:00:00.0Z], ~T[01:01:00.0Z], MyApp.Cldr\n    {:ok, \"11:00 PM – 1:01 AM\"}\n\n    iex> Cldr.Time.Interval.to_string! ~T[10:00:00], ~T[10:03:00], MyApp.Cldr,\n    ...> format: :long, style: :flex\n    \"10:00 – 10:03 in the morning\"\n\n    iex> Cldr.Time.Interval.to_string! ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:00:00.0Z],\n    ...> MyApp.Cldr, format: :long, style: :flex\n    \"12:00 – 10:00 in the morning\"\n\n    iex> Cldr.Time.Interval.to_string! ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:00:00.0Z],\n    ...> MyApp.Cldr, format: :long, style: :zone\n    \"12:00 – 10:00 AM Etc/UTC\"\n\n    iex> Cldr.Time.Interval.to_string! ~T[10:00:00], ~T[10:03:00], MyApp.Cldr,\n    ...> format: :long, style: :flex, locale: \"th\"\n    \"10:00 – 10:03 ในตอนเช้า\"","ref":"Cldr.Time.Interval.html#to_string!/4-examples"},{"type":"module","title":"Cldr.DateTime.Format","doc":"Manages the Date, Time and DateTime formats\ndefined by CLDR.\n\nThe functions in `Cldr.DateTime.Format` are\nprimarily concerned with encapsulating the\ndata from CLDR in functions that are used\nduring the formatting process.","ref":"Cldr.DateTime.Format.html"},{"type":"function","title":"Cldr.DateTime.Format.best_match/4","doc":"Find the best match for a requested format.","ref":"Cldr.DateTime.Format.html#best_match/4"},{"type":"function","title":"Cldr.DateTime.Format.calendars_for/2","doc":"Returns a list of calendars defined for a given locale.","ref":"Cldr.DateTime.Format.html#calendars_for/2"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.calendars_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct. The default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#calendars_for/2-arguments"},{"type":"function","title":"Example - Cldr.DateTime.Format.calendars_for/2","doc":"iex> Cldr.DateTime.Format.calendars_for(:en, MyApp.Cldr)\n    {:ok, [:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem,\n     :generic, :gregorian, :hebrew, :indian, :islamic, :islamic_civil,\n     :islamic_rgsa, :islamic_tbla, :islamic_umalqura, :japanese, :persian, :roc]}","ref":"Cldr.DateTime.Format.html#calendars_for/2-example"},{"type":"function","title":"Cldr.DateTime.Format.common_date_time_format_names/1","doc":"Returns a list of the date_time format types that are\navailable in all known locales.\n\nThe format types returned by `common_date_time_format_names`\nare guaranteed to be available in all known locales,","ref":"Cldr.DateTime.Format.html#common_date_time_format_names/1"},{"type":"function","title":"Example: - Cldr.DateTime.Format.common_date_time_format_names/1","doc":"iex> Cldr.DateTime.Format.common_date_time_format_names()\n    [:Bh, :Bhm, :Bhms, :E, :EBhm, :EBhms, :EHm, :EHms, :Ed, :Ehm, :Ehms, :Gy,\n     :GyMMM, :GyMMMEd, :GyMMMd, :GyMd, :H, :Hm, :Hms, :Hmsv, :Hmv, :M, :MEd, :MMM,\n     :MMMEd, :MMMMW, :MMMMd, :MMMd, :Md, :d, :h, :hm, :hms, :hmsv, :hmv, :ms, :y,\n     :yM, :yMEd, :yMMM, :yMMMEd, :yMMMM, :yMMMd, :yMd, :yQQQ, :yQQQQ, :yw]","ref":"Cldr.DateTime.Format.html#common_date_time_format_names/1-example"},{"type":"function","title":"Cldr.DateTime.Format.date_time_at_formats/3","doc":"Returns a map of the standard datetime \"at\" formats for a given\nlocale and calendar.\n\nAn \"at\" format is one where the datetime is formatted with the\ndate part separated from the time part by a localized version\nof \"at\".","ref":"Cldr.DateTime.Format.html#date_time_at_formats/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.date_time_at_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#date_time_at_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.DateTime.Format.date_time_at_formats/3","doc":"iex> Cldr.DateTime.Format.date_time_at_formats(:en)\n    {:ok, %Cldr.DateTime.Formats{\n      full: \"{1} 'at' {0}\",\n      long: \"{1} 'at' {0}\",\n      medium: \"{1}, {0}\",\n      short: \"{1}, {0}\"}\n    }\n\n    iex> Cldr.DateTime.Format.date_time_at_formats(:en, :buddhist, MyApp.Cldr)\n    {:ok, %Cldr.DateTime.Formats{\n      full: \"{1} 'at' {0}\",\n      long: \"{1} 'at' {0}\",\n      medium: \"{1}, {0}\",\n      short: \"{1}, {0}\"}\n    }","ref":"Cldr.DateTime.Format.html#date_time_at_formats/3-examples"},{"type":"function","title":"Cldr.DateTime.Format.date_time_available_formats/3","doc":"Returns a map of the available datetime formats for a\ngiven locale and calendar.","ref":"Cldr.DateTime.Format.html#date_time_available_formats/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.date_time_available_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#date_time_available_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.DateTime.Format.date_time_available_formats/3","doc":"iex> Cldr.DateTime.Format.date_time_available_formats(:en)\n    {:ok,\n     %{\n       yw: %{\n         other: \"'week' w 'of' Y\",\n         one: \"'week' w 'of' Y\",\n         pluralize: :week_of_year\n       },\n       GyMMMEd: \"E, MMM d, y G\",\n       Hms: \"HH:mm:ss\",\n       MMMMW: %{\n         other: \"'week' W 'of' MMMM\",\n         one: \"'week' W 'of' MMMM\",\n         pluralize: :week_of_month\n       },\n       E: \"ccc\",\n       MMMd: \"MMM d\",\n       yMEd: \"E, M/d/y\",\n       yQQQ: \"QQQ y\",\n       Ehm: %{unicode: \"E h:mm a\", ascii: \"E h:mm a\"},\n       M: \"L\",\n       hm: %{unicode: \"h:mm a\", ascii: \"h:mm a\"},\n       yM: \"M/y\",\n       GyMMMd: \"MMM d, y G\",\n       GyMd: \"M/d/y G\",\n       Gy: \"y G\",\n       Hm: \"HH:mm\",\n       EBhms: \"E h:mm:ss B\",\n       d: \"d\",\n       hms: %{unicode: \"h:mm:ss a\", ascii: \"h:mm:ss a\"},\n       Ed: \"d E\",\n       Ehms: %{unicode: \"E h:mm:ss a\", ascii: \"E h:mm:ss a\"},\n       EHms: \"E HH:mm:ss\",\n       Bh: \"h B\",\n       h: %{unicode: \"h a\", ascii: \"h a\"},\n       Bhms: \"h:mm:ss B\",\n       Hmv: \"HH:mm v\",\n       hmv: %{unicode: \"h:mm a v\", ascii: \"h:mm a v\"},\n       yMd: \"M/d/y\",\n       ms: \"mm:ss\",\n       MMM: \"LLL\",\n       y: \"y\",\n       Bhm: \"h:mm B\",\n       yMMM: \"MMM y\",\n       yQQQQ: \"QQQQ y\",\n       yMMMEd: \"E, MMM d, y\",\n       yMMMM: \"MMMM y\",\n       EBhm: \"E h:mm B\",\n       Hmsv: \"HH:mm:ss v\",\n       yMMMd: \"MMM d, y\",\n       MEd: \"E, M/d\",\n       EHm: \"E HH:mm\",\n       GyMMM: \"MMM y G\",\n       hmsv: %{unicode: \"h:mm:ss a v\", ascii: \"h:mm:ss a v\"},\n       H: \"HH\",\n       Md: \"M/d\",\n       MMMEd: \"E, MMM d\",\n       MMMMd: \"MMMM d\"\n     }}","ref":"Cldr.DateTime.Format.html#date_time_available_formats/3-examples"},{"type":"function","title":"Cldr.DateTime.Format.date_time_formats/3","doc":"Returns a map of the standard datetime formats for a given locale and calendar.","ref":"Cldr.DateTime.Format.html#date_time_formats/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.date_time_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#date_time_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.DateTime.Format.date_time_formats/3","doc":"iex> Cldr.DateTime.Format.date_time_formats(:en)\n    {:ok, %Cldr.DateTime.Formats{\n      full: \"{1}, {0}\",\n      long: \"{1}, {0}\",\n      medium: \"{1}, {0}\",\n      short: \"{1}, {0}\"\n    }}\n\n    iex> Cldr.DateTime.Format.date_time_formats(:en, :buddhist, MyApp.Cldr)\n    {:ok, %Cldr.DateTime.Formats{\n      full: \"{1}, {0}\",\n      long: \"{1}, {0}\",\n      medium: \"{1}, {0}\",\n      short: \"{1}, {0}\"\n    }}","ref":"Cldr.DateTime.Format.html#date_time_formats/3-examples"},{"type":"macro","title":"Cldr.DateTime.Format.different_but_compatible/2","doc":"","ref":"Cldr.DateTime.Format.html#different_but_compatible/2"},{"type":"macro","title":"Cldr.DateTime.Format.different_types/2","doc":"","ref":"Cldr.DateTime.Format.html#different_types/2"},{"type":"function","title":"Cldr.DateTime.Format.gmt_format/2","doc":"Returns the GMT offset format list for a\nfor a timezone offset for a given locale.","ref":"Cldr.DateTime.Format.html#gmt_format/2"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.gmt_format/2","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#gmt_format/2-arguments"},{"type":"function","title":"Example - Cldr.DateTime.Format.gmt_format/2","doc":"iex> Cldr.DateTime.Format.gmt_format(:en, MyApp.Cldr)\n    {:ok, [\"GMT\", 0]}","ref":"Cldr.DateTime.Format.html#gmt_format/2-example"},{"type":"function","title":"Cldr.DateTime.Format.gmt_zero_format/2","doc":"Returns the GMT format string for a\nfor a timezone with an offset of zero for\na given locale.","ref":"Cldr.DateTime.Format.html#gmt_zero_format/2"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.gmt_zero_format/2","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#gmt_zero_format/2-arguments"},{"type":"function","title":"Example - Cldr.DateTime.Format.gmt_zero_format/2","doc":"iex> Cldr.DateTime.Format.gmt_zero_format(:en, MyApp.Cldr)\n    {:ok, \"GMT\"}","ref":"Cldr.DateTime.Format.html#gmt_zero_format/2-example"},{"type":"function","title":"Cldr.DateTime.Format.hour_format/2","doc":"Returns the positive and negative hour format\nfor a timezone offset for a given locale.","ref":"Cldr.DateTime.Format.html#hour_format/2"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.hour_format/2","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#hour_format/2-arguments"},{"type":"function","title":"Example - Cldr.DateTime.Format.hour_format/2","doc":"iex> Cldr.DateTime.Format.hour_format(:en, MyApp.Cldr)\n    {:ok, {\"+HH:mm\", \"-HH:mm\"}}","ref":"Cldr.DateTime.Format.html#hour_format/2-example"},{"type":"function","title":"Cldr.DateTime.Format.interval_formats/3","doc":"Returns a map of the interval formats for a\ngiven locale and calendar.","ref":"Cldr.DateTime.Format.html#interval_formats/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.interval_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#interval_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.DateTime.Format.interval_formats/3","doc":"Cldr.DateTime.Format.interval_formats(:en, :gregorian, MyApp.Cldr)\n    => {:ok,\n     %{\n       bh: %{b: [\"h B\", \"h B\"], h: [\"h\", \"h B\"]},\n       bhm: %{b: [\"h:mm B\", \"h:mm B\"], h: [\"h:mm\", \"h:mm B\"], m: [\"h:mm\", \"h:mm B\"]},\n       d: %{d: [\"d\", \"d\"]},\n       gy: %{g: [\"y G\", \"y G\"], y: [\"y\", \"y G\"]},\n       ...","ref":"Cldr.DateTime.Format.html#interval_formats/3-examples"},{"type":"macro","title":"Cldr.DateTime.Format.same_types/2","doc":"","ref":"Cldr.DateTime.Format.html#same_types/2"},{"type":"function","title":"Cldr.DateTime.Format.time_formats/3","doc":"Returns a map of the standard time formats for a given locale and calendar.","ref":"Cldr.DateTime.Format.html#time_formats/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.time_formats/3","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0`. The default is `Cldr.get_locale/0`.\n\n* `calendar` is any calendar returned by `Cldr.DateTime.Format.calendars_for/1`\n  The default is `:gregorian`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`.","ref":"Cldr.DateTime.Format.html#time_formats/3-arguments"},{"type":"function","title":"Examples: - Cldr.DateTime.Format.time_formats/3","doc":"iex> Cldr.DateTime.Format.time_formats(:en)\n    {:ok, %Cldr.Time.Formats{\n      full: \"h:mm:ss a zzzz\",\n      long: \"h:mm:ss a z\",\n      medium: \"h:mm:ss a\",\n      short: \"h:mm a\"\n    }}\n\n    iex> Cldr.DateTime.Format.time_formats(:en, :buddhist)\n    {:ok, %Cldr.Time.Formats{\n      full: \"h:mm:ss a zzzz\",\n      long: \"h:mm:ss a z\",\n      medium: \"h:mm:ss a\",\n      short: \"h:mm a\"\n    }}","ref":"Cldr.DateTime.Format.html#time_formats/3-examples"},{"type":"type","title":"Cldr.DateTime.Format.format_id/0","doc":"A format_id is an atom that indexes into the map returned by\n`Cldr.DateTime.Format.date_time_available_formats/3` to\nresolve a format string.","ref":"Cldr.DateTime.Format.html#t:format_id/0"},{"type":"type","title":"Cldr.DateTime.Format.format_skeleton/0","doc":"A format skeleton is a string consisting of [format\nsymbols](https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table)\nwhich is used to find the best match from the list of\nformats returned by `Cldr.DateTime.Format.date_time_available_formats/3`","ref":"Cldr.DateTime.Format.html#t:format_skeleton/0"},{"type":"type","title":"Cldr.DateTime.Format.standard_formats/0","doc":"The standard formats of `:full`,\n`:long`, `:medium` and `:short` are used\nto resolve standard formats in a locale independent\nway.","ref":"Cldr.DateTime.Format.html#t:standard_formats/0"},{"type":"module","title":"Cldr.DateTime.Format.Compiler","doc":"Tokenizes and parses `Date`, `Time` and `DateTime` format strings.\n\nDuring compilation, each of the date, time and datetime format\nstrings defined in CLDR are compiled into a list of\nfunction bodies that are then grafted onto the function head\n`format/3` in a backend module.  As a result these compiled\nformats execute with good performance.\n\nFor formats not defined in CLDR (ie a user defined format),\nthe tokenizing and parsing is performed, then list of function\nbodies is created and then `format/3`\nrecurses over the list, invoking each function and\ncollecting the results.  This process is significantly slower\nthan that of the precompiled formats.\n\nUser defined formats can also be precompiled by configuring\nthem under the key `:precompile_datetime_formats`.  For example:\n\n    config :ex_cldr,\n      precompile_datetime_formats: [\"yy/dd\", \"hhh:mmm:sss\"]","ref":"Cldr.DateTime.Format.Compiler.html"},{"type":"function","title":"Cldr.DateTime.Format.Compiler.compile/3","doc":"Parse a date, time or datetime format string.","ref":"Cldr.DateTime.Format.Compiler.html#compile/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.Compiler.compile/3","doc":"* `format_string` is a string defining how a date/time/datetime\nis to be formatted.  See `Cldr.DateTime.Formatter` for the list\nof supported format symbols.","ref":"Cldr.DateTime.Format.Compiler.html#compile/3-arguments"},{"type":"function","title":"Returns - Cldr.DateTime.Format.Compiler.compile/3","doc":"Returns a list of function bodies which are grafted onto\na function head in `Cldr.DateTime.Formatter` at compile time\nto produce a series of functions that process a given format\nstring efficiently.","ref":"Cldr.DateTime.Format.Compiler.html#compile/3-returns"},{"type":"function","title":"Cldr.DateTime.Format.Compiler.tokenize/1","doc":"Tokenize a date, time or datetime format string.\n\nThis function is designed to produce output\nthat is fed into `Cldr.DateTime.Format.Compiler.compile/3`.","ref":"Cldr.DateTime.Format.Compiler.html#tokenize/1"},{"type":"function","title":"Arguments - Cldr.DateTime.Format.Compiler.tokenize/1","doc":"* `format_string` is a date, datetime or time format\n  string.","ref":"Cldr.DateTime.Format.Compiler.html#tokenize/1-arguments"},{"type":"function","title":"Returns - Cldr.DateTime.Format.Compiler.tokenize/1","doc":"A list of 3-tuples which represent the tokens\nof the format definition.","ref":"Cldr.DateTime.Format.Compiler.html#tokenize/1-returns"},{"type":"function","title":"Example - Cldr.DateTime.Format.Compiler.tokenize/1","doc":"iex> Cldr.DateTime.Format.Compiler.tokenize(\"yyyy/MM/dd\")\n    {:ok,\n     [{:year, 1, 4}, {:literal, 1, \"/\"}, {:month, 1, 2}, {:literal, 1, \"/\"},\n      {:day_of_month, 1, 2}], 1}","ref":"Cldr.DateTime.Format.Compiler.html#tokenize/1-example"},{"type":"module","title":"Cldr.DateTime.Formatter","doc":"Functions that implement the formatting for each specific\nformat symbol.\n\nEach format symbol is an ASCII character in the\nrange `a-zA-z`.  Although not all characters are used as\nformat symbols, all characters are reserved for that use\nrequiring that literals be enclosed in single quote\ncharacters, for example `'a literal'`.\n\nVariations of each format are defined by repeating the\nformat symbol one or more times.  CLDR typically defines\nan `:abbreviated`, `:wide` and `:narrow` format that is\nreprented by a sequence of 3, 4 or 5 format symbols but\nthis can vary depending on the format symbol.\n\nThe [CLDR standard](http://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table)\ndefines a wide range of format symbols.  Most - but not\nall - of these symbols are supported in `Cldr`.  The supported\nsymbols are described below.","ref":"Cldr.DateTime.Formatter.html"},{"type":"module","title":"Format Symbol Table - Cldr.DateTime.Formatter","doc":"| Element                | Symbol     | Example         | Cldr Format                        |\n| :--------------------  | :--------  | :-------------- | :--------------------------------- |\n| Era                    | G, GG, GGG | \"AD\"            | Abbreviated                        |\n|                        | GGGG       | \"Anno Domini\"   | Wide                               |\n|                        | GGGGG      | \"A\"             | Narrow                             |\n| Year                   | y          | 7               | Minimum necessary digits           |\n|                        | yy         | \"17\"            | Least significant 2 digits         |\n|                        | yyy        | \"017\", \"2017\"   | Padded to at least 3 digits        |\n|                        | yyyy       | \"2017\"          | Padded to at least 4 digits        |\n|                        | yyyyy      | \"02017\"         | Padded to at least 5 digits        |\n| ISOWeek Year           | Y          | 7               | Minimum necessary digits           |\n|                        | YY         | \"17\"            | Least significant 2 digits         |\n|                        | YYY        | \"017\", \"2017\"   | Padded to at least 3 digits        |\n|                        | YYYY       | \"2017\"          | Padded to at least 4 digits        |\n|                        | YYYYY      | \"02017\"         | Padded to at least 5 digits        |\n| Related Gregorian Year | r, rr, rr+ | 2017            | Minimum necessary digits           |\n| Cyclic Year            | U, UU, UUU | \"甲子\"           | Abbreviated                        |\n|                        | UUUU       | \"甲子\" (for now) | Wide                               |\n|                        | UUUUU      | \"甲子\" (for now) | Narrow                             |\n| Extended Year          | u+         | 4601            | Minimum necessary digits           |\n| Quarter                | Q          | 2               | Single digit                       |\n|                        | QQ         | \"02\"            | Two digits                         |\n|                        | QQQ        | \"Q2\"            | Abbreviated                        |\n|                        | QQQQ       | \"2nd quarter\"   | Wide                               |\n|                        | QQQQQ      | \"2\"             | Narrow                             |\n| Standalone Quarter     | q          | 2               | Single digit                       |\n|                        | qq         | \"02\"            | Two digits                         |\n|                        | qqq        | \"Q2\"            | Abbreviated                        |\n|                        | qqqq       | \"2nd quarter\"   | Wide                               |\n|                        | qqqqq      | \"2\"             | Narrow                             |\n| Month                  | M          | 9               | Single digit                       |\n|                        | MM         | \"09\"            | Two digits                         |\n|                        | MMM        | \"Sep\"           | Abbreviated                        |\n|                        | MMMM       | \"September\"     | Wide                               |\n|                        | MMMMM      | \"S\"             | Narrow                             |\n| Standalone Month       | L          | 9               | Single digit                       |\n|                        | LL         | \"09\"            | Two digits                         |\n|                        | LLL        | \"Sep\"           | Abbreviated                        |\n|                        | LLLL       | \"September\"     | Wide                               |\n|                        | LLLLL      | \"S\"             | Narrow                             |\n| Week of Year           | w          | 2, 22           | Single digit                       |\n|                        | ww         | 02, 22          | Two digits, zero padded            |\n| Week of Month          | W          | 2               | Single digit                       |\n| Day of Year            | D          | 3, 33, 333      | Minimum necessary digits           |\n|                        | DD         | 03, 33, 333     | Minimum of 2 digits, zero padded   |\n|                        | DDD        | 003, 033, 333   | Minimum of 3 digits, zero padded   |\n| Day of Month           | d          | 2, 22           | Minimum necessary digits           |\n|                        | dd         | 02, 22          | Two digits, zero padded            |\n|                        | ddd        | 2nd, 25th       | Ordinal day of month               |\n| Day of Week            | E, EE, EEE | \"Tue\"           | Abbreviated                        |\n|                        | EEEE       | \"Tuesday\"       | Wide                               |\n|                        | EEEEE      | \"T\"             | Narrow                             |\n|                        | EEEEEE     | \"Tu\"            | Short                              |\n|                        | e          | 2               | Single digit                       |\n|                        | ee         | \"02\"            | Two digits                         |\n|                        | eee        | \"Tue\"           | Abbreviated                        |\n|                        | eeee       | \"Tuesday\"       | Wide                               |\n|                        | eeeee      | \"T\"             | Narrow                             |\n|                        | eeeeee     | \"Tu\"            | Short                              |\n| Standalone Day of Week | c, cc      | 2               | Single digit                       |\n|                        | ccc        | \"Tue\"           | Abbreviated                        |\n|                        | cccc       | \"Tuesday\"       | Wide                               |\n|                        | ccccc      | \"T\"             | Narrow                             |\n|                        | cccccc     | \"Tu\"            | Short                              |\n| AM or PM               | a, aa, aaa | \"am.\"           | Abbreviated                        |\n|                        | aaaa       | \"am.\"           | Wide                               |\n|                        | aaaaa      | \"am\"            | Narrow                             |\n| Noon, Mid, AM, PM      | b, bb, bbb | \"mid.\"          | Abbreviated                        |\n|                        | bbbb       | \"midnight\"      | Wide                               |\n|                        | bbbbb      | \"md\"            | Narrow                             |\n| Flexible time period   | B, BB, BBB | \"at night\"      | Abbreviated                        |\n|                        | BBBB       | \"at night\"      | Wide                               |\n|                        | BBBBB      | \"at night\"      | Narrow                             |\n| Hour                   | h, K, H, k |                 | See the table below                |\n| Minute                 | m          | 3, 10           | Minimum digits of minutes          |\n|                        | mm         | \"03\", \"12\"      | Two digits, zero padded            |\n| Second                 | s          | 3, 48           | Minimum digits of seconds          |\n|                        | ss         | \"03\", \"48\"      | Two digits, zero padded            |\n| Fractional Seconds     | S          | 3, 48           | Minimum digits of fractional seconds |\n|                        | SS         | \"03\", \"48\"      | Two digits, zero padded            |\n| Milliseconds            | A+         | 4000, 63241     | Minimum digits of milliseconds since midnight |\n| Generic non-location TZ | v         | \"Etc/UTC\"       | `:time_zone` key, unlocalised      |\n|                         | vvvv      | \"unk\"           | Generic timezone name.  Currently returns only \"unk\" |\n| Specific non-location TZ | z..zzz   | \"UTC\"           | `:zone_abbr` key, unlocalised      |\n|                         | zzzz      | \"GMT\"           | Delegates to `zone_gmt/4`          |\n| Timezone ID             | V         | \"unk\"           | `:zone_abbr` key, unlocalised      |\n|                         | VV        | \"Etc/UTC        | Delegates to `zone_gmt/4`          |\n|                         | VVV       | \"Unknown City\"  | Exemplar city.  Not supported.     |\n|                         | VVVV      | \"GMT\"           | Delegates to `zone_gmt/4           |\n| ISO8601 Format          | Z..ZZZ    | \"+0100\"         | ISO8601 Basic Format with hours and minutes |\n|                         | ZZZZ      | \"+01:00\"        | Delegates to `zone_gmt/4           |\n|                         | ZZZZZ     | \"+01:00:10\"     | ISO8601 Extended format with optional seconds |\n| ISO8601 plus Z          | X         | \"+01\"           | ISO8601 Basic Format with hours and optional minutes or \"Z\" |\n|                         | XX        | \"+0100\"         | ISO8601 Basic Format with hours and minutes or \"Z\"          |\n|                         | XXX       | \"+0100\"         | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\" |\n|                         | XXXX      | \"+010059\"       | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\" |\n|                         | XXXXX     | \"+01:00:10\"     | ISO8601 Extended Format with hours and minutes, optional seconds or \"Z\" |\n| ISO8601 minus Z         | x         | \"+0100\"         | ISO8601 Basic Format with hours and optional minutes |\n|                         | xx        | \"-0800\"         | ISO8601 Basic Format with hours and minutes          |\n|                         | xxx       | \"+01:00\"        | ISO8601 Extended Format with hours and minutes       |\n|                         | xxxx      | \"+010059\"       | ISO8601 Basic Format with hours and minutes, optional seconds     |\n|                         | xxxxx     | \"+01:00:10\"     | ISO8601 Extended Format with hours and minutes, optional seconds  |\n| GMT Format              | O         | \"+0100\"         | Short localised GMT format        |\n|                         | OOOO      | \"+010059\"       | Long localised GMT format         |","ref":"Cldr.DateTime.Formatter.html#module-format-symbol-table"},{"type":"module","title":"Formatting symbols for hour of day - Cldr.DateTime.Formatter","doc":"The hour of day can be formatted differently depending whether\na 12- or 24-hour day is being represented and depending on the\nway in which midnight and noon are represented.  The following\ntable illustrates the differences:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   h\t    |  12\t  | 1...11\t|  12\t |   1...11   |  12   |\n|   K\t    |   0\t  | 1...11\t|   0\t |   1...11   |   0   |\n|   H\t    |   0\t  | 1...11\t|  12\t |  13...23   |   0   |\n|   k\t    |  24\t  | 1...11\t|  12\t |  13...23   |  24   |","ref":"Cldr.DateTime.Formatter.html#module-formatting-symbols-for-hour-of-day"},{"type":"function","title":"Cldr.DateTime.Formatter.cyclic_year/3","doc":"Returns the cyclic year (format symbol `U`) name for\nnon-gregorian calendars.\n\n**NOTE: In the current implementation, the cyclic year is\ndelegated to `Cldr.DateTime.Formatter.year/3`\n(format symbol `y`) and does not return a localized\ncyclic year.**","ref":"Cldr.DateTime.Formatter.html#cyclic_year/3"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.cyclic_year/3","doc":"| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| U, UU, UUU | \"甲子\"           | Abbreviated     |\n| UUUU       | \"甲子\" (for now) | Wide            |\n| UUUUU      | \"甲子\" (for now) | Narrow          |\n\nCalendars such as the Chinese lunar\ncalendar (and related calendars) and the Hindu calendars\nuse 60-year cycles of year names. If the calendar does\nnot provide cyclic year name data, or if the year value\nto be formatted is out of the range of years for which\ncyclic name data is provided, then numeric formatting\nis used (behaves like format symbol `y`).\n\nCurrently the CLDR data only provides abbreviated names,\nwhich will be used for all requested name widths.","ref":"Cldr.DateTime.Formatter.html#cyclic_year/3-format-symbol"},{"type":"function","title":"Cldr.DateTime.Formatter.cyclic_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#cyclic_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.date/3","doc":"Returns a formatted date.\n\nDateTime formats are defined in CLDR using substitution rules whereby\nthe Date and/or Time are substituted into a format string.  Therefore\nthis function crafts a date format string which is then inserted into\nthe overall format being requested.","ref":"Cldr.DateTime.Formatter.html#date/3"},{"type":"function","title":"Cldr.DateTime.Formatter.date/5","doc":"","ref":"Cldr.DateTime.Formatter.html#date/5"},{"type":"function","title":"Cldr.DateTime.Formatter.day_name/3","doc":"Returns the weekday name (format  symbol `E`) as an string.","ref":"Cldr.DateTime.Formatter.html#day_name/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.day_name/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 6 that determines the format of\n  the day of week\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `day_name/4`","ref":"Cldr.DateTime.Formatter.html#day_name/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.day_name/3","doc":"The representation of the day name is made in accordance with\nthe following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| E, EE, EEE | \"Tue\"           | Abbreviated     |\n| EEEE       | \"Tuesday\"       | Wide            |\n| EEEEE      | \"T\"             | Narrow          |\n| EEEEEE     | \"Tu\"            | Short           |","ref":"Cldr.DateTime.Formatter.html#day_name/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.day_name/3","doc":"iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 6\n    \"Tu\"\n\n    iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 5\n    \"T\"\n\n    iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 4\n    \"Tuesday\"\n\n    iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 3\n    \"Tue\"\n\n    iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 2\n    \"Tue\"\n\n    iex> Cldr.DateTime.Formatter.day_name ~D[2017-08-15], 1\n    \"Tue\"","ref":"Cldr.DateTime.Formatter.html#day_name/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.day_name/5","doc":"","ref":"Cldr.DateTime.Formatter.html#day_name/5"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_month/3","doc":"Returns the day of the month (symbol `d`) as an integer.","ref":"Cldr.DateTime.Formatter.html#day_of_month/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.day_of_month/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 2 that determines the format of\n  the day of month\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `day_of_month/4`","ref":"Cldr.DateTime.Formatter.html#day_of_month/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.day_of_month/3","doc":"The representation of the day of the month is made in accordance\nwith the following table. Note that `ddd` is not part of the CLDR\nstandard.\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| d          | 2, 22           |                 |\n| dd         | 02, 22          |                 |\n| ddd        | 2nd, 22nd       |                 |","ref":"Cldr.DateTime.Formatter.html#day_of_month/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.day_of_month/3","doc":"iex> Cldr.DateTime.Formatter.day_of_month ~D[2017-01-04], 1\n    4\n\n    iex> Cldr.DateTime.Formatter.day_of_month ~D[2017-01-04], 2\n    \"04\"\n\n    iex> Cldr.DateTime.Formatter.day_of_month ~D[2017-01-04], 3\n    \"4th\"","ref":"Cldr.DateTime.Formatter.html#day_of_month/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_month/5","doc":"","ref":"Cldr.DateTime.Formatter.html#day_of_month/5"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_week/3","doc":"Returns the local day of week (format symbol `e`) as a\nnumber or name.","ref":"Cldr.DateTime.Formatter.html#day_of_week/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.day_of_week/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 6 that determines the format of\n  the day of week\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `day_of_week/4`","ref":"Cldr.DateTime.Formatter.html#day_of_week/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.day_of_week/3","doc":"Returns the same as format symbol `E` except that it adds a\nnumeric value that will depend on the local starting day\nof the week.","ref":"Cldr.DateTime.Formatter.html#day_of_week/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.day_of_week/3","doc":"The representation of the time period is made in accordance with\nthe following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| e          | 2               | Single digit    |\n| ee         | \"02\"            | Two digits      |\n| eee        | \"Tue\"           | Abbreviated     |\n| eeee       | \"Tuesday\"       | Wide            |\n| eeeee      | \"T\"             | Narrow          |\n| eeeeee     | \"Tu\"            | Short           |","ref":"Cldr.DateTime.Formatter.html#day_of_week/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.day_of_week/3","doc":"iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 3\n    \"Tue\"\n\n    iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 4\n    \"Tuesday\"\n\n    iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 5\n    \"T\"\n\n    iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 6\n    \"Tu\"\n\n    iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 1\n    \"2\"\n\n    iex> Cldr.DateTime.Formatter.day_of_week ~D[2017-08-15], 2\n    \"02\"","ref":"Cldr.DateTime.Formatter.html#day_of_week/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_week/5","doc":"","ref":"Cldr.DateTime.Formatter.html#day_of_week/5"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_year/3","doc":"Returns the day of the year (symbol `D`) as an integer in string\nformat.","ref":"Cldr.DateTime.Formatter.html#day_of_year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.day_of_year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 3 that determines the format of\n  the day of year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `day_of_year/4`","ref":"Cldr.DateTime.Formatter.html#day_of_year/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.day_of_year/3","doc":"The representation of the day of the year is made in accordance with\nthe following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| D          | 3, 33, 333      |                 |\n| DD         | 03, 33, 333     |                 |\n| DDD        | 003, 033, 333   |                 |","ref":"Cldr.DateTime.Formatter.html#day_of_year/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.day_of_year/3","doc":"iex> Cldr.DateTime.Formatter.day_of_year ~D[2017-01-15], 1\n    \"15\"\n\n    iex> Cldr.DateTime.Formatter.day_of_year ~D[2017-01-15], 2\n    \"15\"\n\n    iex> Cldr.DateTime.Formatter.day_of_year ~D[2017-01-15], 3\n    \"015\"","ref":"Cldr.DateTime.Formatter.html#day_of_year/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.day_of_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#day_of_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.era/3","doc":"Returns the `era` (format symbol `G`) of a date\nfor given locale.","ref":"Cldr.DateTime.Formatter.html#era/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.era/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  The only applicable\n  option is `:era` with a value of either `nil` (the default) or\n  `:variant` which will return the variant form of an era if one\n  is available.","ref":"Cldr.DateTime.Formatter.html#era/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.era/3","doc":"The representation of the era is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format                 |\n| :--------  | :-------------- | :---------------------------|\n| G, GG, GGG | \"AD\"            | Abbreviated                 |\n| GGGG       | \"Anno Domini    | Wide                        |\n| GGGGG      | \"A\"             | Narrow                      |","ref":"Cldr.DateTime.Formatter.html#era/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.era/3","doc":"iex> Cldr.DateTime.Formatter.era(~D[2017-12-01], 1)\n    \"AD\"\n\n    iex> Cldr.DateTime.Formatter.era(~D[2017-12-01], 4, \"fr\", MyApp.Cldr)\n    \"après Jésus-Christ\"\n\n    iex> Cldr.DateTime.Formatter.era(~D[2017-12-01], 4, \"fr\", MyApp.Cldr, era: :variant)\n    \"de l’ère commune\"","ref":"Cldr.DateTime.Formatter.html#era/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.era/5","doc":"","ref":"Cldr.DateTime.Formatter.html#era/5"},{"type":"function","title":"Cldr.DateTime.Formatter.extended_year/3","doc":"Returns the Extended year (format symbol `u`).","ref":"Cldr.DateTime.Formatter.html#extended_year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.extended_year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `weeK_aligned_year/4`\n\n**NOTE: This current implementation always returns\nthe year provided in the supplied date.  This means\n`u` returns the same result as the format `y`.**","ref":"Cldr.DateTime.Formatter.html#extended_year/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.extended_year/3","doc":"| Symbol     | Example         | Cldr Format               |\n| :--------  | :-------------- | :------------------------ |\n| u+         | 4601            | Minimum necessary digits  |\n\nThis is a single number designating the year of this\ncalendar system, encompassing all supra-year fields.\n\nFor example, for the Julian calendar system, year\nnumbers are positive, with an era of BCE or CE. An\nextended year value for the Julian calendar system\nassigns positive values to CE years and negative\nvalues to BCE years, with 1 BCE being year 0.\n\nFor `u`, all field lengths specify a minimum number of\ndigits; there is no special interpretation for `uu`.","ref":"Cldr.DateTime.Formatter.html#extended_year/3-format-symbol"},{"type":"function","title":"Cldr.DateTime.Formatter.extended_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#extended_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.fractional_second/3","doc":"Returns the `:second` of a `time` or `datetime` (format symbol `S`) as float\nin string format. The seconds are calculate to include microseconds if they\nare available.  The number of `S`'s in the format determines the formatting.","ref":"Cldr.DateTime.Formatter.html#fractional_second/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.fractional_second/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:second`\n  with and optional `:microsecond` key of the format used by `Time`\n\n* `n` is the number of fractional digits to which the float number of seconds\n  is rounded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `fractional_second/4`","ref":"Cldr.DateTime.Formatter.html#fractional_second/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.fractional_second/3","doc":"The representation of the `second` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                           |\n| :----  | :--------- | :---------------------------------------------------- |\n| S      | \"4.0\"      | Minimum digits of fractional seconds                  |\n| SS     | \"4.00\"     | Number of seconds zero-padded to 2 fractional digits  |\n| SSS    | \"4.002\"    | Number of seconds zero-padded to 3 fractional digits  |","ref":"Cldr.DateTime.Formatter.html#fractional_second/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.fractional_second/3","doc":"iex> Cldr.DateTime.Formatter.fractional_second %{second: 4, microsecond: {2000, 3}}, 1\n    \"4.0\"\n\n    iex> Cldr.DateTime.Formatter.fractional_second %{second: 4, microsecond: {2000, 3}}, 3\n    \"4.002\"\n\n    iex> Cldr.DateTime.Formatter.fractional_second %{second: 4}, 1\n    \"4\"","ref":"Cldr.DateTime.Formatter.html#fractional_second/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.fractional_second/5","doc":"","ref":"Cldr.DateTime.Formatter.html#fractional_second/5"},{"type":"function","title":"Cldr.DateTime.Formatter.h11/3","doc":"Returns the formatting of the `:hour` (format symbol `K`) as a number in the\nrange 0..11 as a string.","ref":"Cldr.DateTime.Formatter.html#h11/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.h11/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:hour`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `h11/4`","ref":"Cldr.DateTime.Formatter.html#h11/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.h11/3","doc":"The representation of the `hour` is made in accordance with the following\ntable:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   K     |   0   | 1...11  |   0  |  1...11    |   0   |","ref":"Cldr.DateTime.Formatter.html#h11/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.h11/3","doc":"iex> Cldr.DateTime.Formatter.h11 %{hour: 0}\n    \"0\"\n\n    iex> Cldr.DateTime.Formatter.h11 %{hour: 12}\n    \"0\"\n\n    iex> Cldr.DateTime.Formatter.h11 %{hour: 24}\n    \"0\"\n\n    iex> Cldr.DateTime.Formatter.h11 %{hour: 23}\n    \"11\"\n\n    iex> Cldr.DateTime.Formatter.h11 %{hour: 11}\n    \"11\"\n\n    iex> Cldr.DateTime.Formatter.h11 %{hour: 9}\n    \"9\"","ref":"Cldr.DateTime.Formatter.html#h11/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.h11/5","doc":"","ref":"Cldr.DateTime.Formatter.html#h11/5"},{"type":"function","title":"Cldr.DateTime.Formatter.h12/3","doc":"Returns the formatting of the `:hour` (format symbol `h`) as a number in the\nrange 1..12 as a string.","ref":"Cldr.DateTime.Formatter.html#h12/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.h12/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:hour`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `h12/4`","ref":"Cldr.DateTime.Formatter.html#h12/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.h12/3","doc":"The representation of the `hour` is made in accordance with the following\ntable:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   h     |  12   | 1...11  |  12  |  1...11    |  12   |","ref":"Cldr.DateTime.Formatter.html#h12/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.h12/3","doc":"iex> Cldr.DateTime.Formatter.h12 %{hour: 0}\n    \"12\"\n\n    iex> Cldr.DateTime.Formatter.h12 %{hour: 12}\n    \"12\"\n\n    iex> Cldr.DateTime.Formatter.h12 %{hour: 24}\n    \"12\"\n\n    iex> Cldr.DateTime.Formatter.h12 %{hour: 11}\n    \"11\"\n\n    iex> Cldr.DateTime.Formatter.h12 %{hour: 23}\n    \"11\"","ref":"Cldr.DateTime.Formatter.html#h12/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.h12/5","doc":"","ref":"Cldr.DateTime.Formatter.html#h12/5"},{"type":"function","title":"Cldr.DateTime.Formatter.h23/3","doc":"Returns the formatting of the `:hour` (format symbol `H`) as a number\nin the range 0..23 as a string.","ref":"Cldr.DateTime.Formatter.html#h23/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.h23/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:hour`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `h23/4`","ref":"Cldr.DateTime.Formatter.html#h23/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.h23/3","doc":"The representation of the `hour` is made in accordance with the following\ntable:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   H     |   0   | 1...11  |  12  |  13...23   |   0   |","ref":"Cldr.DateTime.Formatter.html#h23/3-format-symbol"},{"type":"function","title":"Examples: - Cldr.DateTime.Formatter.h23/3","doc":"iex> Cldr.DateTime.Formatter.h23 %{hour: 10}\n    \"10\"\n\n    iex> Cldr.DateTime.Formatter.h23 %{hour: 13}\n    \"13\"\n\n    iex> Cldr.DateTime.Formatter.h23 %{hour: 21}\n    \"21\"\n\n    iex> Cldr.DateTime.Formatter.h23 %{hour: 24}\n    \"0\"\n\n    iex> Cldr.DateTime.Formatter.h23 %{hour: 0}\n    \"0\"","ref":"Cldr.DateTime.Formatter.html#h23/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.h23/5","doc":"","ref":"Cldr.DateTime.Formatter.html#h23/5"},{"type":"function","title":"Cldr.DateTime.Formatter.h24/3","doc":"Returns the formatting of the `:hour` (format symbol `k`) as a number in the\nrange 1..24 as a string.","ref":"Cldr.DateTime.Formatter.html#h24/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.h24/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:hour`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `h24/4`","ref":"Cldr.DateTime.Formatter.html#h24/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.h24/3","doc":"The representation of the `hour` is made in accordance with the following\ntable:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   k     |  24   | 1...11  |  12  |  13...23   |  24   |","ref":"Cldr.DateTime.Formatter.html#h24/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.h24/3","doc":"iex(4)> Cldr.DateTime.Formatter.h24 %{hour: 0}\n    \"24\"\n\n    iex(5)> Cldr.DateTime.Formatter.h24 %{hour: 12}\n    \"12\"\n\n    iex(6)> Cldr.DateTime.Formatter.h24 %{hour: 13}\n    \"13\"\n\n    iex(7)> Cldr.DateTime.Formatter.h24 %{hour: 9}\n    \"9\"\n\n    iex(8)> Cldr.DateTime.Formatter.h24 %{hour: 24}\n    \"24\"","ref":"Cldr.DateTime.Formatter.html#h24/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.h24/5","doc":"","ref":"Cldr.DateTime.Formatter.html#h24/5"},{"type":"macro","title":"Cldr.DateTime.Formatter.has_year_and_month/1","doc":"","ref":"Cldr.DateTime.Formatter.html#has_year_and_month/1"},{"type":"function","title":"Cldr.DateTime.Formatter.hour/3","doc":"Returns the hour formatted in a locale-specific format","ref":"Cldr.DateTime.Formatter.html#hour/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.hour/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:hour`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `hour/4`","ref":"Cldr.DateTime.Formatter.html#hour/3-arguments"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.hour/3","doc":"iex> Cldr.DateTime.Formatter.hour ~N[2020-04-25 15:00:00.0]\n    \"3\"\n\n    iex> Cldr.DateTime.Formatter.hour ~N[2020-04-25 15:00:00.0], locale: \"fr\"\n    \"15\"\n\n    iex> Cldr.DateTime.Formatter.hour ~N[2020-04-25 15:00:00.0], locale: \"en-AU\"\n    \"3\"\n\n    iex> Cldr.DateTime.Formatter.hour ~N[2020-04-25 15:00:00.0], locale: \"en-AU-u-hc-h23\"\n    \"15\"","ref":"Cldr.DateTime.Formatter.html#hour/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.hour/5","doc":"","ref":"Cldr.DateTime.Formatter.html#hour/5"},{"type":"macro","title":"Cldr.DateTime.Formatter.is_time/1","doc":"","ref":"Cldr.DateTime.Formatter.html#is_time/1"},{"type":"function","title":"Cldr.DateTime.Formatter.literal/3","doc":"Returns a literal.","ref":"Cldr.DateTime.Formatter.html#literal/3"},{"type":"function","title":"Example - Cldr.DateTime.Formatter.literal/3","doc":"iex> Cldr.DateTime.Formatter.literal %{time_zone:\n    ...>   \"Etc/UTC\", utc_offset: 0, std_offset: 0}, \"A literal\"\n    \"A literal\"","ref":"Cldr.DateTime.Formatter.html#literal/3-example"},{"type":"function","title":"Cldr.DateTime.Formatter.literal/5","doc":"","ref":"Cldr.DateTime.Formatter.html#literal/5"},{"type":"function","title":"Cldr.DateTime.Formatter.maybe_wrap/3","doc":"","ref":"Cldr.DateTime.Formatter.html#maybe_wrap/3"},{"type":"function","title":"Cldr.DateTime.Formatter.millisecond/3","doc":"Returns the `time` (format symbol `A`) as milliseconds since\nmidnight.","ref":"Cldr.DateTime.Formatter.html#millisecond/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.millisecond/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:second`\n  with and optional `:microsecond` key of the format used by `Time`\n\n* `n` is the number of fractional digits to which the float number of seconds\n  is rounded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `millisecond/4`","ref":"Cldr.DateTime.Formatter.html#millisecond/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.millisecond/3","doc":"The representation of the `milliseconds` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                             |\n| :----  | :--------- | :------------------------------------------------------ |\n| A+     | \"4000\"     | Minimum necessary digits of milliseconds since midnight |","ref":"Cldr.DateTime.Formatter.html#millisecond/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.millisecond/3","doc":"iex> Cldr.DateTime.Formatter.millisecond %{hour: 0, minute: 0,\n    ...>   second: 4, microsecond: {2000, 3}}, 1\n    \"4002\"\n\n    iex> Cldr.DateTime.Formatter.millisecond %{hour: 0, minute: 0, second: 4}, 1\n    \"4000\"\n\n    iex> Cldr.DateTime.Formatter.millisecond %{hour: 10, minute: 10, second: 4}, 1\n    \"36604000\"\n\n    iex> Cldr.DateTime.Formatter.millisecond ~T[07:35:13.215217]\n    \"27313215\"","ref":"Cldr.DateTime.Formatter.html#millisecond/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.millisecond/5","doc":"","ref":"Cldr.DateTime.Formatter.html#millisecond/5"},{"type":"function","title":"Cldr.DateTime.Formatter.minute/3","doc":"Returns the `:minute` of a `time` or `datetime` (format symbol `m`) as number\nin string format.  The number of `m`'s in the format determines the formatting.","ref":"Cldr.DateTime.Formatter.html#minute/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.minute/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:minute`\n\n* `n` is the number of digits to which `:minute` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `minute/4`","ref":"Cldr.DateTime.Formatter.html#minute/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.minute/3","doc":"The representation of the `minute` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                           |\n| :----  | :--------- | :---------------------------------------------------- |\n| m      | 3, 10      | Minimum digits of minutes                             |\n| mm     | \"03\", \"12\" | Number of minutes zero-padded to 2 digits             |","ref":"Cldr.DateTime.Formatter.html#minute/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.minute/3","doc":"iex> Cldr.DateTime.Formatter.minute %{minute: 3}, 1\n    3\n\n    iex> Cldr.DateTime.Formatter.minute %{minute: 3}, 2\n    \"03\"","ref":"Cldr.DateTime.Formatter.html#minute/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.minute/5","doc":"","ref":"Cldr.DateTime.Formatter.html#minute/5"},{"type":"function","title":"Cldr.DateTime.Formatter.month/3","doc":"Returns the `month` (format symbol `M`) of a date\nfor given locale.","ref":"Cldr.DateTime.Formatter.html#month/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.month/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the month\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `month/4`","ref":"Cldr.DateTime.Formatter.html#month/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.month/3","doc":"The representation of the month is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| M          | 9               | Single digit    |\n| MM         | \"09\"            | Two digits      |\n| MMM        | \"Sep\"           | Abbreviated     |\n| MMMM       | \"September\"     | Wide            |\n| MMMMM      | \"S\"             | Narrow          |","ref":"Cldr.DateTime.Formatter.html#month/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.month/3","doc":"iex> Cldr.DateTime.Formatter.month ~D[2019-09-08]\n    \"9\"\n\n    iex> Cldr.DateTime.Formatter.month ~D[2019-09-08], 2\n    \"09\"\n\n    iex> Cldr.DateTime.Formatter.month ~D[2019-09-08], 3\n    \"Sep\"\n\n    iex> Cldr.DateTime.Formatter.month ~D[2019-09-08], 4\n    \"September\"\n\n    iex> Cldr.DateTime.Formatter.month ~D[2019-09-08], 5\n    \"S\"","ref":"Cldr.DateTime.Formatter.html#month/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.month/5","doc":"","ref":"Cldr.DateTime.Formatter.html#month/5"},{"type":"function","title":"Cldr.DateTime.Formatter.period_am_pm/3","doc":"Returns a localised version of `am` or `pm` (format symbol `a`).","ref":"Cldr.DateTime.Formatter.html#period_am_pm/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.period_am_pm/3","doc":"* `time` is a `Time` struct or any map that contains at least the\n  key `:second`\n\n* `n` in an integer between 1 and 5 that determines the format of the\n  time period\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  The available option is\n  `period: :variant` which will use a veriant of localised \"am\" or\n  \"pm\" if one is available","ref":"Cldr.DateTime.Formatter.html#period_am_pm/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.period_am_pm/3","doc":"May be upper or lowercase depending on the locale and other options.\nThe wide form may be the same as the short form if the “real”\nlong form (eg ante meridiem) is not customarily used.","ref":"Cldr.DateTime.Formatter.html#period_am_pm/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.period_am_pm/3","doc":"The representation of the time period is made in accordance with the following\ntable:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| a, aa, aaa | \"am.\"           | Abbreviated     |\n| aaaa       | \"am.\"           | Wide            |\n| aaaaa      | \"am\"            | Narrow          |","ref":"Cldr.DateTime.Formatter.html#period_am_pm/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.period_am_pm/3","doc":"iex> Cldr.DateTime.Formatter.period_am_pm %{hour: 0, minute: 0}\n    \"AM\"\n\n    iex> Cldr.DateTime.Formatter.period_am_pm %{hour: 3, minute: 0}\n    \"AM\"\n\n    iex> Cldr.DateTime.Formatter.period_am_pm %{hour: 13, minute: 0}\n    \"PM\"\n\n    iex> Cldr.DateTime.Formatter.period_am_pm %{hour: 21, minute: 0}, 5\n    \"p\"\n\n    iex> Cldr.DateTime.Formatter.period_am_pm %{hour: 21, minute: 0}, 5\n    \"p\"","ref":"Cldr.DateTime.Formatter.html#period_am_pm/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.period_am_pm/5","doc":"","ref":"Cldr.DateTime.Formatter.html#period_am_pm/5"},{"type":"function","title":"Cldr.DateTime.Formatter.period_flex/3","doc":"Returns the formatting of the time period as a string, for\nexample `at night` (format symbol `B`).","ref":"Cldr.DateTime.Formatter.html#period_flex/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.period_flex/3","doc":"* `time` is a `Time` struct or any map that contains at least the\n  key `:second`\n\n* `n` in an integer between 1 and 5 that determines the format of the\n  time period\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  The available option is\n  `period: :variant` which will use a veriant of localised flexible time\n  period names if one is available","ref":"Cldr.DateTime.Formatter.html#period_flex/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.period_flex/3","doc":"The time period may be upper or lowercase depending on the locale and\nother options.  Often there is only one width that is customarily used.","ref":"Cldr.DateTime.Formatter.html#period_flex/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.period_flex/3","doc":"The representation of the time period is made in accordance with the following\ntable:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| B, BB, BBB | \"at night\"      | Abbreviated     |\n| BBBB       | \"at night\"      | Wide            |\n| BBBBB      | \"at night\"      | Narrow          |","ref":"Cldr.DateTime.Formatter.html#period_flex/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.period_flex/3","doc":"iex> Cldr.DateTime.Formatter.period_flex %{hour: 11, minute: 5, second: 23}\n    \"in the morning\"\n\n    iex> Cldr.DateTime.Formatter.period_flex %{hour: 16, minute: 5, second: 23}\n    \"in the afternoon\"\n\n    iex> Cldr.DateTime.Formatter.period_flex %{hour: 23, minute: 5, second: 23}\n    \"at night\"","ref":"Cldr.DateTime.Formatter.html#period_flex/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.period_flex/5","doc":"","ref":"Cldr.DateTime.Formatter.html#period_flex/5"},{"type":"function","title":"Cldr.DateTime.Formatter.period_noon_midnight/3","doc":"Returns the formatting of the time period as either\n`noon`, `midnight` or `am`/`pm` (format symbol 'b').","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.period_noon_midnight/3","doc":"* `time` is a `Time` struct or any map that contains at least the\n  key `:second`\n\n* `n` in an integer between 1 and 5 that determines the format of the\n  time period\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  The available option is\n  `period: :variant` which will use a variant of localised \"noon\" and\n  \"midnight\" if one is available","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.period_noon_midnight/3","doc":"If the language doesn't support \"noon\" or \"midnight\" then\n`am`/`pm` is used for all time periods.\n\nMay be upper or lowercase depending on the locale and other options.\nIf the locale doesn't have the notion of a unique `noon == 12:00`,\nthen the PM form may be substituted. Similarly for `midnight == 00:00`\nand the AM form.","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.period_noon_midnight/3","doc":"The representation of the time period is made in accordance with the following\ntable:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| b, bb, bbb | \"mid.\"          | Abbreviated     |\n| bbbb       | \"midnight\"      | Wide            |\n| bbbbb      | \"md\"            | Narrow          |","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.period_noon_midnight/3","doc":"iex> Cldr.DateTime.Formatter.period_noon_midnight %{hour: 12, minute: 0}\n    \"noon\"\n\n    iex> Cldr.DateTime.Formatter.period_noon_midnight %{hour: 0, minute: 0}\n    \"midnight\"\n\n    iex> Cldr.DateTime.Formatter.period_noon_midnight %{hour: 11, minute: 0}\n    \"in the morning\"\n\n    iex> Cldr.DateTime.Formatter.period_noon_midnight %{hour: 16, minute: 0}\n    \"PM\"","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.period_noon_midnight/5","doc":"","ref":"Cldr.DateTime.Formatter.html#period_noon_midnight/5"},{"type":"function","title":"Cldr.DateTime.Formatter.quarter/3","doc":"Returns the `quarter` (format symbol `Q`) of a date\nfor given locale.","ref":"Cldr.DateTime.Formatter.html#quarter/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.quarter/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the quarter\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `quarter/5`","ref":"Cldr.DateTime.Formatter.html#quarter/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.quarter/3","doc":"The representation of the quarter is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| Q          | 2               | Single digit    |\n| QQ         | \"02\"            | Two digits      |\n| QQQ        | \"Q2\"            | Abbreviated     |\n| QQQQ       | \"2nd quarter\"   | Wide            |\n| QQQQQ      | \"2\"             | Narrow          |","ref":"Cldr.DateTime.Formatter.html#quarter/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.quarter/3","doc":"iex> Cldr.DateTime.Formatter.quarter ~D[2017-04-01], 1\n    2\n\n    iex> Cldr.DateTime.Formatter.quarter ~D[2017-04-01], 2\n    \"02\"\n\n    iex> Cldr.DateTime.Formatter.quarter ~D[2017-04-01], 3\n    \"Q2\"\n\n    iex> Cldr.DateTime.Formatter.quarter ~D[2017-04-01], 4\n    \"2nd quarter\"\n\n    iex> Cldr.DateTime.Formatter.quarter ~D[2017-04-01], 5\n    \"2\"","ref":"Cldr.DateTime.Formatter.html#quarter/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.quarter/5","doc":"","ref":"Cldr.DateTime.Formatter.html#quarter/5"},{"type":"function","title":"Cldr.DateTime.Formatter.related_year/3","doc":"Returns the related gregorian year (format symbol `r`)\nof a date for given locale.","ref":"Cldr.DateTime.Formatter.html#related_year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.related_year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the quarter\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `related_year/4`","ref":"Cldr.DateTime.Formatter.html#related_year/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.related_year/3","doc":"The representation of the related year is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| r+         | 2017            |                 |\n\nThis corresponds to the extended Gregorian year\nin which the calendar’s year begins. Related\nGregorian years are often displayed, for example,\nwhen formatting dates in the Japanese calendar —\ne.g. “2012(平成24)年1月15日” — or in the Chinese\ncalendar — e.g. “2012壬辰年腊月初四”. The related\nGregorian year is usually displayed using the\n\":latn\" numbering system, regardless of what\nnumbering systems may be used for other parts\nof the formatted date.\n\nIf the calendar’s year is linked to the solar\nyear (perhaps using leap months), then for that\ncalendar the ‘r’ year will always be at a fixed\noffset from the ‘u’ year.\n\nFor the Gregorian calendar, the ‘r’ year\nis the same as the ‘u’ year. For ‘r’, all field\nlengths specify a minimum number of digits; there\nis no special interpretation for “rr”.","ref":"Cldr.DateTime.Formatter.html#related_year/3-format-symbol"},{"type":"function","title":"Cldr.DateTime.Formatter.related_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#related_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.second/3","doc":"Returns the `:second` of a `time` or `datetime` (format symbol `s`) as number\nin string format.  The number of `s`'s in the format determines the formatting.","ref":"Cldr.DateTime.Formatter.html#second/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.second/3","doc":"* `time` is a `Time` struct or any map that contains at least the key `:second`\n\n* `n` is the number of digits to which `:hour` is padded\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `second/4`","ref":"Cldr.DateTime.Formatter.html#second/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.second/3","doc":"The representation of the `second` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                           |\n| :----  | :--------- | :---------------------------------------------------- |\n| s      | 3, 48      | Minimum digits of seconds                             |\n| ss     | \"03\", \"48\" | Number of seconds zero-padded to 2 digits             |","ref":"Cldr.DateTime.Formatter.html#second/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.second/3","doc":"iex> Cldr.DateTime.Formatter.second %{second: 23}, 1\n    \"23\"\n\n    iex> Cldr.DateTime.Formatter.second %{second: 4}, 2\n    \"04\"","ref":"Cldr.DateTime.Formatter.html#second/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.second/5","doc":"","ref":"Cldr.DateTime.Formatter.html#second/5"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_day_of_week/3","doc":"Returns the stand-alone local day (format symbol `c`)\nof week number/name.","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.standalone_day_of_week/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 6 that determines the format of\n  the day of week\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `standalone_day_of_week/4`","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.standalone_day_of_week/3","doc":"This is the same as `weekday_number/4` except that it is intended\nfor use without the associated `d` format symbol.","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.standalone_day_of_week/3","doc":"The representation of the time period is made in accordance with\nthe following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| c, cc      | 2               | Single digit    |\n| ccc        | \"Tue\"           | Abbreviated     |\n| cccc       | \"Tuesday\"       | Wide            |\n| ccccc      | \"T\"             | Narrow          |\n| cccccc     | \"Tu\"            | Short           |","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.standalone_day_of_week/3","doc":"iex> Cldr.DateTime.Formatter.standalone_day_of_week ~D[2017-08-15], 3\n    \"Tue\"\n\n    iex> Cldr.DateTime.Formatter.standalone_day_of_week ~D[2017-08-15], 4\n    \"Tuesday\"\n\n    iex> Cldr.DateTime.Formatter.standalone_day_of_week ~D[2017-08-15], 5\n    \"T\"\n\n    iex> Cldr.DateTime.Formatter.standalone_day_of_week ~D[2017-08-15], 6\n    \"Tu\"","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_day_of_week/5","doc":"","ref":"Cldr.DateTime.Formatter.html#standalone_day_of_week/5"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_month/3","doc":"Returns the `month` (symbol `L`) in standalone format which is\nintended to formatted without an accompanying day (`d`).","ref":"Cldr.DateTime.Formatter.html#standalone_month/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.standalone_month/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the month\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `standalone_month/4`","ref":"Cldr.DateTime.Formatter.html#standalone_month/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.standalone_month/3","doc":"The representation of the standalone month is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| L          | 9               | Single digit    |\n| LL         | \"09\"            | Two digits      |\n| LLL        | \"Sep\"           | Abbreviated     |\n| LLLL       | \"September\"     | Wide            |\n| LLLLL      | \"S\"             | Narrow          |","ref":"Cldr.DateTime.Formatter.html#standalone_month/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.standalone_month/3","doc":"iex> Cldr.DateTime.Formatter.standalone_month ~D[2019-09-08]\n    \"9\"\n\n    iex> Cldr.DateTime.Formatter.standalone_month ~D[2019-09-08], 2\n    \"09\"\n\n    iex> Cldr.DateTime.Formatter.standalone_month ~D[2019-09-08], 3\n    \"Sep\"\n\n    iex> Cldr.DateTime.Formatter.standalone_month ~D[2019-09-08], 4\n    \"September\"\n\n    iex> Cldr.DateTime.Formatter.standalone_month ~D[2019-09-08], 5\n    \"S\"","ref":"Cldr.DateTime.Formatter.html#standalone_month/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_month/5","doc":"","ref":"Cldr.DateTime.Formatter.html#standalone_month/5"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_quarter/3","doc":"Returns the standalone `quarter` (format symbol `a`) of a date\nfor given locale.","ref":"Cldr.DateTime.Formatter.html#standalone_quarter/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.standalone_quarter/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the quarter\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `standalone_quarter/5`","ref":"Cldr.DateTime.Formatter.html#standalone_quarter/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.standalone_quarter/3","doc":"The representation of the quarter is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| q          | 2               | Single digit    |\n| qq         | \"02\"            | Two digits      |\n| qqq        | \"Q2\"            | Abbreviated     |\n| qqqq       | \"2nd quarter\"   | Wide            |\n| qqqqq      | \"2\"             | Narrow          |","ref":"Cldr.DateTime.Formatter.html#standalone_quarter/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.standalone_quarter/3","doc":"iex> Cldr.DateTime.Formatter.standalone_quarter ~D[2019-06-08], 1\n    2\n\n    iex> Cldr.DateTime.Formatter.standalone_quarter ~D[2019-06-08], 2\n    \"02\"\n\n    iex> Cldr.DateTime.Formatter.standalone_quarter ~D[2019-06-08], 3\n    \"Q2\"\n\n    iex> Cldr.DateTime.Formatter.standalone_quarter ~D[2019-06-08], 4\n    \"2nd quarter\"\n\n    iex> Cldr.DateTime.Formatter.standalone_quarter ~D[2019-06-08], 5\n    \"2\"","ref":"Cldr.DateTime.Formatter.html#standalone_quarter/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.standalone_quarter/5","doc":"","ref":"Cldr.DateTime.Formatter.html#standalone_quarter/5"},{"type":"function","title":"Cldr.DateTime.Formatter.time/3","doc":"Returns a formatted time.\n\nDateTime formats are defined in CLDR using substitution rules whereby\nthe Date and/or Time are substituted into a format string.  Therefore\nthis function crafts a time format string which is then inserted into\nthe overall format being requested.","ref":"Cldr.DateTime.Formatter.html#time/3"},{"type":"function","title":"Cldr.DateTime.Formatter.time/5","doc":"","ref":"Cldr.DateTime.Formatter.html#time/5"},{"type":"function","title":"Cldr.DateTime.Formatter.week_aligned_year/3","doc":"Returns the `year` (format symbol `Y`) in “Week of Year”\nbased calendars in which the year transition occurs\non a week boundary.","ref":"Cldr.DateTime.Formatter.html#week_aligned_year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.week_aligned_year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `weeK_aligned_year/4`","ref":"Cldr.DateTime.Formatter.html#week_aligned_year/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.week_aligned_year/3","doc":"The representation of the year is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format                 |\n| :--------  | :-------------- | :---------------------------|\n| Y          | 7               | Minimum necessary digits    |\n| YY         | \"17\"            | Least significant 2 digits  |\n| YYY        | \"017\", \"2017\"   | Padded to at least 3 digits |\n| YYYY       | \"2017\"          | Padded to at least 4 digits |\n| YYYYY      | \"02017\"         | Padded to at least 5 digits |\n\nThe result may differ from calendar year ‘y’ near\na year transition. This numeric year designation\nis used in conjunction with pattern character ‘w’\nin the ISO year-week calendar as defined\nby ISO 8601, but can be used in non-Gregorian based\ncalendar systems where week date processing is desired.\n\nThe field length is interpreted in the same was as for\n`y`; that is, `yy` specifies use of the two low-order\nyear digits, while any other field length specifies a\nminimum number of digits to display.","ref":"Cldr.DateTime.Formatter.html#week_aligned_year/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.week_aligned_year/3","doc":"iex> Cldr.DateTime.Formatter.week_aligned_year ~D[2017-01-04], 1\n    \"2017\"\n\n    iex> Cldr.DateTime.Formatter.week_aligned_year ~D[2017-01-04], 2\n    \"17\"\n\n    iex> Cldr.DateTime.Formatter.week_aligned_year ~D[2017-01-04], 3\n    \"2017\"\n\n    iex> Cldr.DateTime.Formatter.week_aligned_year ~D[2017-01-04], 4\n    \"2017\"\n\n    iex> Cldr.DateTime.Formatter.week_aligned_year ~D[2017-01-04], 5\n    \"02017\"","ref":"Cldr.DateTime.Formatter.html#week_aligned_year/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.week_aligned_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#week_aligned_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.week_of_month/3","doc":"Returns the week of the month (format symbol `W`) as an integer.","ref":"Cldr.DateTime.Formatter.html#week_of_month/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.week_of_month/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between that should be between 1 and 4 that\n  determines the format of the week of the month\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `week_of_month/4`","ref":"Cldr.DateTime.Formatter.html#week_of_month/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.week_of_month/3","doc":"The representation of the week of the month is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| W          | 2               |                 |","ref":"Cldr.DateTime.Formatter.html#week_of_month/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.week_of_month/3","doc":"iex> import Cldr.Calendar.Sigils\n    Cldr.Calendar.Sigils\n    iex> Cldr.DateTime.Formatter.week_of_month ~D[2019-01-07], 1\n    \"2\"\n    iex> Cldr.DateTime.Formatter.week_of_month ~d[2019-W04-1], 1\n    \"4\"","ref":"Cldr.DateTime.Formatter.html#week_of_month/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.week_of_month/5","doc":"","ref":"Cldr.DateTime.Formatter.html#week_of_month/5"},{"type":"function","title":"Cldr.DateTime.Formatter.week_of_year/3","doc":"Returns the week of the year (symbol `w`) as an integer.","ref":"Cldr.DateTime.Formatter.html#week_of_year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.week_of_year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:year`, `:month`, `:day` and `:calendar`\n\n* `n` in an integer between 1 and 2 that determines the format of\n  the week of the year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `week_of_year/4`","ref":"Cldr.DateTime.Formatter.html#week_of_year/3-arguments"},{"type":"function","title":"Notes - Cldr.DateTime.Formatter.week_of_year/3","doc":"Determining the week of the year is influenced\nby two factors:\n\n1. The calendar in use.  For example the ISO calendar (which\nis the default calendar in Elixir) follows the ISO standard\nin which the first week of the year is the week containing\nthe first thursday of the year.\n\n2. The territory in use.  For example, in the US the first\nweek of the year is the week containing January 1st whereas\nmany territories follow the ISO standard.","ref":"Cldr.DateTime.Formatter.html#week_of_year/3-notes"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.week_of_year/3","doc":"The representation of the day of the year is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format     |\n| :--------  | :-------------- | :-------------- |\n| w          | 2, 22           |                 |\n| ww         | 02, 22          |                 |","ref":"Cldr.DateTime.Formatter.html#week_of_year/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.week_of_year/3","doc":"iex> import Cldr.Calendar.Sigils\n    Cldr.Calendar.Sigils\n    iex> Cldr.DateTime.Formatter.week_of_year ~D[2019-01-07], 1\n    \"2\"\n    iex> Cldr.DateTime.Formatter.week_of_year ~d[2019-W04-1], 2\n    \"04\"","ref":"Cldr.DateTime.Formatter.html#week_of_year/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.week_of_year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#week_of_year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.year/3","doc":"Returns the `year` (format symbol `y`) of a date\nas an integer. The `y` format returns the year\nas a simple integer in string format.\n\nThe format `yy` is a special case which requests just\nthe two low-order digits of the year, zero-padded\nas necessary. For most use cases, `y` or `yy` should\nbe adequate.","ref":"Cldr.DateTime.Formatter.html#year/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.year/3","doc":"* `date` is a `Date` struct or any map that contains at least the\n  keys `:month` and `:calendar`\n\n* `n` in an integer between 1 and 5 that determines the format of\n  the year\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options\n  used in `year/4`","ref":"Cldr.DateTime.Formatter.html#year/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.year/3","doc":"The representation of the quarter is made in accordance\nwith the following table:\n\n| Symbol     | Example         | Cldr Format                 |\n| :--------  | :-------------- | :---------------------------|\n| y          | 7               | Minimum necessary digits    |\n| yy         | \"17\"            | Least significant 2 digits  |\n| yyy        | \"017\", \"2017\"   | Padded to at least 3 digits |\n| yyyy       | \"2017\"          | Padded to at least 4 digits |\n| yyyyy      | \"02017\"         | Padded to at least 5 digits |\n\nIn most cases the length of the `y` field specifies\nthe minimum number of   digits to display, zero-padded\nas necessary; more digits will be displayed if needed\nto show the full year.","ref":"Cldr.DateTime.Formatter.html#year/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.year/3","doc":"iex> Cldr.DateTime.Formatter.year %{year: 2017, calendar: Calendar.ISO}, 1\n    2017\n\n    iex> Cldr.DateTime.Formatter.year %{year: 2017, calendar: Calendar.ISO}, 2\n    \"17\"\n\n    iex> Cldr.DateTime.Formatter.year %{year: 2017, calendar: Calendar.ISO}, 3\n    \"2017\"\n\n    iex> Cldr.DateTime.Formatter.year %{year: 2017, calendar: Calendar.ISO}, 4\n    \"2017\"\n\n    iex> Cldr.DateTime.Formatter.year %{year: 2017, calendar: Calendar.ISO}, 5\n    \"02017\"","ref":"Cldr.DateTime.Formatter.html#year/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.year/5","doc":"","ref":"Cldr.DateTime.Formatter.html#year/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_basic/3","doc":"Returns the basic zone offset (format symbol `Z`) part of a `DateTime` or `Time`,\n\nThe ISO8601 basic format with hours, minutes and optional seconds fields.\nThe format is equivalent to RFC 822 zone format (when optional seconds field\nis absent). This is equivalent to the \"xxxx\" specifier.","ref":"Cldr.DateTime.Formatter.html#zone_basic/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_basic/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:utc_offset`\n  and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `zone_basic/4`","ref":"Cldr.DateTime.Formatter.html#zone_basic/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_basic/3","doc":"The representation of the `timezone` is made in accordance with the following\ntable:\n\n| Symbol | Results        | Description                                             |\n| :----  | :------------- | :------------------------------------------------------ |\n| Z..ZZZ | \"+0100\"        | ISO8601 Basic Format with hours and minutes             |\n| ZZZZ   | \"+01:00\"       | Delegates to `zone_gmt/4                                |\n| ZZZZZ  | \"+01:00:10\"    | ISO8601 Extended format with optional seconds           |","ref":"Cldr.DateTime.Formatter.html#zone_basic/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_basic/3","doc":"iex> Cldr.DateTime.Formatter.zone_basic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3600, std_offset: 0}, 1\n    \"+0100\"\n\n    iex> Cldr.DateTime.Formatter.zone_basic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 4\n    \"GMT+01:00\"\n\n    iex> Cldr.DateTime.Formatter.zone_basic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 5\n    \"Z\"\n\n    iex> Cldr.DateTime.Formatter.zone_basic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 5\n    \"+01:00:10\"","ref":"Cldr.DateTime.Formatter.html#zone_basic/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_basic/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_basic/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_generic/3","doc":"Returns the generic non-location format of a timezone (format symbol `v`)\nfrom a `DateTime` or `Time`.\n\nSince Elixir does not provide full time zone support, we return here only\nthe `:time_zone` element of the provided `DateTime` or other struct without\nany localization.","ref":"Cldr.DateTime.Formatter.html#zone_generic/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_generic/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the key `:time_zone`\n  key of the format used by `Time`\n\n* `n` is the generic non-location timezone format and is either `1` (the\n  default) or `4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `zone_generic/4`","ref":"Cldr.DateTime.Formatter.html#zone_generic/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_generic/3","doc":"The representation of the `timezone` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                             |\n| :----  | :--------- | :------------------------------------------------------ |\n| v      | \"Etc/UTC\"  | `:time_zone` key, unlocalised                           |\n| vvvv   | \"unk\"      | Generic timezone name.  Currently returns only \"unk\"    |","ref":"Cldr.DateTime.Formatter.html#zone_generic/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_generic/3","doc":"iex> Cldr.DateTime.Formatter.zone_generic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 4\n    \"GMT\"\n\n    iex> Cldr.DateTime.Formatter.zone_generic %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 1\n    \"Etc/UTC\"","ref":"Cldr.DateTime.Formatter.html#zone_generic/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_generic/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_generic/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_gmt/3","doc":"Returns the short localised GMT offset (format symbol `O`) part of a\n`DateTime` or `Time`.","ref":"Cldr.DateTime.Formatter.html#zone_gmt/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_gmt/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:utc_offset`\n  and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `zone_gmt/4`","ref":"Cldr.DateTime.Formatter.html#zone_gmt/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_gmt/3","doc":"The representation of the `GMT offset` is made in accordance with the following\ntable:\n\n| Symbol | Results        | Description                                                     |\n| :----  | :------------- | :-------------------------------------------------------------- |\n| O      | \"GMT+1\"        | Short localised GMT format                                      |\n| OOOO   | \"GMT+01:00\"    | Long localised GMT format                                       |","ref":"Cldr.DateTime.Formatter.html#zone_gmt/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_gmt/3","doc":"iex> Cldr.DateTime.Formatter.zone_gmt %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 1\n    \"GMT+1\"\n\n    iex> Cldr.DateTime.Formatter.zone_gmt %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 4\n    \"GMT+01:00\"","ref":"Cldr.DateTime.Formatter.html#zone_gmt/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_gmt/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_gmt/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_id/3","doc":"Returns the time zone ID (format symbol `V`) part of a `DateTime` or `Time`\n\nFor now the short timezone name, exemplar city and generic location\nformats are not supported and therefore return the fallbacks defined in CLDR.","ref":"Cldr.DateTime.Formatter.html#zone_id/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_id/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:utc_offset`\n  and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n `zone_id/4`","ref":"Cldr.DateTime.Formatter.html#zone_id/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_id/3","doc":"The representation of the `timezone ID` is made in accordance with the following\ntable:\n\n| Symbol | Results        | Description                                             |\n| :----  | :------------- | :------------------------------------------------------ |\n| V      | \"unk\"          | `:zone_abbr` key, unlocalised                           |\n| VV     | \"Etc/UTC       | Delegates to `zone_gmt/4`                               |\n| VVV    | \"Unknown City\" | Examplar city.  Not supported.                          |\n| VVVV   | \"GMT\"          | Delegates to `zone_gmt/4                                |","ref":"Cldr.DateTime.Formatter.html#zone_id/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_id/3","doc":"iex> Cldr.DateTime.Formatter.zone_id %{zone_abbr: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 1\n    \"unk\"\n\n    iex> Cldr.DateTime.Formatter.zone_id %{zone_abbr: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 2\n    \"Etc/UTC\"\n\n    iex> Cldr.DateTime.Formatter.zone_id %{zone_abbr: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 3\n    \"Unknown City\"\n\n    iex> Cldr.DateTime.Formatter.zone_id %{zone_abbr: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 4\n    \"GMT\"","ref":"Cldr.DateTime.Formatter.html#zone_id/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_id/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_id/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_iso/3","doc":"Returns the ISO zone offset (format symbol `x`) part of a `DateTime` or `Time`,\n\nThis is the ISO8601 format with hours, minutes and optional seconds fields but\nwith no \"Z\" as the identifier if the timezone offset is 0.","ref":"Cldr.DateTime.Formatter.html#zone_iso/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_iso/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:utc_offset`\n  and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `zone_iso/4`","ref":"Cldr.DateTime.Formatter.html#zone_iso/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_iso/3","doc":"The representation of the `timezone offset` is made in accordance with the following\ntable:\n\n| Symbol | Results        | Description                                                       |\n| :----  | :------------- | :---------------------------------------------------------------- |\n| x      | \"+0100\"        | ISO8601 Basic Format with hours and optional minutes              |\n| xx     | \"-0800\"        | ISO8601 Basic Format with hours and minutes                       |\n| xxx    | \"+01:00\"       | ISO8601 Extended Format with hours and minutes                    |\n| xxxx   | \"+010059\"      | ISO8601 Basic Format with hours and minutes, optional seconds     |\n| xxxxx  | \"+01:00:10\"    | ISO8601 Extended Format with hours and minutes, optional seconds  |","ref":"Cldr.DateTime.Formatter.html#zone_iso/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_iso/3","doc":"iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 1\n    \"+01\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 2\n    \"+0100\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 3\n    \"+01:00\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 4\n    \"+010010\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 5\n    \"+01:00:10\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 5\n    \"+00:00\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 4\n    \"+0000\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 3\n    \"+00:00\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 2\n    \"+0000\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 1\n    \"+00\"","ref":"Cldr.DateTime.Formatter.html#zone_iso/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_iso/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_iso/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_iso_z/3","doc":"Returns the ISO zone offset (format symbol `X`) part of a `DateTime` or `Time`,\n\nThis is the ISO8601 format with hours, minutes and optional seconds fields with\n\"Z\" as the identifier if the timezone offset is 0.","ref":"Cldr.DateTime.Formatter.html#zone_iso_z/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_iso_z/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:utc_offset`\n  and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n  `zone_iso_z/4`","ref":"Cldr.DateTime.Formatter.html#zone_iso_z/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_iso_z/3","doc":"The representation of the `timezone offset` is made in accordance with the following\ntable:\n\n| Symbol | Results        | Description                                                              |\n| :----  | :------------- | :----------------------------------------------------------------------- |\n| X      | \"+01\"          | ISO8601 Basic Format with hours and optional minutes or \"Z\"              |\n| XX     | \"+0100\"        | ISO8601 Basic Format with hours and minutes or \"Z\"                       |\n| XXX    | \"+0100\"        | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\"     |\n| XXXX   | \"+010059\"      | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\"     |\n| XXXXX  | \"+01:00:10\"    | ISO8601 Extended Format with hours and minutes, optional seconds or \"Z\"  |","ref":"Cldr.DateTime.Formatter.html#zone_iso_z/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_iso_z/3","doc":"iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 1\n    \"+01\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 2\n    \"+0100\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 3\n    \"+01:00:10\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 4\n    \"+010010\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 3610, std_offset: 0}, 5\n    \"+01:00:10\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 5\n    \"Z\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 4\n    \"Z\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 3\n    \"Z\"\n\n    iex> Cldr.DateTime.Formatter.zone_iso_z %{time_zone: \"Etc/UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 2\n    \"Z\"","ref":"Cldr.DateTime.Formatter.html#zone_iso_z/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_iso_z/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_iso_z/5"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_short/3","doc":"Returns the specific non-location format of a timezone (format symbol `z`)\nfrom a `DateTime` or `Time`.\n\nSince Elixir does not provide full time zone support, we return here only\nthe `:time_zone` element of the provided `DateTime` or other struct without\nany localization.","ref":"Cldr.DateTime.Formatter.html#zone_short/3"},{"type":"function","title":"Arguments - Cldr.DateTime.Formatter.zone_short/3","doc":"* `time` is a `t:DateTime.t/0` struct or any map that contains at least the `:zone_abbr`,\n`:utc_offset` and `:std_offset` keys of the format used by `Time`\n\n* `n` is the specific non-location timezone format and is in the range `1..4`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag.t/0` struct. The default is `Cldr.get_locale/0`\n\n* `options` is a `Keyword` list of options.  There are no options used in\n `zone_short/4`","ref":"Cldr.DateTime.Formatter.html#zone_short/3-arguments"},{"type":"function","title":"Format Symbol - Cldr.DateTime.Formatter.zone_short/3","doc":"The representation of the `timezone` is made in accordance with the following\ntable:\n\n| Symbol | Results    | Description                                             |\n| :----  | :--------- | :------------------------------------------------------ |\n| z..zzz | \"UTC\"      | `:zone_abbr` key, unlocalised                           |\n| zzzz   | \"GMT\"      | Delegates to `zone_gmt/4`                               |","ref":"Cldr.DateTime.Formatter.html#zone_short/3-format-symbol"},{"type":"function","title":"Examples - Cldr.DateTime.Formatter.zone_short/3","doc":"iex> Cldr.DateTime.Formatter.zone_short %{zone_abbr: \"UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 1\n    \"UTC\"\n\n    iex> Cldr.DateTime.Formatter.zone_short %{zone_abbr: \"UTC\",\n    ...>   utc_offset: 0, std_offset: 0}, 4\n    \"GMT\"","ref":"Cldr.DateTime.Formatter.html#zone_short/3-examples"},{"type":"function","title":"Cldr.DateTime.Formatter.zone_short/5","doc":"","ref":"Cldr.DateTime.Formatter.html#zone_short/5"},{"type":"exception","title":"Cldr.DateTime.Compiler.ParseError","doc":"Exception raised when tokenizing a datetime format.","ref":"Cldr.DateTime.Compiler.ParseError.html"},{"type":"exception","title":"Cldr.DateTime.DateTimeOrderError","doc":"Exception raised when the first\ndatetime in an interval is greater than\nthe last datetime.","ref":"Cldr.DateTime.DateTimeOrderError.html"},{"type":"exception","title":"Cldr.DateTime.FormatError","doc":"Exception raised when attempting to\nformat a date or time which does not have\nthe data available to fulfill the format.","ref":"Cldr.DateTime.FormatError.html"},{"type":"exception","title":"Cldr.DateTime.IncompatibleTimeZonerError","doc":"Exception raised when the two\ndatetimes are in different time zones","ref":"Cldr.DateTime.IncompatibleTimeZonerError.html"},{"type":"exception","title":"Cldr.DateTime.IntervalFormatError","doc":"Exception raised when attempting to\ncompile an interval format.","ref":"Cldr.DateTime.IntervalFormatError.html"},{"type":"exception","title":"Cldr.DateTime.InvalidFormat","doc":"Exception raised when formatting and there is no\ndata for the given format.","ref":"Cldr.DateTime.InvalidFormat.html"},{"type":"exception","title":"Cldr.DateTime.UnknownTimeUnit","doc":"Exception raised when an attempt is made to use a time unit that is not known.\nin `Cldr.DateTime.Relative`.","ref":"Cldr.DateTime.UnknownTimeUnit.html"},{"type":"exception","title":"Cldr.DateTime.UnresolvedFormat","doc":"Exception raised when formatting and there is no\ndata for the given format.","ref":"Cldr.DateTime.UnresolvedFormat.html"},{"type":"extras","title":"Date and Time Localization and Formatting","doc":"# Date and Time Localization and Formatting\n\n![Build status](https://github.com/elixir-cldr/cldr_dates_times/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_dates_times.svg)](https://hex.pm/packages/ex_cldr_dates_times)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_dates_times.svg?)](https://hex.pm/packages/ex_cldr_dates_times)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr_dates_times.svg?)](https://hex.pm/packages/ex_cldr_dates_times)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_dates_times.svg)](https://hex.pm/packages/ex_cldr_dates_times)","ref":"readme.html"},{"type":"extras","title":"Installation - Date and Time Localization and Formatting","doc":"**Note that `ex_cldr_dates_times` requires Elixir 1.12 or later.**\n\nAdd `ex_cldr_dates_time` as a dependency to your `mix` project:\n\n```\ndefp deps do\n  [\n    {:ex_cldr_dates_times, \"~> 2.0\"}\n  ]\nend\n```\n\nthen retrieve `ex_cldr_dates_times` from [hex](https://hex.pm/packages/ex_cldr_dates_times):\n\n```\nmix deps.get\nmix deps.compile\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuring a required backend module - Date and Time Localization and Formatting","doc":"`ex_cldr_dates_times` uses the configuration set for the dependency `ex_cldr`.  See the documentation for [ex_cldr](https://hexdocs.pm/ex_cldr/2.0.0/readme.html#configuration).\n\nA `backend` module is required that is used to host the functions that manage CLDR data.  An example to get started is:\n\n1. Create a backend module (see [ex_cldr](https://hexdocs.pm/ex_cldr/2.0.0/readme.html#configuration) for details of the available options). Note the requirement to configure the appropriate `Cldr` provider backends.\n\n    ```elixir\n    defmodule MyApp.Cldr do\n      use Cldr,\n        locales: [\"en\", \"fr\", \"ja\"],\n        providers: [Cldr.Number, Cldr.Calendar, Cldr.DateTime]\n\n    end\n    ```\n\n2. [Optional] Update `config.exs` configuration to specify this backend as the system default. Not required, but often useful.\n\n    ```elixir\n    config :ex_cldr,\n      default_locale: \"en\",\n      default_backend: MyApp.Cldr\n    ```","ref":"readme.html#configuring-a-required-backend-module"},{"type":"extras","title":"Introduction - Date and Time Localization and Formatting","doc":"`ex_cldr_dates_times` is an addon library application for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localisation and formatting for dates, times and date_times.\n\nThe primary API is `MyApp.Cldr.Date.to_string/2`, `MyApp.Cldr.Time.to_string/2`, `MyApp.Cldr.DateTime.to_string/2` and `MyApp.Cldr.DateTime.Relative.to_string/2`.  In the following examples `MyApp` refers to a CLDR backend module that must be defined by the developer:\n\n```elixir\niex> MyApp.Cldr.Date.to_string ~D[2020-05-30]\n{:ok, \"May 30, 2020\"}\n\niex> MyApp.Cldr.Time.to_string ~U[2020-05-30 03:52:56Z]\n{:ok, \"3:52:56 AM\"}\n\niex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z]\n{:ok, \"May 30, 2020, 3:52:56 AM\"}\n\n# Note that if options are provided, a backend\n# module is also required\niex> MyApp.Cldr.DateTime.Relative.to_string 1, unit: :day, format: :narrow\n{:ok, \"tomorrow\"}\n```\n\nFor help in `iex`:\n\n```elixir\niex> h MyApp.Cldr.Date.to_string\niex> h MyApp.Cldr.Time.to_string\niex> h MyApp.Cldr.DateTime.to_string\niex> h MyApp.Cldr.DateTime.Relative.to_string\n```","ref":"readme.html#introduction"},{"type":"extras","title":"Date, Time and DateTime Localization Formats - Date and Time Localization and Formatting","doc":"Dates, Times and DateTimes can be formatted using standard formats, format strings or format IDs.\n\n* Standard formats provide cross-locale standardisation and therefore should be preferred where possible.  The format types, implemented for `MyApp.Cldr.Date.to_string/2`, `MyApp.Cldr.Time.to_string/2`,`MyApp.Cldr.DateTime.to_string/2` are `:short`, `:medium`, `:long`  and `:full`.   The default is `:medium`. For example, assuming a configured backend called `MyApp.Cldr`:\n\n    ```elixir\n    iex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], format: :short\n    {:ok, \"5/30/20, 3:52 AM\"}\n\n    iex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], format: :long\n    {:ok, \"May 30, 2020 at 3:52:56 AM UTC\"}\n\n    iex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], format: :medium\n    {:ok, \"May 30, 2020, 3:52:56 AM\"}\n\n    iex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], format: :long, locale: \"fr\"\n    {:ok, \"30 mai 2020 à 03:52:56 UTC\"}\n    ```\n\n* Format strings use one or more formatting symbols to define what date and time elements should be placed in the format.  A simple example to format the time into hours and minutes:\n\n    ```elixir\n    iex> MyApp.Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], format: \"hh:mm\"\n    {:ok, \"03:52\"}\n    ```\n\n* Format IDs are an atom that is a key into a map of formats defined by CLDR. These format IDs are returned by `MyApp.Cldr.DateTime.Format.date_time_available_formats/2` (assuming your backend is `MyApp.Cldr`).  The set of common format names across all locales configured in `ex_cldr` can be returned by `MyApp.Cldr.DateTime.Format.common_date_time_format_names/0`.\n\n    ```elixir\n    iex> MyApp.Cldr.DateTime.Format.date_time_available_formats()\n    %{mmmm_w_count_one: \"'week' W 'of' MMMM\", gy_mmm: \"MMM y G\", md: \"M/d\",\n    mmm_md: \"MMMM d\", e_hms: \"E HH:mm:ss\", ed: \"d E\", y_mmm: \"MMM y\",\n    e_hm: \"E HH:mm\", mmm_ed: \"E, MMM d\", y_mmm_ed: \"E, MMM d, y\",\n    gy_mm_md: \"MMM d, y G\", mmm: \"LLL\", y_md: \"M/d/y\", gy: \"y G\",\n    hms: \"h:mm:ss a\", hm: \"h:mm a\", y_mmmm: \"MMMM y\", m: \"L\",\n    gy_mmm_ed: \"E, MMM d, y G\", y_qqq: \"QQQ y\", e: \"ccc\", y_qqqq: \"QQQQ y\",\n    hmsv: \"h:mm:ss a v\", mmmm_w_count_other: \"'week' W 'of' MMMM\",\n    ehm: \"E h:mm a\", y_m_ed: \"E, M/d/y\", h: \"h a\", hmv: \"h:mm a v\",\n    yw_count_other: \"'week' w 'of' y\", mm_md: \"MMM d\", y_m: \"M/y\", m_ed: \"E, M/d\",\n    ms: \"mm:ss\", d: \"d\", y_mm_md: \"MMM d, y\", yw_count_one: \"'week' w 'of' y\",\n    y: \"y\", ehms: \"E h:mm:ss a\"}\n\n    # These format types can be invoked for any locale - meaning\n    # these format names are defined for all configured locales.\n    iex> MyApp.Cldr.DateTime.Format.common_date_time_format_names()\n    [:gy_mmm, :md, :mmm_md, :e_hms, :ed, :y_mmm, :e_hm, :mmm_ed, :y_mmm_ed,\n    :gy_mm_md, :mmm, :y_md, :gy, :hms, :hm, :y_mmmm, :m, :gy_mmm_ed, :y_qqq, :e,\n    :y_qqqq, :hmsv, :mmmm_w_count_other, :ehm, :y_m_ed, :h, :hmv, :yw_count_other,\n    :mm_md, :y_m, :m_ed, :ms, :d, :y_mm_md, :y, :ehms]\n\n    iex> Cldr.DateTime.to_string ~U[2020-05-30 03:52:56Z], MyApp.Cldr, format: :gy_mmm_ed\n    {:ok, \"Sat, May 30, 2020 AD\"}\n\n    iex(2)> Cldr.Time.to_string ~U[2020-05-30 03:52:56Z], MyApp.Cldr, format: :hm\n    {:ok, \"3:52 AM\"}\n\n    iex(3)> Cldr.Date.to_string ~U[2020-05-30 03:52:56Z], MyApp.Cldr, format: :yMd\n    {:ok, \"5/30/2020\"}\n    ```","ref":"readme.html#date-time-and-datetime-localization-formats"},{"type":"extras","title":"Format strings - Date and Time Localization and Formatting","doc":"The [CLDR standard](http://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table)\ndefines a wide range of format symbols.  Most - but not all - of these symbols are supported in\n`Cldr`.  The supported symbols are described below.  Note the [known restrictions and limitations](#known-restrictions-and-limitations).\n\n| Element                | Symbol     | Example         | Cldr Format                        |\n| :--------------------  | :--------  | :-------------- | :--------------------------------- |\n| Era                    | G, GG, GGG | \"AD\"            | Abbreviated                        |\n|                        | GGGG       | \"Anno Domini\"   | Wide                               |\n|                        | GGGGG      | \"A\"             | Narrow                             |\n| Year                   | y          | 7               | Minimum necessary digits           |\n|                        | yy         | \"17\"            | Least significant 2 digits         |\n|                        | yyy        | \"017\", \"2017\"   | Padded to at least 3 digits        |\n|                        | yyyy       | \"2017\"          | Padded to at least 4 digits        |\n|                        | yyyyy      | \"02017\"         | Padded to at least 5 digits        |\n| ISOWeek Year           | Y          | 7               | Minimum necessary digits           |\n|                        | YY         | \"17\"            | Least significant 2 digits         |\n|                        | YYY        | \"017\", \"2017\"   | Padded to at least 3 digits        |\n|                        | YYYY       | \"2017\"          | Padded to at least 4 digits        |\n|                        | YYYYY      | \"02017\"         | Padded to at least 5 digits        |\n| Related Gregorian Year | r, rr, rr+ | 2017            | Minimum necessary digits           |\n| Cyclic Year            | U, UU, UUU | \"甲子\"           | Abbreviated                        |\n|                        | UUUU       | \"甲子\" (for now) | Wide                               |\n|                        | UUUUU      | \"甲子\" (for now) | Narrow                             |\n| Extended Year          | u+         | 4601            | Minimum necessary digits           |\n| Quarter                | Q          | 2               | Single digit                       |\n|                        | QQ         | \"02\"            | Two digits                         |\n|                        | QQQ        | \"Q2\"            | Abbreviated                        |\n|                        | QQQQ       | \"2nd quarter\"   | Wide                               |\n|                        | QQQQQ      | \"2\"             | Narrow                             |\n| Standalone Quarter     | q          | 2               | Single digit                       |\n|                        | qq         | \"02\"            | Two digits                         |\n|                        | qqq        | \"Q2\"            | Abbreviated                        |\n|                        | qqqq       | \"2nd quarter\"   | Wide                               |\n|                        | qqqqq      | \"2\"             | Narrow                             |\n| Month                  | M          | 9               | Single digit                       |\n|                        | MM         | \"09\"            | Two digits                         |\n|                        | MMM        | \"Sep\"           | Abbreviated                        |\n|                        | MMMM       | \"September\"     | Wide                               |\n|                        | MMMMM      | \"S\"             | Narrow                             |\n| Standalone Month       | L          | 9               | Single digit                       |\n|                        | LL         | \"09\"            | Two digits                         |\n|                        | LLL        | \"Sep\"           | Abbreviated                        |\n|                        | LLLL       | \"September\"     | Wide                               |\n|                        | LLLLL      | \"S\"             | Narrow                             |\n| Week of Year           | w          | 2, 22           | Single digit                       |\n|                        | ww         | 02, 22          | Two digits, zero padded            |\n| Week of Month          | W          | 2               | Single digit. NOT IMPLEMENTED YET  |\n| Day of Year            | D          | 3, 33, 333      | Minimum necessary digits           |\n|                        | DD         | 03, 33, 333     | Minimum of 2 digits, zero padded   |\n|                        | DDD        | 003, 033, 333   | Minimum of 3 digits, zero padded   |\n| Day of Month           | d          | 2, 22           | Minimum necessary digits           |\n|                        | dd         | 02, 22          | Two digits, zero padded            |\n| Day of Week            | E, EE, EEE | \"Tue\"           | Abbreviated                        |\n|                        | EEEE       | \"Tuesday\"       | Wide                               |\n|                        | EEEEE      | \"T\"             | Narrow                             |\n|                        | EEEEEE     | \"Tu\"            | Short                              |\n|                        | e          | 2               | Single digit                       |\n|                        | ee         | \"02\"            | Two digits                         |\n|                        | eee        | \"Tue\"           | Abbreviated                        |\n|                        | eeee       | \"Tuesday\"       | Wide                               |\n|                        | eeeee      | \"T\"             | Narrow                             |\n|                        | eeeeee     | \"Tu\"            | Short                              |\n| Standalone Day of Week | c, cc      | 2               | Single digit                       |\n|                        | ccc        | \"Tue\"           | Abbreviated                        |\n|                        | cccc       | \"Tuesday\"       | Wide                               |\n|                        | ccccc      | \"T\"             | Narrow                             |\n|                        | cccccc     | \"Tu\"            | Short                              |\n| AM or PM               | a, aa, aaa | \"am.\"           | Abbreviated                        |\n|                        | aaaa       | \"am.\"           | Wide                               |\n|                        | aaaaa      | \"am\"            | Narrow                             |\n| Noon, Mid, AM, PM      | b, bb, bbb | \"mid.\"          | Abbreviated                        |\n|                        | bbbb       | \"midnight\"      | Wide                               |\n|                        | bbbbb      | \"md\"            | Narrow                             |\n| Flexible time period   | B, BB, BBB | \"at night\"      | Abbreviated                        |\n|                        | BBBB       | \"at night\"      | Wide                               |\n|                        | BBBBB      | \"at night\"      | Narrow                             |\n| Hour                   | h, K, H, k |                 | See the table below                |\n| Minute                 | m          | 3, 10           | Minimum digits of minutes          |\n|                        | mm         | \"03\", \"12\"      | Two digits, zero padded            |\n| Second                 | s          | 3, 48           | Minimum digits of seconds          |\n|                        | ss         | \"03\", \"48\"      | Two digits, zero padded            |\n| Fractional Seconds     | S          | 3, 48           | Minimum digits of fractional seconds |\n|                        | SS         | \"03\", \"48\"      | Two digits, zero padded            |\n| Milliseconds            | A+         | 4000, 63241     | Minimum digits of milliseconds since midnight |\n| Generic non-location TZ | v         | \"Etc/UTC\"       | `:time_zone` key, unlocalised      |\n|                         | vvvv      | \"unk\"           | Generic timezone name.  Currently returns only \"unk\" |\n| Specific non-location TZ | z..zzz   | \"UTC\"           | `:zone_abbr` key, unlocalised      |\n|                         | zzzz      | \"GMT\"           | Delegates to `zone_gmt/4`          |\n| Timezone ID             | V         | \"unk\"           | `:zone_abbr` key, unlocalised      |\n|                         | VV        | \"Etc/UTC        | Delegates to `zone_gmt/4`          |\n|                         | VVV       | \"Unknown City\"  | Exemplar city.  Not supported.     |\n|                         | VVVV      | \"GMT\"           | Delegates to `zone_gmt/4           |\n| ISO8601 Format          | Z..ZZZ    | \"+0100\"         | ISO8601 Basic Format with hours and minutes |\n|                         | ZZZZ      | \"+01:00\"        | Delegates to `zone_gmt/4           |\n|                         | ZZZZZ     | \"+01:00:10\"     | ISO8601 Extended format with optional seconds |\n| ISO8601 plus Z          | X         | \"+01\"           | ISO8601 Basic Format with hours and optional minutes or \"Z\" |\n|                         | XX        | \"+0100\"         | ISO8601 Basic Format with hours and minutes or \"Z\"          |\n|                         | XXX       | \"+0100\"         | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\" |\n|                         | XXXX      | \"+010059\"       | ISO8601 Basic Format with hours and minutes, optional seconds or \"Z\" |\n|                         | XXXXX     | \"+01:00:10\"     | ISO8601 Extended Format with hours and minutes, optional seconds or \"Z\" |\n| ISO8601 minus Z         | x         | \"+0100\"         | ISO8601 Basic Format with hours and optional minutes |\n|                         | xx        | \"-0800\"         | ISO8601 Basic Format with hours and minutes          |\n|                         | xxx       | \"+01:00\"        | ISO8601 Extended Format with hours and minutes       |\n|                         | xxxx      | \"+010059\"       | ISO8601 Basic Format with hours and minutes, optional seconds     |\n|                         | xxxxx     | \"+01:00:10\"     | ISO8601 Extended Format with hours and minutes, optional seconds  |\n| GMT Format              | O         | \"+0100\"         | Short localised GMT format        |\n|                         | OOOO      | \"+010059\"       | Long localised GMT format         |","ref":"readme.html#format-strings"},{"type":"extras","title":"Formatting symbols for hour of day - Date and Time Localization and Formatting","doc":"The hour of day can be formatted differently depending whether\na 12- or 24-hour day is being represented and depending on the\nway in which midnight and noon are represented.  The following\ntable illustrates the differences:\n\n| Symbol  | Midn.\t|\tMorning\t| Noon |\tAfternoon\t| Midn. |\n| :----:  | :---: | :-----: | :--: | :--------: | :---: |\n|   h\t    |  12\t  | 1...11\t|  12\t |   1...11   |  12   |\n|   K\t    |   0\t  | 1...11\t|   0\t |   1...11   |   0   |\n|   H\t    |   0\t  | 1...11\t|  12\t |  13...23   |   0   |\n|   k\t    |  24\t  | 1...11\t|  12\t |  13...23   |  24   |","ref":"readme.html#formatting-symbols-for-hour-of-day"},{"type":"extras","title":"Relative Date, Time and DateTime Localization Formatting - Date and Time Localization and Formatting","doc":"The primary API for formatting relative dates and datetimes is `MyApp.Cldr.DateTime.Relative.to_string/2`.  Some examples:\n\n```elixir\niex> MyApp.Cldr.DateTime.Relative.to_string(-1)\n{:ok, \"1 second ago\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1)\n{:ok, \"in 1 second\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day)\n{:ok, \"tomorrow\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, locale: \"fr\")\n{:ok, \"demain\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, format: :narrow)\n{:ok, \"tomorrow\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year)\n{:ok, \"in 1,234 years\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year, locale: \"fr\")\n{:ok, \"dans 1 234 ans\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(31)\n{:ok, \"in 31 seconds\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(~D[2017-04-29], relative_to: ~D[2017-04-26])\n{:ok, \"in 3 days\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(310, format: :short, locale: \"fr\")\n{:ok, \"dans 5 min\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(310, format: :narrow, locale: \"fr\")\n{:ok, \"+5 min\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string 2, unit: :wed, format: :short\n{:ok, \"in 2 Wed.\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string 1, unit: :wed, format: :short\n{:ok, \"next Wed.\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string -1, unit: :wed, format: :short\n{:ok, \"last Wed.\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string -1, unit: :wed\n{:ok, \"last Wednesday\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string -1, unit: :quarter\n{:ok, \"last quarter\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string -1, unit: :mon, locale: \"fr\"\n{:ok, \"lundi dernier\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(~D[2017-04-29], unit: :ziggeraut)\n{:error, {Cldr.UnknownTimeUnit,\n\"Unknown time unit :ziggeraut.  Valid time units are [:day, :hour, :minute, :month, :second, :week, :year, :mon, :tue, :wed, :thu, :fri, :sat, :sun, :quarter]\"}}\n```","ref":"readme.html#relative-date-time-and-datetime-localization-formatting"},{"type":"extras","title":"Interval Formatting - Date and Time Localization and Formatting","doc":"Interval formats allow for software to format intervals like \"Jan 10-12, 2008\" as a shorter and more natural format than \"Jan 10, 2008 - Jan 12, 2008\". They are designed to take a start and end date, time or datetime plus a formatting pattern and use that information to produce a localized format.\n\nAn interval is expressed as either a `from` and `to` date, time or datetime. Or it can also be a `Date.Range` or `CalendarInterval` from the [calendar_interval](https://hex.pm/packages/calendar_interval) library.\n\n`Cldr.Interval.to_string/3` function to format an interval based upon the type of the arguments: date, datetime or time.  The modules `Cldr.Date.Interval`, `Cldr.Time.Interval` and `Cldr.DateTime.Interval` also provide a `to_string/3` function for when the desired output format is more specific.\n\nSome examples:\n\n```elixir\niex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-12-31], MyApp.Cldr\n{:ok, \"Jan 1 – Dec 31, 2020\"}\n\niex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr\n{:ok, \"Jan 1 – 12, 2020\"}\n\niex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-01-12], MyApp.Cldr,\n...> format: :long\n{:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\niex> Cldr.Interval.to_string ~D[2020-01-01], ~D[2020-12-01], MyApp.Cldr,\n...> format: :long, style: :year_and_month\n{:ok, \"January – December 2020\"}\n\niex> use CalendarInterval\niex> Cldr.Interval.to_string ~I\"2020-01-01/12\", MyApp.Cldr,\n...> format: :long\n{:ok, \"Wed, Jan 1 – Sun, Jan 12, 2020\"}\n\niex> Cldr.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-12-01 10:05:00.0Z], MyApp.Cldr,\n...> format: :long\n{:ok, \"January 1, 2020 at 12:00:00 AM UTC – December 1, 2020 at 10:05:00 AM UTC\"}\n\niex> Cldr.Interval.to_string ~U[2020-01-01 00:00:00.0Z], ~U[2020-01-01 10:05:00.0Z], MyApp.Cldr,\n...> format: :long\n{:ok, \"January 1, 2020 at 12:00:00 AM UTC – 10:05:00 AM UTC\"}\n```","ref":"readme.html#interval-formatting"},{"type":"extras","title":"Known restrictions and limitations - Date and Time Localization and Formatting","doc":"Although largely complete (with respect to the CLDR data), there are some known limitations as of release 2.0.\n\n* *Timezones*  Although the timezone format codes are supported (formatting symbols `v`, `V`, `x`, `X`, `z`, `Z`, `O`) not all localisations are performed.  Only that data available within a `t:DateTime.t/0` struct is used to format timezone data.","ref":"readme.html#known-restrictions-and-limitations"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n**Note that `ex_cldr_dates_times` version 2.18.0 and later are supported on Elixir 1.12 and later only.**","ref":"changelog.html"},{"type":"extras","title":"Cldr_Dates_Times v2.19.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.19.1 released on July 8th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-19-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Include `:skeleton_tokenizer.xrl` to the hex package definition.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.19.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.19.0 released on July 8th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-19-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Date.to_string/2` with the option `era: :variant` to correctly render the variant \"AD\"/\"CE\"/\"BC\"/\"BCE\" text.\n\n* Fix `Cldr.Date.to_string/2` with the option `period: :variant` to correctly render the variant \"am\"/\"pm\" text.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds support for partial dates in `Cldr.Date.to_string/2`. Partial dates are maps with one or more of the fields `:year`, `:month`, `:day` and `:calendar`.\n\n* Adds support for partial time in `Cldr.Time.to_string/2`. Partial times are maps with one or more of the fields `:hour`, `:minute`, and `:second`.\n\n* Adds support for partial datetimes in `Cldr.DateTime.to_string/2`. Partial datetimes are maps with one or more of the fields `:year`, `:month`, `:day`, `:hour`, `:minute`, `:second` and `:calendar`.\n\n* Adds support for deriving the \"best match\" format for a date, time or datetime based upon the users requested format or deriving from the available date, time or datetime fields.\n\n* Adds support for formatting using format IDs (atoms that are keys to locale-independent formats) in `Cldr.Date.to_string/2` and `Cldr.Time.to_string/2`. They have been previously supported in `Cldr.DateTime.to_string/2` only.\n\n* Add `MyApp.Cldr.DateTime.Format.common_date_time_format_names/0`.\n\n* Improve the error message if `:hour` is outside the valid range.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.18.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.18.1 released on July 1st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-18-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting `am/pm` with format `:narrow` or `:wide`. Thanks to @sysashi for the report. Closes #48.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.18.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.18.0 released on May 29th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-18-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Clarify format compiler documentation. Thanks to @tjchambers for the issue. Closes #46.\n\n* Fix typos. Thanks to @tjchambers for the PR. Closes #47.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.17.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.17.1 released on May 2nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-17-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add `config/prod.exs` so that the library can be compiled with `MIX_ENV=prod`. Thanks to @camelpunch for the PR. Closes #45.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.17.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.17.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-17-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting with formats that have may have pluralization like the `:MMMMW` and `:yw` formats.\n\n* Fix `:underspecs` for dialyzer.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 45.0](https://cldr.unicode.org/index/downloads/cldr-45) data.\n\n* Adds support for formats that have both unicode whitespace and ascii whitespace versions. The option `:prefer` is added to `Cldr.DateTime.to_string/3`. The default is `prefer: :unicode`. The option `prefer: :ascii` is included for backwards compatibility of older applications. The formats that provide both `:unicode` and `:ascii` versions can be seen from the results of `Cldr.DateTime.Format.date_time_available_formats/2`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.16.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.16.0 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-16-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting time intervals when the `to` time is not greater than the `from` time. This allows time intervals that cross midnight to be formatted correctly. Thanks to @larshei  for the report. Closes #42.\n\n* Fix compiler warnings on Elixir 1.16.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds options `:date_format` and `:time_format` to `Cldr.DateTime.Interval.to_string/2` and `Cldr.DateTime.to_string/2`. These options allow separate formatting of the date and time parts of a datetime, including those that are part of an interval. Thanks to @jmoldrich for the report (and patience). Closes #33.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.15.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.15.0 released on October 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-15-0"},{"type":"extras","title":"Deprecations - Changelog","doc":"* The support of `:style` as a synonym for `:format` with the functions `Cldr.Time.to_string/2`, `Cldr.Date.to_string/2` and `Cldr.DateTime.to_string/2` is now removed.  The `:style` option is now used to influence the use of \"at\" formats in `Cldr.DateTime.to_string/2`. `:style` also remains a valid option for interval formatting.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for \"at\" style formatting for `DateTime` structs. This style is documented in [TR35](https://unicode.org/reports/tr35/tr35-dates.html#Date_Time_Combination_Examples) and was introduced in [CLDR 43](https://cldr.unicode.org/index/downloads/cldr-43). Thanks to @jueberschlag for the report and motivation to get this done.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.14.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.14.3 released on October 10th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-14-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting date intervals with `:month_and_day` style when the last date is in a different year to the first. Thanks to @matt-glover for the report. Closes #40.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.14.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.14.2 released on September 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-14-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix additional typespecs for various functions that allow a string-based locale identifier. Thanks to @jarrodmoldrich for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.14.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.14.1 released on September 23rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-14-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix typespecs for various functions that allow a string-based locale identifier. Thanks to @jarrodmoldrich for the report. Closes #39.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.14.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.14.0 released on August 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-14-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.37.0](https://hex.pm/packages/ex_cldr/2.37.0) which includes data from [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43)\n\n* Adds an option `:wrapper` to `Cldr.DateTime.to_string/2`, `Cldr.Date.to_string/2` and `Cldr.Time.to_string/2`. The argument is a 2-arity function that receives the parameters `string` and `tag` where `tag` is an atom denoting the time unit being formatted (for example, `:minute` or `:year` or `:literal`). The function must return either iodata or a \"safe string\" such as that returned by `Phoenix.HTML.Tag.content_tag/3`. The function can be used to wrap format elements in HTML or other tags.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.13.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.13.3 released on March 13th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-13-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"**This release requires (and configures) `ex_cldr` version 2.36.0 or later. That version fixes the interval format data so that formats required by locales that use 24-hour times are not overwritten by data for 12-hour formats.  As a result, formatting intervals using a format key directly (ie one of the keys in the map returned by `MyApp.Cldr.DateTime.Format.date_time_interval_formats/1`) may find the key has changed.**\n\n* Fixes localised time interval formatting to respect the locale's preference for 12-hour or 24-hour times.  Thanks to @Gladear for the report and collaboration. Closes #35.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.13.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.13.2 released on March 12th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-13-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixed interval formats when the format provided is a string (rather than the normal atom-based predefined formats)\n\n* Fixed setting the number system from options (typographical error)\n\n* Removed spurious `IO.inspect/2` output when the format is a string.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.13.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.13.1 released on November 12th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-13-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes doc generation errors (no functional changes to executing code).  Closes #34. THanks to @sax for the report and the PR.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.13.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.13.0 released on October 19th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-13-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR 42](https://cldr.unicode.org/index/downloads/cldr-42).  The data time formats for several locales have changed from \"  at  \" to \" ,  \". This is a new category of formats that retain the `at` formats but these are not yet exposed in `ex_cldr_dates_times`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.12.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.12.0 released on May 7th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes `Cldr.Date.Interval.greatest_difference/2` to be part of the public API. Also adds `Cldr.DateTime.Interval.greatest_difference/2` and `Cldr.Time.Interval.greatest_difference/2`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.11.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.11.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-11-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) and [ex_cldr_numbers version 2.25.0](https://hex.pm/packages/ex_cldr_numbers/2.25.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.10.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.2 released on January 15th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Date.to_string/2` when the second argument is a list of options and not a backend module. Previously this would ignore any `:backend` option and try to use `Cldr.default_backend!/0` which would fail if not one was configured. The same fix is applied to `Cldr.Time.to_string/2` and `Cldr.DateTime.to_string/2`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.10.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.1 released on December 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Replace `use Mix.Config` with `import Config` in config files\n\n* Correctly call `transliterate_digits/3` not `transliterate/3` when transliterating digits for date/time formats","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.10.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Improved localization in support of Chinese, Japanese and Korea calendars (era, month names, cyclic year, related gregorian year)\n\n* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix year formatting to account for different calendar resolvers","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_config/2` instead.\n\n* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Dates_Times v2.10.0-rc.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.0-rc.3 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-0-rc-3"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Dates_Times v2.10.0-rc.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.0-rc.2 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-0-rc-2"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_config/2` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Dates_Times v2.10.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.0-rc.1 released on October 21st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-0-rc-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix year formatting to account for different calendar resolvers","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.10.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.10.0-rc.0 released on October 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-10-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Improved localization in support of Chinese, Japanese and Korea calendars (era, month names, cyclic year, related gregorian year)\n\n* Update to `ex_cldr` version `2.24` which uses [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.9.4 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.9.4 released on September 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-9-4"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes relative date and date time formatting when a `:relative_to` parameter and no `:unit` parameter is specified. Thanks to @maennchen for the report.  Closes #26.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.9.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.9.3 released on September 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-9-3"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes relative date and date time formatting when a `:relative_to` parameter and a `:unit` parameter is specified. Thanks to @DaTrader for the report.  Closes #25.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.9.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.9.2 released on August 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-9-2"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Open interval formats can now also be called directly on the backend. For example:\n\n        iex> MyApp.Cldr.Date.Interval.to_string ~D[2020-01-01], nil\n        {:ok, \"Jan 1, 2020 –\"}","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.9.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.9.1 released on August 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-9-1"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* When formatting an open interval (one side is `nil`) the backend function `date_time_interval_fallback/2` is used to retrieve the format pattern. Previously this function was being called with default parameters. Now it is properly called with a locale and a calendar.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.9.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.9.0 released on August 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-9-0"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fix splitting interval formats when there is no repeating field. Use the principal that standalone formats are equivalent to normal formats when splitting.  ie, for this purposes \"L\" == \"M\". This means the locale \"fa\" no longer raises an exception.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Allow formatting of intervals where one side is `nil`. This will produce an open-ended interval. Only one side of the interval can be `nil`. Thanks to @woylie for the request.  Closes #23.\n\n#### Examples\n\n      iex> Cldr.Date.Interval.to_string ~D[2020-01-01], nil, MyApp.Cldr,\n      ...> format: :short\n      {:ok, \"1/1/20 –\"}\n\n      iex> Cldr.Time.Interval.to_string ~U[2020-01-01 00:00:00.0Z], nil, MyApp.Cldr,\n      ...> format: :long, style: :flex\n      {:ok, \"12:00:00 AM UTC –\"}\n\n      iex> Cldr.DateTime.Interval.to_string ~U[2020-01-01 00:00:00.0Z], nil, MyApp.Cldr\n      {:ok, \"Jan 1, 2020, 12:00:00 AM –\"}","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.8.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.8.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-8-0"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes formatting time intervals that by checking for a format key of `:h` in addition to the `:a` and `:b` format keys (similar to issue #22).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to [ex_cldr version 2.23.0](https://hex.pm/packages/ex_cldr/2.23.0) which changes the names of some of the field in the \"-u-\" extension to match the CLDR canonical name. In particular the field name `hour_cycle` changes to `hc`. The values for `hc` also change to the canonical forms of `:h12`, `:h11`, `:h23` and `:h24`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.7.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.7.2 released on May 6th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-7-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix regression time intervals where the start time is \"a.m.\" and the end time is \"p.m.\" and the format code is `:b` (previously assumed `:a`). Thanks to @bryanlep for the report. Closes #22.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.7.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.7.1 released on May 6th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting time intervals where the start time is \"a.m.\" and the end time is \"p.m.\". Thanks to @sfusato for the report. Closes #21.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.7.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.7.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-7-0"},{"type":"extras","title":"Data changes - Changelog","doc":"* Some date and time formats have changed for some locales. This applies to interval date, time and datetime formats in `en` locale for example. Some time formats have also now changed in `en` from 24-hour times to `am/pm` formats.","ref":"changelog.html#data-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.7.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.7.0-rc.0 released on March 19th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-7-0-rc-0"},{"type":"extras","title":"Data changes - Changelog","doc":"* Some date and time formats have changed for some locales. This applies to interval date, time and datetime formats in `en` locale for example. Some time formats have also now changed in `en` from 24-hour times to `am/pm` formats.","ref":"changelog.html#data-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.6.4 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.6.4 released on December 17th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-6-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove `xref` section from the project in `mix.exs`. The fixes an error where the configuration for `xref` was incorrect and causing compiler errors on some versions of Elixir. Closes #19. Thanks to @fertapric.\n\n* Make dependencies `eprof` and `dialyixir` optional so that they aren't dragged into host apps unnecessarily.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.6.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.6.3 released on December 3rd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-6-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* [UPDATED] Fix regression whereby formatting a Date or Time via a backend with no options would raise a `Cldr.NoDefaultBackendError (No default :ex_cldr backend is configured)` exception. Closes #18 properly. Thanks to @maennchen.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.6.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.6.2 released on December 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-6-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix regression whereby formatting a DateTime via a backend with no options would raise a `Cldr.NoDefaultBackendError (No default :ex_cldr backend is configured)` exception. Closes #18. Thanks to @maennchen.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.6.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.6.1 released on November 30th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-6-1"},{"type":"extras","title":"Performance improvements - Changelog","doc":"* Don't transliterate when the number system is `:latn` (which it most commonly is). The improves formatting performance by about 40%.\n\n* Handle default parameters more efficiently which improves performance by a further 10%.","ref":"changelog.html#performance-improvements"},{"type":"extras","title":"Cldr_Dates_Times v2.6.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.6.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.5.4 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.5.4 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-5-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `Cldr.Date.default_backend/0` as a shim to provide compatibility for the upcoming `ex_cldr` version `2.18.0` where `Cldr.default_backend/0` is deprecated in favour of `Cldr.default_backend!/0`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.5.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.5.3 released on September 22nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-5-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warns on duplicate `@doc` on Elixir 1.11","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.5.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.5.2 released on September 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-5-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct the spec for Cldr.DateTime.Relative.to_string!/3. Thanks to @loskobrakai.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.5.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.5.1 released on June 17th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-5-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use locale's number system if no optional number system is provided. Fixes `Cldr.Date`, `Cldr.Time` and `Cldr.DateTime`\n\n* Fix datetime formatting for `CalendarInterval`s that have minute precision. In these cases, `:seconds` and `:microseconds` should be zeroed.\n\n* Fix links to `hex.pm` for `calendar_interval`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.5.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.5.0 released on June 13th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add localized interval formatting with `Cldr.Interval.to_string/3` and specific implementations in `Cldr.Date.Interval.to_string/3`, `Cldr.Time.Interval.to_string/3` and `Cldr.DateTime.to_string/3`\n\n* Add ` .Interval.to_string/3`, ` .Date.Interval.to_string/3`, ` .Time.Interval.to_string/3`, ` .DateTime.Interval.to_string/3`\n\n* Add `:precompiled_interval_formats` defined in the backend configuration","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct doc examples in README.md. Thanks to @tcitworld. Closes #13.\n\n* Fix options processing for `:style` and `:format` for `Cldr.Date.to_string/3`, `Cldr.DateTime.to_string/3` and `Cldr.Time.to_string/3`.  `:format` is preferred although `:style` is honoured.\n\n* Fix transliteration to other number systems\n\n* Retrieve `:precompiled_date_time_formats` from the backend configuration, not the global configuration","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.4.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.4.0 released on May 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Time.hour_format_from_locale/1` to return the hour formatted preferred for a locale\n\n* Add `Cldr.DateTime.Formatter.hour/{2, 4}` that formats the hour part of a time in accordance with locale preferences (including honouring the `hc` key of the `u` language tag extension)\n\n* Add format symbol `ddd` to return the day of the month with ordinal formatting. This not a CLDR standard format symbol.\n\n* Add protocol support for `Cldr.Chars` which is used by `Cldr.to_string/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.3.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.3.0 released on February 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds backend modules `MyApp.Cldr.Date`, `MyApp.Cldr.Time` and `MyApp.Cldr.DateTime` that contain the functions `to_string/2` and `to_string!/2`. This means all the `ex_cldr` family of libraries should now be primarily called on the backend modules. This makes aliasing easier too. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr, providers: [Cldr.Number, Cldr.DateTime], default_locale: \"en\"\nend\n\ndefmodule MyApp do\n  alias MyApp.Cldr\n\n  def some_fun do\n    Cldr.Date.to_string Date.utc_today()\n  end\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.2.4 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.2.4 released on January 14th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-2-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Update tests for Elixir 1.10 date/time inspection changes\n\n* Fix dialyzer warning in generated backend","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.2.3 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.2.3 released on September 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-2-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly uses a provided `:backend` option when validating the `:locale` option to the various `to_string/3` calls.  Thanks to @lostkobrakai. Closes #108 and #109.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.2.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.2.2 released on August 31st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-2-2"},{"type":"extras","title":"Changes & Deprecations - Changelog","doc":"* Deprecates the option `:format` on `Cldr.DateTime.Relative.to_string/3` in favour of `:style`. `:format` will be removed with `ex_cldr_dates_times` version 3.0","ref":"changelog.html#changes-deprecations"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Return an error tuple immediately when a format code is used but no data is available to fulfill it","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.2.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.2.1 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `@spec` for `Cldr.Date.to_string/3`, `Cldr.Time.to_string/3` and `Cldr.DateTime.to_string/3` as well as the `!` variants.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.2.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.2.0 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-2-0"},{"type":"extras","title":"Breaking change - Changelog","doc":"* Support Elixir 1.8 and later only since this package depends on [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars) which requires Elixir 1.8.","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix references to `Cldr.get_current_locale/0` to the current `Cldr.get_locale/0`\n\n* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.1.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.1.0 released on June 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* All calling `Date`, `Time` and `DateTime` `to_string/3` as `to_string/1` omitting the backend and providing options.  The backend will default to `Cldr.default_backend()`. An exception will be raised if there is no default backend.\n\n* Updates to [ex_cldr_calendars 1.0](https://hex.pm/packages/ex_cldr_calendars/1.0.0) which includes `Cldr.Calendar.week_of_month/1`. The result corresponds to the `W` format which is now implemented as well.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Dates_Times v2.0.2 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.0.2 released on June 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-0-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Resolve the actual number system before transliterating a date, time or datetime.  Closes #9.  Thanks to @ribanez7 for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.0.1 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.0.1 released on June 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)","ref":"changelog.html#cldr_dates_times-v2-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes a formatter code generation error when a format is a tuple form not a string form.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Dates_Times v2.0.0 - Changelog","doc":"This is the changelog for Cldr_Dates_Times v2.0 released on June 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_dates_times/tags)\n\nThis release depends on [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars) which provides the underlying calendar calculations as well as providing a set of additional calendars.","ref":"changelog.html#cldr_dates_times-v2-0-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* `ex_cldr_dates_times` requires a minimum Elixir version of 1.8.  It depends on `Calendar` capabilities built into this and later release.\n\n* `ex_cldr_dates_times` now depends upon [ex_cldr version 2.0](https://hex.pm/packages/ex_cldr/2.0.0).  As a result it is a requirement that at least one backend module be configured as described in the [ex_cldr readme](https://hexdocs.pm/ex_cldr/2.0.0/readme.html#configuration).\n\n* The public API is now based upon functions defined on a backend module. Therefore calls to functions such as `Cldr.DateTime.to_string/3` should be replaced with calls to `MyApp.Cldr.DateTime.to_string/3` (assuming your configured backend module is called `MyApp.Cldr`).","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Correctly calculates `week_of_year`\n\n* Supports `Calendar.ISO` and any calendar defined with `Cldr.Calendar` (see [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars))","ref":"changelog.html#enhancements"},{"type":"extras","title":"Known limitations - Changelog","doc":"* Does not calculate `week_of_month`. If called will return `1` for all input values.","ref":"changelog.html#known-limitations"},{"type":"extras","title":"Migration - Changelog","doc":"`ex_cldr_dates_times` uses the configuration set for the dependency `ex_cldr`.  See the documentation for [ex_cldr](https://hexdocs.pm/ex_cldr)\n\nUnlike `ex_cldr_dates_times` version 1, version 2 requires one or more `backend` modules to host the functions that manage CLDR data.  An example to get started is:\n\n1. Create a backend module:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\", \"ja\"],\n    providers: [Cldr.Number, Cldr.Calendar, Cldr.DateTime]\n\nend\n```\n\n2. Update `config.exs` configuration to specify this backend as the system default:\n\n```elixir\nconfig :ex_cldr,\n  default_locale: \"en\",\n  default_backend: MyApp.Cldr\n```\n\n3. Replace calls to `Date`. `Time` and `DateTime` functions `to_string/2` with calls to `to_string/3` where the second parameter is a backend module.","ref":"changelog.html#migration"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2017 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}